(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    504138,      10385]*)
(*NotebookOutlinePosition[    505121,      10416]*)
(*  CellTagsIndexPosition[    505077,      10412]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Interactive Evolution of Biomorphs", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Christian Jacob and Henry Kwong\n",
  StyleBox["Department of Computer Science, University of Calgary, Alberta\n\
May 2001 ",
    FontFamily->"Times"],
  "\[Copyright] Copyright"
}], "Subtitle"],

Cell["Inspired by: Richard Dawkins's \"Blind Watchmaker\"", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Starting the Biomorphs Program", "Section"],

Cell[BoxData[GridBox[{
        {"1.", 
          RowBox[{
            RowBox[{"In", " ", \(the'\), 
              RowBox[{
                StyleBox["Kernel",
                  FontWeight->"Bold"], "'"}], " ", "menu", " ", \(select'\), 
              RowBox[{
                StyleBox["Evaluation",
                  FontWeight->"Bold"], "'"}]}], ",", 
            RowBox[{\(then'\), 
              StyleBox["Evaluate",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              RowBox[{
                RowBox[{
                  StyleBox["Initialization",
                    FontWeight->"Bold"], "'"}], ".", "  ", 
                "\[IndentingNewLine]", "Click"}], " ", \(on'\), 
              RowBox[{
                StyleBox["Yes",
                  FontWeight->"Bold"], "'"}], " ", "when", " ", "the", " ", 
              "dialog", " ", "box", " ", "appears", " ", "to", " ", "ask", 
              " ", "whether", " ", "you", " ", "would", " ", "like", " ", 
              "to", " ", "initialize", " ", "all", " ", "the", 
              " ", \(\(cells\)\(.\)\)}]}]}
        },
      ColumnAlignments->{Left}]], "Text"],

Cell[BoxData[GridBox[{
        {"2.", 
          RowBox[{\(When\ the\ initialization\ has\ completed\), ",", 
            RowBox[{
            "click", " ", "on", " ", "the", " ", "button", " ", "below", " ", 
              "to", " ", "start", " ", "the", " ", "Biomorphs", " ", 
              RowBox[{"program", ".", "\[IndentingNewLine]", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        RowBox[{
                        "You", " ", "will", " ", "know", " ", "when", " ", 
                          "the", " ", "initializations", " ", "are", " ", 
                          "complete", " ", "when", " ", "the", " ", \(word'\),
                           
                          StyleBox["Running",
                            FontWeight->"Bold"]}], 
                        StyleBox["...",
                          FontWeight->"Bold"]}], "'"}], " ", "disappears", 
                    " ", "\[IndentingNewLine]", "from", " ", "the", " ", 
                    "title", " ", "bar", " ", "of", " ", "this", 
                    " ", \(\(window\)\(.\)\)}], ")"}]}]}]}]}
        }]], "Text"],

Cell[BoxData[
    TagBox[
      ButtonBox[
        StyleBox[\(Start\ Biomorph\ Program\),
          FontColor->GrayLevel[0]],
        ButtonFunction:>If[ 
            SameQ[ 
              SymbolName[ BiomorphInitializedFlag], "True"], 
            CompoundExpression[ 
              Set[ allNBs, {}], 
              Times[ 
                CompoundExpression[ 
                  Set[ curBiomorphNBObj, 
                    spawnNB[ 
                      curBiomorphNB[ ]]], Null], 
                CompoundExpression[ 
                  Set[ chooserNBObj, 
                    spawnNB[ chooserNB]], Null], 
                CompoundExpression[ 
                  Set[ ctrlNBObj, 
                    spawnNB[ ctrlNB]], Null], 
                CompoundExpression[ 
                  Set[ biomorphModel, 
                    newBioTree[ 
                      randomBiomorphParams[ ]]], Null], 
                refreshAll[ biomorphModel]], Null], 
            CompoundExpression[ 
              Set[ 
                MessageName[ StartBiomorphsButton, "UninitializedNotebook"], 
                "Please execute 'Evaluate Initialization' from the 'Kernel' \
-> 'Evaluation' menu."], 
              Message[ 
                MessageName[ 
                StartBiomorphsButton, "UninitializedNotebook"]]]],
        ButtonEvaluator->Automatic,
        Active->True],
      DisplayForm]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the Program", "Section"],

Cell[BoxData[GridBox[{
        {"1.", \(The\ user\ can\ select\ Biomorphs\ \((line\ figures)\)\ by\ \
clicking\ on\ an\ image\ in\ the\ enumerated\ grid\ of\ \[IndentingNewLine]
          
          Biomorphs . \ \ Biomorphs\ can\ be\ deselected\ by\ clicking\ on\ \
their\ image\ a\ second\ \(\(time\)\(.\)\)\)},
        {"2.", \(To\ interactively\ evolve\ the\ Biomorphs, 
          simply\ select\ the\ desired\ Biomorphs\ to\ be\ breed\ and\ \
\[IndentingNewLine]
          
          then\ click\ on\ the' 
            Evolve'\ button\ that\ appears\ in\ the\ same\ window . \ \ This\ \
will\ create\ a\ new\ generation, \[IndentingNewLine]however\ previous\ \
generations\ can\ still\ be\ \(\(selected\)\(.\)\)\)},
        {"3.", \(To\ compare\ the\ genome\ of\ various\ Biomorphs, \ 
          simply\ select\ the\ desired\ Biomorphs\ and\ click\ \
\[IndentingNewLine]
          the\ ' Compare'\ \(\(button\)\(.\)\)\)},
        {"4.", \(One\ can\ also\ get\ more\ information\ on\ the\ selected\ \
Biomorphs\ by\ clicking\ on\ the' 
            Profile'\ button . \ \ This\[IndentingNewLine]
          
          will\ spawn\ a\ new\ window\ containing\ a\ larger\ image\ of\ the\ \
selected\ Biomorph, \ and\ its\ genome\ \ formatted\[IndentingNewLine]
          in\ a\ \(\(table\)\(.\)\(\ \ \)\)\)},
        {"5.", \(If\ LiveGraphics3D\ is\ installed\ \((as\ described\ in\ the\
\ next\ section)\) 
            one\ can\ also\ spawn\ an\ interactive\ \[IndentingNewLine]
          
          viewer\ \ from\ the\ profile\ window\ to\ view\ the\ Biomorphs\ as\ \
rendered\ with\ cones\ or\ ellipsoids . \ \ To\ spawn\ \[IndentingNewLine]
          this\ viewer, \ 
          click\ on\ either\ the\ ' Cone'\ or\ ' 
            Ellipsoid'\ button\ from\ a\ profile\ window . \
\[IndentingNewLine]\((Note\ these\ buttons\ will\ only\ appear\ if\ \
LiveGraphics3D\ is\ setup, \ 
                which\ is\ described\ in\ the\ next\ section)\) . \)},
        {"6.", 
          RowBox[{
          "One", " ", "can", " ", "animate", " ", "a", " ", "biomorph", " ", 
            "in", " ", "a", " ", "profile", " ", "window", " ", "by", " ", 
            "doing", " ", "the", " ", 
            RowBox[{"following", ":", "\[IndentingNewLine]", GridBox[{
                  {\(\(a\)\(.\)\), \(Select\ the\ number\ of\ animation\ \
frames\ by\ clicking\ on\ one\ of\ the\ numbered\ buttons\ in\ the\ \
\(\(window\)\(.\)\)\)},
                  {\(\(b\)\(.\)\), \(Click\ on\ the\ ' 
                      Refresh'\ \(\(button\)\(.\)\)\)},
                  {\(\(c\)\(.\)\), \(Double\ click\ on\ the\ first\ Biomorph\ \
image\ in\ the\ profile\ \(\(window\)\(.\)\)\)}
                  },
                ColumnAlignments->{Left}]}]}]}
        },
      ColumnAlignments->{Left}]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting LiveGraphics3D", "Section"],

Cell[BoxData[GridBox[{
        {" ", \(If\ you\ would\ like\ to\ run\ the\ program\ with\ Live\ \
Graphics\ 3  D\ then\ you\ will\ need\ to\ have\ \[IndentingNewLine]
          installed\ J/Link\ and\ Live\ Graphics\ 3  D . \ \ However, 
          you\ can\ run\ the\ program\ without\ \[IndentingNewLine]
          Live\ Graphics\ 3 \( \(D\)\(.\)\(\ \ \)\)\)}
        },
      ColumnAlignments->{Left}]], "Text"],

Cell[TextData[{
  "\tThe following are web sites where one can find J/Link and \
LiveGraphics3D:\n\tJ/Link web site",
  ButtonBox["\n\t\thttp://www.wolfram.com/solutions/mathlink/jlink/ \n\t",
    ButtonData:>{
      URL[ "http://www.wolfram.com/solutions/mathlink/jlink/"], None},
    ButtonStyle->"Hyperlink"],
  "Live Graphics 3D web site:\n \t\t",
  ButtonBox["http://wwwvis.informatik.uni-stuttgart.de/~kraus/LiveGraphics3D/ \
index.html",
    ButtonData:>{
      URL[ 
      "http://wwwvis.informatik.uni-stuttgart.de/~kraus/LiveGraphics3D/index.\
html"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using LiveGraphics3D", "Section"],

Cell[BoxData[GridBox[{
        {"  ", \(To\ activate\ LiveGraphics3D, 
          execute\ the\ following\ cell\ and\ restart\ the\ Biomorph\ program\
\[IndentingNewLine]
          \(\((note, 
              you\ must\ have\ installed\ J/Link\ and\ Live\ Graphics\ 3  
                D\ \((see\ step\ 1)\))\)\(:\)\)\)}
        }]], "Text"],

Cell[BoxData[{
    \(\(<< JLink`;\)\), "\[IndentingNewLine]", 
    \(\(InstallJava[];\)\), "\[IndentingNewLine]", 
    \(\(\(liveOn = True;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(live3DPrimitiveBT[theBiomorph_List, label_String, 
          prim_Rule]\  := \ \[IndentingNewLine]ButtonBox[
          AdjustmentBox[\[IndentingNewLine]StyleBox[
              label, \ \ FontColor\  \[Rule] \ 
                RGBColor[0, 0, 
                  0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ \
{invarLRBoxMargin[9, label], {0.5, 0.5}}], \ \ Background\  \[Rule] \ 
            GrayLevel[0.8], \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
            Automatic, \ 
          Active \[Rule] \ 
            True, \ \[IndentingNewLine]ButtonFunction \[RuleDelayed] \ \((\
\[IndentingNewLine]Module[{liveApplet, 
                  bioInputForm}, \[IndentingNewLine]bioInputForm = 
                  InputForm[
                    biomorph[theBiomorph, \ 
                      prim]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
                  Add\ in\ the\ background\ color\ \
*) \[IndentingNewLine]bioInputForm = 
                  ReplacePart[
                    bioInputForm, \[IndentingNewLine]Append[
                      Extract[bioInputForm, {1, 2}], 
                      Background -> 
                        windowBackgroundColor], \[IndentingNewLine]{1, 
                      2}]; \[IndentingNewLine]liveApplet\  = \ 
                  JavaNew["\<Live\>"]; \
\[IndentingNewLine]JavaNew["\<com.wolfram.jlink.MathAppletFrame\>", \ 
                  liveApplet, \ \[IndentingNewLine]{"\<INPUT=\>"\  <> \ 
                      ToString[
                        bioInputForm], \ "\<WIDTH=300\>", \ \
"\<HEIGHT=300\>"}];\[IndentingNewLine]])\)]\ ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(live3D[
        theGraphics_Graphics3D]\  := \ \[IndentingNewLine]Module[{liveApplet, 
          graphicsInputForm}, \[IndentingNewLine]graphicsInputForm = 
          InputForm@theGraphics; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Add\ in\ the\ background\ color\ \
\[IndentingNewLine]\(graphicsInputForm = 
                ReplacePart[
                  graphicsInputForm, \[IndentingNewLine]Append[
                    Extract[graphicsInputForm, {1, 2}], 
                    Background -> 
                      notebookBackgroundColor], \[IndentingNewLine]{1, 
                    2}];\)*) \[IndentingNewLine]\[IndentingNewLine]liveApplet\
\  = \ JavaNew["\<Live\>"]; \
\[IndentingNewLine]JavaNew["\<com.wolfram.jlink.MathAppletFrame\>", \ 
          liveApplet, \ \[IndentingNewLine]{"\<INPUT=\>"\  <> \ 
              ToString[
                graphicsInputForm], \ "\<WIDTH=300\>", \ "\<HEIGHT=300\>"}];\
\[IndentingNewLine]]\)\( (*Module*) \)\(\[IndentingNewLine]\)
    \)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Biomorph Code", "Section",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell["Chooser Code", "Subsection",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell["\<\

BeginPackage[\"Chooser`\"];
(*
Selection Clearing, Expanding and Retrieval
*)
(* Retrieves the selected choices within a given generation *)
getSelection[genNum_Integer] := If[((Head@chooserSelection[genNum] === List)
        && (chooserSelection[genNum] =!= {})),
    {genNum, chooserSelection[genNum]},
    Null]
(* Retrieves all the selected choices within a given generation range *)
getAllSelection[genNumRange__] :=
  Select[getSelection[#1] & /@ Range[genNumRange],
    (#1 =!= Null) &]
(* Converts a selection list of the form :
      { {genNum, {a, b, c, ...}}, ...} to { {genNum, a}, {genNum, b}, \
{genNum,
             c}, ... }
    where a, b, c are selections within a generation
    and genNum is the generation number
  *)
expandSelections[genNum_Integer, selection_List] := {genNum, #1} & /@ 
      selection;
expandSelections[selections_List] :=
    Flatten[expandSelections[Sequence @@ #1] & /@ selections, 1];
(* Clears the selected choices within a given generation *)
clearSelection[genNum_Integer] := 
    If[Head@chooserSelection[genNum] === List, 
      chooserSelection[genNum] = {}];
(* Clears all the selected choices within a given generation range*)
clearAllSelection[genNumRange__] :=
  clearSelection[#1] & /@ Range[genNumRange]
(*
refreshChooser[ ]  and  clearAndUpdate[ ]
*)
(* Refresh chooser highlights for all generations upto genNum *)
refreshChooser[genNum_Integer] :=
  If[Head@refreshParms[#1] === List,
        refreshHighlights @@ refreshParms[#1]
        ] & /@ Range[1, genNum]
(* Clear all selections and refresh the chooser within a 
    given generation.
      idNums specify selected individuals in the generation.
  *)
clearAndUpdate[idNums_List, nbObj_NotebookObject, genNum_Integer, 
    numColumns_List, highlightSize_List, opts___] :=
  Module[{buttonsPerRow, numRows, theRows, theFirstNums, theColumns},
    chooserSelection[genNum] = {};
    buttonsPerRow = numColumns[[1]];
    numRows = Length@numColumns;
    theRows = Union[Floor[(#1 - 1)/buttonsPerRow] & /@ idNums];
    theFirstNums = theRows*buttonsPerRow + 1;
    theColumns = numColumns[[#1 + 1]] & /@ theRows;
    
    MapThread[(
          updateHighlight[nbObj, genNum, #1, #2, highlightSize, True, opts];
          updateHighlight[nbObj, genNum, #1, #2, highlightSize, False, opts];
          ) &,
      {theFirstNums, theColumns}
      ];
    ]
(* Clear all selections and refresh the chooser within a given generation \\
range (Note the range is specified in the same manner as that of the built in \
\\
Range[] function in Mathematica) 
  *)
clearAllAndUpdate[genNumRange__] :=
  (clearAndUpdate @@ Prepend[refreshParms[ #1[[1]] ], #1[[2]]  ]) & /@
    Sort[getAllSelection[genNumRange]]
(*
Chooser
*)
(*
chooser
 Inputs
    nbObj:\t\tNotebook in which to insert the chooser
    choices:\t\tflattened list of graphics that one wishes to choose from
    generation:  \t\tgeneration number of choices

Global Vars
    chooserSelection[generation]:\tList of integers representing the choices \
\\
made by the user.
    updateParms[generation]:\tList of parameters needed to refresh the \
chooser \\
for a given generation
    
Returns\t N/A
*)
chooser[nbObj_NotebookObject, choices_List, generation_Integer, opts___] := 
  Module[
    {imgSize, buttonsPerRow, numRows, partitionedChoices, bracketSize, 
      numColumnsList = {}, backgroundColorOpt},
    
    imgSize = choiceImageSize /. {opts} /. Options[chooser];
    buttonsPerRow = choicesPerRow /. {opts} /. Options[chooser];
    backgroundColorOpt = backgroundColor /. {opts} /. Options[chooser];
    numRows = Ceiling[Length@choices / buttonsPerRow];
    bracketSize = {imgSize[[1]], 10};
    
    (* Partition and pad choices into rows of length buttonsPerRow *)
    partitionedChoices = Partition[Join[choices, Table[Null,
            {Mod[buttonsPerRow - Mod[Length@choices, buttonsPerRow], 
                buttonsPerRow]} 
            ] ], buttonsPerRow];
    
    (* Reset global var chooserSelection[generation] *)
    chooserSelection[generation] = {};
    
    For[r = 0, r < numRows, r++,
      Module[
        {firstNum = r*buttonsPerRow + 1, numColumns, firstNumList},
        
        numColumns = If[(firstNum + buttonsPerRow - 1) > Length@choices,
            Length@choices - firstNum + 1,
            buttonsPerRow];
        
        (* Create above brackets (True) *)
        NotebookWrite[nbObj, 
          highlight[chooserSelection[generation], generation, firstNum, 
            numColumns, True, bracketSize, opts] ];  
        
        (* Display choice buttons *)
        NotebookWrite[nbObj,
          choiceBTRow[
            choiceGraphicCell[#1, imgSize] & /@ partitionedChoices[[r + 1]]
            , chooserSelection[generation], generation, firstNum, \
bracketSize,
             opts] ];
        
        (* Create below brackets (False) *)
        NotebookWrite[nbObj, 
          highlight[chooserSelection[generation], generation, firstNum, 
            numColumns, False, bracketSize, opts] ];  
        
        numColumnsList = Append[numColumnsList, numColumns];
        ](*Module*)
      ] ;(*For*)
    
     (* Store all the parameters needed to refresh the chooser *)
    refreshParms[generation] = {nbObj, generation, numColumnsList, 
        bracketSize, opts};
    
    ](*Module*)
Options[chooser] := {
    choiceImageSize -> {100, 100}, choicesPerRow -> 4, 
    backgroundColor -> GrayLevel[1], bracketColor -> GrayLevel[0]
    }
(*
Chooser
*)
(*
The chooser can be made more general purpose by using a unique chooser ID to \
\\
reference all global vars.
This unique ID could be created by a function (eg. createChooser [ ]) in a \\
similar fashion as NotebookObjects.
*)
Begin[\"`Private`\"];
(*
Utility functions
*)
generateCellTag[genNum_Integer, firstNum_Integer, suffix_String] :=
  {ToString[genNum] <> \",\" <> ToString[firstNum] <> \",\" <> suffix}
generateSelectionIDs[firstNum_Integer, numColumns_Integer] :=
  ((firstNum - 1) + Range[numColumns])
nonNullLength[list_List] := Length@Select[list, (#1 =!= Null) &]
(* Inserts a specified graphic in a Cell *)
choiceGraphicCell[graphic_, imgSize_List] := Module[{gdata},
    If[graphic === Null,
      Null,
      gdata = GraphicsData[\"PostScript\",
          DisplayString@Append[
              
              Graphics@
                Show[graphic, DisplayFunction -> Identity], {AspectRatio -> 
                  Automatic, PlotRange -> {{0, 1}, {0, 1}}, 
                ImageSize -> imgSize}
              ]];
       Cell[gdata, \"Graphics\",
        CellFrame -> False, CellFrameMargins -> {{0, 0}, {0, 0}},
        ImageMargins -> {{0, 0}, {0, 0}}, CellMargins -> {{0, 0}, {0, 0}}
        ]
      ](*If*)
    ]
(*
Bracket Graphics
*)
(*bracketWidth = 100; bracketHieght = 10;*)
(* List of polygon vertices that define the outline of the lower bracket \\
graphic.
      Note that these points can be converted into the upper bracket graphic \
\\
by multiplying this list by {1, -1}
  *)
lowerBracketPrimitive[bracketWidth_, 
    bracketHieght_] := {{0, bracketWidth}, {0, 0}, {bracketWidth, 
      0}, {bracketWidth, bracketWidth},
    {bracketWidth - bracketWidth/10, bracketWidth/5}, {bracketWidth/10, 
      bracketWidth/5}, {0, bracketWidth}}
bracketGraphic[label_, color_, isUpper_, textColor_, bracketWidth_, 
      bracketHieght_] :=
    Module[{isUpperSign},
      isUpperSign = If[isUpper, {1, -1}, {1, 1}];
      GraphicsData[\"PostScript\", DisplayString[Graphics[
            Show[Graphics[{
                  color,
                  
                  Polygon[(isUpperSign*#1) & /@ 
                      lowerBracketPrimitive[bracketWidth, bracketHieght]],
                  textColor,
                  
                  Text[label, {bracketWidth, bracketWidth + \
bracketWidth/5}/2*
                      isUpperSign]
                  }],
              
              PlotRange -> {{0, 
                    bracketWidth}, {bracketWidth/10, bracketWidth}*
                    isUpperSign},
              DisplayFunction -> Identity,
              AspectRatio -> bracketHieght/bracketWidth,
              ImageSize -> {bracketWidth, bracketHieght}]
            ]]]
      ];
selectionBracket[label_, color_, isUpper_, opts___] :=
  Module[{textColorOpt, bracketWidth, bracketHieght},
    textColorOpt = textColor /. {opts} /. Options[selectionBracket];
    bracketWidth = (bracketSize /. {opts} /. Options[selectionBracket])[[1]];
    bracketHieght = (bracketSize /. {opts} /. 
            Options[selectionBracket])[[2]];
    
    Cell[
      bracketGraphic[label, color, isUpper, textColorOpt, bracketWidth, 
        bracketHieght], \"Graphics\",
      CellFrame -> False, CellFrameMargins -> {{0, 0}, {0, 0}},
      ImageMargins -> {{0, 0}, {0, 0}}, 
      ImageSize -> {bracketWidth, bracketHieght},
      CellMargins -> {{0, 0}, {0, 0}}
      ]
    ]
Options[selectionBracket] = {
      textColor -> GrayLevel[0], bracketSize -> {100, 10}
      };
(*
Cell[BoxData[
      RowBox[selectionBracket[#1, GrayLevel[0], True, textColor -> Hue[0.5], 
              bracketSize -> {50, 10}] & /@ Range[1, 3]]],
    CellMargins -> {{0, 0}, {0, 0}}, CellFrameMargins -> {{0, 0}, {0, 0}}, 
    ImageMargins -> {{0, 0}, {0, 0}}] // CellPrint
*)
(*
\\!\\(\\*
  RowBox[{GraphicsData[\"PostScript\", \"\\<\\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
%%ImageSize: 50 10 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.02 0.181818 0.00363636 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 g
0 0 m
0 .18182 L
1 .18182 L
1 0 L
.9 .14545 L
.1 .14545 L
0 0 L
F
0 1 1 r
[(1)] .5 .07273 0 0 Mshowa
% End of Graphics
MathPictureEnd
\\
\\>\"], GraphicsData[\"PostScript\", \"\\<\\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
%%ImageSize: 50 10 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.02 0.181818 0.00363636 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 g
0 0 m
0 .18182 L
1 .18182 L
1 0 L
.9 .14545 L
.1 .14545 L
0 0 L
F
0 1 1 r
[(2)] .5 .07273 0 0 Mshowa
% End of Graphics
MathPictureEnd
\\
\\>\"], GraphicsData[\"PostScript\", \"\\<\\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
%%ImageSize: 50 10 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.02 0.181818 0.00363636 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 g
0 0 m
0 .18182 L
1 .18182 L
1 0 L
.9 .14545 L
.1 .14545 L
0 0 L
F
0 1 1 r
[(3)] .5 .07273 0 0 Mshowa
% End of Graphics
MathPictureEnd
\\
\\>\"]}]\\)
*)
(*
Highlight Bracket
*)
(*
 Inputs
    theSelection:  \tlist of selected choices
    genNum:  \t\tgeneration number of choices
    firstNum:  \t\tnumber of the first choice in the row
    numColumns:  \tnumber of columns in the row
    isUpper:  \t\tTrue if this is to be an upper bracket, and False for lower \
\\
bracket
    highlightSize: \t{width, hieght} of highlight bracket
    
Returns\t a cell containing an upper/lower bracket to highlight a graphic \\
cell.
*)
highlight[theSelection_List, genNum_Integer, firstNum_Integer,
    numColumns_Integer, isUpper_, highlightSize_List, opts___] :=
  
  Module[{backgroundColorOpt, bracketColorOpt},
    backgroundColorOpt = backgroundColor /. {opts} /. Options[highlight];
    bracketColorOpt = bracketColor /. {opts} /. Options[highlight];
    
    Cell[BoxData[RowBox[
          selectionBracket[#1,
                
                If[MemberQ[theSelection, #1], bracketColorOpt, 
                  backgroundColorOpt],
                isUpper, 
                textColor -> If[isUpper, backgroundColorOpt, \
bracketColorOpt],
                 bracketSize -> highlightSize
                ] & /@ generateSelectionIDs[firstNum, numColumns]
          ]],
      CellTags -> 
        generateCellTag[genNum, firstNum, 
          If[isUpper, \"highlightAboveCell\", \"highlightBelowCell\"]], 
      CellMargins -> {{0, 0}, If[isUpper, {-5, 0}, {0, -5}]}, 
      CellFrameMargins -> {{0, 0}, {0, 0}}]
    ]
Options[highlight] := {
    backgroundColor -> GrayLevel[1], bracketColor -> GrayLevel[0], 
    textColorSelected -> {GrayLevel[0], GrayLevel[0]}, (*{above, below}*)
    textColorUnselected -> {GrayLevel[1], GrayLevel[1]}  (*{above, below}*)
    }
(*
Update, Clear and Refresh Brackets
*)
updateHighlight[nbObj_NotebookObject, genNum_Integer, firstNum_Integer, 
    numColumns_Integer, highlightSize_List, isUpper_, opts___] := 
  Module[{cellStrSuffix},
    cellStrSuffix = If[isUpper, \"highlightAboveCell\", \
\"highlightBelowCell\"];
    If[
      NotebookFind[nbObj, generateCellTag[genNum, firstNum, cellStrSuffix],
          Previous, CellTags, AutoScroll -> False] =!= $Failed,
      NotebookWrite[nbObj, 
          highlight[chooserSelection[genNum], genNum, firstNum, numColumns, 
            isUpper, highlightSize, opts], AutoScroll -> False];
      ]
    ](*Module*)
(* Refresh chooser highlights for a certain generation *)
refreshHighlights[nbObj_NotebookObject, genNum_Integer, numColumns_List, 
    highlightSize_List, opts___] :=
  Module[{buttonsPerRow, numRows},
    buttonsPerRow = numColumns[[1]];
    numRows = Length@numColumns;
    MapThread[(
          updateHighlight[nbObj, genNum, #1, #2, highlightSize, True, opts];
          updateHighlight[nbObj, genNum, #1, #2, highlightSize, False, opts];
          ) &,
      {((#1*buttonsPerRow + 1) & /@ Range[0, numRows - 1]),
        numColumns}
      ];
    ]
(*
Choice Button
*)
(*
choiceBT
 Inputs
    content:\t\tbutton label (can be a graphic cell)
    id:\t\t\tid to refer to this choice
    genNum:  \t\tgeneration number of choices
    firstNum:  \t\tnumber of the first choice in the row
    numColumns:  \tnumber of columns in the row
    highlightSize: \t{width, hieght} of highlight bracket
    
Returns\t a ButtonBox that represents a particular choice.  By clicking on \\
this button one can add & remove the choice 
\t\tfrom the global chooserSelection list, and toggle the highlight brackets \
\\
which indicate to the user that the choice has
\t\tbeen selected.
*)
choiceBT[content_, id_, genNum_Integer,
    firstNum_Integer, numColumns_Integer, highlightSize_List, opts___] :=
  
  If[content === Null,
    \"\"
    ,
    ButtonBox[content,
      Active -> True, ButtonEvaluator -> Automatic,
      Background -> GrayLevel[0.5], ButtonFrame -> None,
      ButtonMargins -> 0, ButtonMinHeight -> 0,
      ButtonFunction :> (
          (* Add or Remove selection from global selection list *)
          
          chooserSelection[genNum] = 
            If[MemberQ[chooserSelection[genNum], id],
              Select[chooserSelection[genNum], (#1 =!= id) &],
              Join[chooserSelection[genNum], {id}]
              ];
          
          (* Update selection brackets *)
          
          updateHighlight[ButtonNotebook[], genNum, firstNum, numColumns, 
            highlightSize, True, opts];
          
          updateHighlight[ButtonNotebook[], genNum, firstNum, numColumns, 
            highlightSize, False, opts];
          )
      ](*ButtonBox*)
    ](*If*)
(*
choiceBTRow
 Inputs
    choiceGraphics:\tList of graphic cell button labels that represent the \\
choices
    theSelection:\tList of selected choices
    genNum:  \t\tgeneration number of choices
    firstNum:  \t\tnumber of the first choice in the row
    highlightSize: \t{width, hieght} of highlight bracket
    
Returns\t a cell containing a row of  choice buttons
*)
choiceBTRow[choiceGraphics_List, theSelection_List, genNum_Integer,
    firstNum_Integer, highlightSize_List, opts___] := 
  
  Cell[BoxData[RowBox[
        MapThread[
          
          choiceBT[#1, #2, genNum, firstNum, nonNullLength@choiceGraphics, 
              highlightSize, opts] &
          , {choiceGraphics, 
            generateSelectionIDs[firstNum, Length@choiceGraphics]}
          ]
        ]
      ], CellTags -> generateCellTag[genNum, firstNum, \"Chooser\"], 
    CellFrameMargins -> {{0, 0}, {0, 0}}, CellMargins -> {{0, 0}, {0, 0}}]
(*
End[ ] and EndPackage[ ]
*)
End[];
EndPackage[];
\
\>", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Biomorph Model", "Subsection",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[TextData[{
  StyleBox["Data Structure",
    FontSize->15,
    FontWeight->"Bold"],
  "\n",
  StyleBox["Biomorph Tree",
    FontWeight->"Bold"],
  "\nheadNode = { {ancestors}, {initial Individual} }\npopNode = { {indiv1}, \
{indiv2}, ..., {indivN} }\nindividual = {{biomorph chromosome}, PopNode}\n"
}], "Text",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell["\<\
Biomorph Tree Field Constants
   (headAncestorsF, headPopF, chromosomeF, popNodeF )\
\>", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \( (*\ 
      Field\ access\ constants\ *) \[IndentingNewLine] (*\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(----\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\
\[IndentingNewLine] (*Biomorph\ tree\ head\ node\ list*) \
\[IndentingNewLine]\(headAncestorsF\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(headPopNodesF\  = \ 2;\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Individual\ in\ pop\ node\ *) \), "\[IndentingNewLine]", 
    \(\(parentF\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(childrenF\  = \ 2;\)\), "\[IndentingNewLine]", 
    \(\(\(popNodesF\  = \ 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(latestAddition\  = \  . ;\)\)}], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["getNumGens[ bioTreeHead_List ]", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getNumGens[bioTreeHead_List]\  := \ 
      Count[bioTreeHead[\([headAncestorsF]\)], \ _Integer]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["getCurNode[ bioTreeHead_List, <gen_Integer> ]", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurNode[popNode_List, \ {}]\  := \ popNode\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurNode[popNode_List, \ ancestors_List]\  := \ \[IndentingNewLine]If[
        Count[\ popNode[\([popNodesF]\)], \ _List] < \ 
          ancestors[\([1]\)]\ \[IndentingNewLine], \[IndentingNewLine]Print["\
\<ERROR: Inconsistent ancestor list:  \>", \ 
          ancestors]\[IndentingNewLine], \[IndentingNewLine]getCurNode[\ \
\(popNode[\([popNodesF]\)]\)[\([\ ancestors[\([1]\)]\ ]\)]\ , \ 
          Drop[ancestors, 1]\ ]\[IndentingNewLine]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurNode[bioTreeHead_List]\  := \ \[IndentingNewLine]getCurNode[\ 
        bioTreeHead[\([headPopNodesF]\)], \ 
        Drop[bioTreeHead[\([headAncestorsF]\)], 1]\ ]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Gets\ a\ specific\ generation\ by\ calling\ getCurChildren[\ ]\ with\ a\
\ reduced\ ancestor\ list\ *) \)\(\[IndentingNewLine]\)\(getCurNode[
        bioTreeHead_List, \ gen_Integer]\  := \ 
      Module[\[IndentingNewLine]{reducedBioTree}, \
\[IndentingNewLine]If[\((getNumGens[bioTreeHead] < \ 
                gen)\)\  || \ \((gen\  \[LessEqual] \ 
                0)\), \[IndentingNewLine]Print["\<getCurNode[ ]: ERROR: \
Specified generation does not exist in ancestor list\>"]\[IndentingNewLine], \
\[IndentingNewLine]reducedBioTree\  = \ 
            ReplacePart[bioTreeHead, \ 
              Take[bioTreeHead[\([headAncestorsF]\)], \ gen], \ 
              headAncestorsF]; \[IndentingNewLine]getCurNode[
            reducedBioTree]\[IndentingNewLine]]\[IndentingNewLine]]\)\)\)], \
"Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurChildren[bioTreeHead_List, \ 
        gen_Integer]\  := \ \(getCurNode[bioTreeHead, \ 
          gen]\)[\([childrenF]\)]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurChildren[
        bioTreeHead_List]\  := \ \(getCurNode[
          bioTreeHead]\)[\([childrenF]\)]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurParent[bioTreeHead_List, \ 
        gen_Integer]\  := \ \(getCurNode[bioTreeHead, \ 
          gen]\)[\([parentF]\)]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurParent[
        bioTreeHead_List]\  := \ \(getCurNode[
          bioTreeHead]\)[\([parentF]\)]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
selectionsToBiomorphs [ bioTreeHead_List, bioSelections_List \
]\
\>", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Extracts\ biomorphs\ from\ within\ a\ particular\ generation\ *) \)\(\
\[IndentingNewLine]\)\(selectionsToBiomorphs[bioTreeHead_List, gen_Integer, 
        bioSelectionsWithinGen_List] := \[IndentingNewLine]Extract[
        getCurChildren[bioTreeHead, gen], 
        Partition[bioSelectionsWithinGen, 1]]\)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Extracts\ biomorphs\ from\ within\ a\ bioSelections . \
\[IndentingNewLine]bioSelections\ have\ the\ \(form : \ {\ {genNum, {a, b, 
                c,  ... }}, \  ... }\ \[IndentingNewLine]
        where\ a\), 
      b, \(c\ are\ selections\ within\ a\ generation\)\[IndentingNewLine]and\ \
genNum\ is\ the\ generation\ number\[IndentingNewLine]*) \)\(\
\[IndentingNewLine]\)\(selectionsToBiomorphs[bioTreeHead_List, 
        bioSelections_List] := \[IndentingNewLine]Flatten[\[IndentingNewLine]\
\(selectionsToBiomorphs[bioTreeHead, Sequence @@ #1] &\) /@ 
          bioSelections, \[IndentingNewLine]1]\)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
newBioTree[ initBio ], 
newPopNode[ parentBio ], 
insertBioNode[ destNode_List, newNode_List ],
replacePopNode[destNode_List, newNode_List, position_Integer]\
\>", \
"Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell["\<\
Input:  Biomorph chromosome,
Returns:  Head node for biomorph tree
{ 
   {path list},
   {{initial Biomorph chromosome}, {population spawned from initial \
biomorph}, {No next popNode}} 
}\
\>", "Text",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(newBioTree[initial_List]\  := \ {\ \ \ {1}, 
        newPopNode[initial]\ \ \ }\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(newPopNode[parent_List]\  := \ 
      With[\[IndentingNewLine]{numChildren\  = \ 15}, \[IndentingNewLine]{\ 
          parent, Table[
            PointMutation[parent, i], {i, 1, 
              numChildren}], {}\ }\[IndentingNewLine]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell["\<\
insertBioNode[ ]
Input:  1. New popNode
\t2. Destination popNode
\t3. Destination index into popNode
Returns: popNode containing the newly inserted popNode\
\>", "Text",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(insertBioNode[\ destNode_List, \ 
        newNode_List]\  := \ \[IndentingNewLine]\ {destNode[\([parentF]\)], \ \
\[IndentingNewLine]destNode[\([childrenF]\)], \ \[IndentingNewLine]Append[\ 
          destNode[\([popNodesF]\)], \ newNode\ ]}\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(replacePopNode[destNode_List, \ newNode_List, \ 
        position_Integer]\  := \[IndentingNewLine]{destNode[\([parentF]\)], \ \
\[IndentingNewLine]destNode[\([childrenF]\)], \[IndentingNewLine]ReplacePart[\
\ destNode[\([popNodesF]\)], \ newNode, position]}\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["createNewGen[bioTreeHead_List, newPopNode_List]", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Clear[createNewGen]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(createNewGen[popNode_List, \ {}, \ newNode_List]\  := \ 
      Module[\[IndentingNewLine]{updatedPopNode}, \[IndentingNewLine]\
\[IndentingNewLine]updatedPopNode\  = \ 
          insertBioNode[popNode, \ 
            newNode]; \[IndentingNewLine]latestAddition\  = \ 
          Count[updatedPopNode[\([popNodesF]\)], \ _List]; \
\[IndentingNewLine]updatedPopNode\[IndentingNewLine]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(createNewGen[popNode_List, \ ancestors_List, \ newNode_List]\  := \ 
      Module[\[IndentingNewLine]{updatedPopNode}, \[IndentingNewLine]If[
          Count[\ popNode[\([popNodesF]\)], \ _List] < \ 
            ancestors[\([1]\)]\ \[IndentingNewLine], \
\[IndentingNewLine]Print["\<ERROR: Inconsistent ancestor list:  \>", \ 
            ancestors]\[IndentingNewLine], \[IndentingNewLine]updatedPopNode\ \
 = \ createNewGen[\[IndentingNewLine]\(popNode[\([popNodesF]\)]\)\ \ [\([\ \ \
ancestors[\([1]\)]\ \ ]\)], \ \[IndentingNewLine]Drop[ancestors, \ 
                1], \ \[IndentingNewLine]newNode\[IndentingNewLine]]; \
\[IndentingNewLine]replacePopNode[\ \ popNode, \ updatedPopNode, 
            ancestors[\([1]\)]\ ]\[IndentingNewLine]]\[IndentingNewLine]]\)], \
"Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell["\<\
createNewGen[ ]
Input:  1. Biomorph tree containing history of biomorphs,
\t2. Choosen individual from current population (pointed to by the first list \
in the head node in the biomorph tree) to be the parent for the next \
generation,
Returns:  Biomorph tree with new generation added.\
\>", "Text",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(createNewGen[bioTreeHead_List, \ newPopNode_List]\  := \ 
      Module[\[IndentingNewLine]{updatedPopNode, \ 
          returnVal}, \[IndentingNewLine]\[IndentingNewLine]latestAddition\  \
= \  . ; \[IndentingNewLine]updatedPopNode\  = \ 
          createNewGen[
            bioTreeHead[\([headPopNodesF]\)], \[IndentingNewLine]Drop[
              bioTreeHead[\([headAncestorsF]\)], 1], \ 
            newPopNode]; \[IndentingNewLine]\[IndentingNewLine]returnVal\  = \
\ {Append[bioTreeHead[\([headAncestorsF]\)], \ latestAddition], \ 
            updatedPopNode}; \[IndentingNewLine]\[IndentingNewLine]refreshAll[
          returnVal]; \[IndentingNewLine]\[IndentingNewLine]returnVal\
\[IndentingNewLine]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(Following is not used anymore)
parentSelection
toggleParentSelection[selection_List, buttonNum_Integer]\
\>", "Subsubsection",\

  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(parentSelections\  = \ {};\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Add\ or\ remove\ a\ parent\ from\ the\ parentSelection\ list\ depending\
\ on\ whether\ the\ parent\ is\ already\ in\ the\ list\ or\ not\
\[IndentingNewLine]Input\ \ \ 1. \ parent\ selection\ list\[IndentingNewLine]\
\t\t2. \ button\ number\ corresponding\ to\ selected\ parent\
\[IndentingNewLine]Returns\ updated\ parent\ selection\ list\
\[IndentingNewLine]*) \)\(\[IndentingNewLine]\)\(toggleParentSelection[
        bioSelection_List, \ buttonNum_Integer]\  := \ \[IndentingNewLine]If[
        MemberQ[bioSelection, \ buttonNum]\[IndentingNewLine], 
        Select[bioSelection, \ \((#1 \[NotEqual] \ 
                buttonNum)\) &]\[IndentingNewLine], 
        Append[bioSelection, \ buttonNum]\[IndentingNewLine]]\)\)\)], "Input",\

  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Test", "Subsubsection",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({{}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
          9}, {{{1, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 
              6, 9}, {}}, {{2, 6, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 
              5, 10, 4, 6, 9}, {}}, {{2, 1, 1, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 
              4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 6, 5, 5, 2, 8, 4, 9, 
              5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 6, 5, 2, 
              8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 
              5, 4, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 
              1, 10, 7, 5, 5, 1, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
              9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 9, 4, 9, 5, 2, 7, 4, 6, 3, 5, 
              10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 3, 9, 5, 2, 7, 4, 
              6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 10, 
              5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 
              8, 4, 9, 4, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 
              5, 5, 2, 8, 4, 9, 5, 3, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 
              1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 6, 4, 6, 3, 5, 10, 4, 6, 
              9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 5, 6, 3, 5, 
              10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 
              7, 3, 5, 10, 4, 6, 9}, {}}}}}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell[BoxData[
    \(bioModel\  = createNewGen[bioModel, 2]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({{2}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
          9}, {{{1, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 
              6, 9}, {}}, {{2, 6, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 
              5, 10, 4, 6, 
              9}, {{{3, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 
                  4, 6, 9}, {}}, {{2, 5, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 
                  6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 1, 7, 5, 5, 2, 8, 4, 9, 
                  5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 8, 5, 
                  5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 
                  1, 10, 7, 4, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
                  9}, {}}, {{2, 1, 10, 7, 5, 6, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 
                  5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 1, 8, 4, 9, 5, 
                  2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 
                  2, 9, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 
                  10, 7, 5, 5, 2, 8, 5, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
                  9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 10, 5, 2, 7, 4, 6, 
                  3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 
                  4, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 
                  5, 2, 8, 4, 9, 5, 1, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 
                  1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 8, 4, 6, 3, 5, 10, 4, 6, 
                  9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 2, 7, 3, 6, 3, 
                  5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 
                  2, 7, 4, 5, 3, 5, 10, 4, 6, 9}, {}}}}, {{2, 1, 1, 7, 5, 5, 
              2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 
              6, 5, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
              9}, {}}, {{2, 1, 10, 7, 6, 5, 2, 8, 4, 9, 5, 2, 7, 4, 6, 3, 5, 
              10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 4, 2, 8, 4, 9, 5, 2, 7, 4, 
              6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 1, 8, 4, 9, 5, 
              2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 9, 
              4, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 
              5, 2, 8, 3, 9, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 
              10, 7, 5, 5, 2, 8, 4, 10, 5, 2, 7, 4, 6, 3, 5, 10, 4, 6, 
              9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 4, 2, 7, 4, 6, 3, 5, 
              10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 3, 7, 4, 
              6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 4, 9, 5, 
              2, 6, 4, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 5, 2, 8, 
              4, 9, 5, 2, 7, 5, 6, 3, 5, 10, 4, 6, 9}, {}}, {{2, 1, 10, 7, 5, 
              5, 2, 8, 4, 9, 5, 2, 7, 4, 7, 3, 5, 10, 4, 6, 
              9}, {}}}}}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[BoxData[
    \(bioModel\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell[BoxData[
    \(getNumGens[bioModel]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getNumGens[bioModel]\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(getCurChildren[bioModel, 4]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \("getCurNode[ ]: ERROR: Specified generation does not exist in ancestor \
list"\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(getCurNode[bioModel]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({{{5, 1, 2, 1, 6, 5, 1, 7, 7, 2, 3, 5, 3, 6, 10, 2, 5, 1, 8, 4, 
          10}, {}}, {{1, 2, 2, 1, 6, 5, 1, 7, 7, 2, 3, 5, 3, 6, 10, 2, 5, 1, 
          8, 4, 10}, {}}, {{1, 1, 1, 1, 6, 5, 1, 7, 7, 2, 3, 5, 3, 6, 10, 2, 
          5, 1, 8, 4, 10}, {}}, {{1, 1, 2, 2, 6, 5, 1, 7, 7, 2, 3, 5, 3, 6, 
          10, 2, 5, 1, 8, 4, 10}, {}}, {{1, 1, 2, 1, 5, 5, 1, 7, 7, 2, 3, 5, 
          3, 6, 10, 2, 5, 1, 8, 4, 10}, {}}}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(getCurParent[bioModel, 2]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({2, 2, 7, 2, 7, 5, 1, 3, 4, 6, 2, 3, 5, 2, 8, 1, 1, 3, 3, 5, 
      3}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Test2", "Subsubsection",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell[BoxData[
    \(btest\  = \ newBioTree[randomBiomorphParams[]]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({{1}, {{4, 3, 2, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 8, 8, 
          8}, {{1, 3, 2, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 8, 8, 
            8}, {4, 4, 2, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 8, 
            8, 8}, {4, 3, 3, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 
            8, 8, 8}, {4, 3, 2, 11, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 
            10, 8, 8, 8}, {4, 3, 2, 1, 3, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 
            1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 1, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 
            1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 1, 9, 9, 5, 2, 3, 2, 6, 1, 
            8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 8, 9, 5, 2, 3, 2, 6, 
            1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 10, 5, 2, 3, 2, 
            6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 6, 2, 3, 
            2, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 5, 3, 
            3, 2, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 5, 
            2, 4, 2, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 
            5, 2, 3, 1, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 
            9, 5, 2, 3, 2, 5, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 
            9, 9, 5, 2, 3, 2, 6, 11, 8, 1, 10, 8, 8, 8}}, {}}}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(popNodeTest\  = \ newPopNode[randomBiomorphParams[]]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({{2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
        9}, {{3, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 3, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 4, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 7, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 11, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 10, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 1, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 7, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 1, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 11, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 3, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 1, 2, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 1, 7, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 8, 1, 10, 4, 6, 5, 8, 
          9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 2, 10, 4, 6, 5, 8, 
          9}}, {}}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(btest\  = \ createNewGen[btest, \ popNodeTest]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({{1, 
        1}, {{4, 3, 2, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 8, 8, 
          8}, {{1, 3, 2, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 8, 8, 
            8}, {4, 4, 2, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 8, 
            8, 8}, {4, 3, 3, 1, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 10, 
            8, 8, 8}, {4, 3, 2, 11, 4, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 1, 
            10, 8, 8, 8}, {4, 3, 2, 1, 3, 10, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 
            1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 1, 5, 9, 9, 5, 2, 3, 2, 6, 1, 8, 
            1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 1, 9, 9, 5, 2, 3, 2, 6, 1, 
            8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 8, 9, 5, 2, 3, 2, 6, 
            1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 10, 5, 2, 3, 2, 
            6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 6, 2, 3, 
            2, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 5, 3, 
            3, 2, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 5, 
            2, 4, 2, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 9, 
            5, 2, 3, 1, 6, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 9, 
            9, 5, 2, 3, 2, 5, 1, 8, 1, 10, 8, 8, 8}, {4, 3, 2, 1, 4, 10, 5, 
            9, 9, 5, 2, 3, 2, 6, 11, 8, 1, 10, 8, 8, 
            8}}, {{{2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 
              8, 9}, {{3, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 
                5, 8, 9}, {2, 3, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 
                4, 6, 5, 8, 9}, {2, 2, 4, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 
                10, 4, 6, 5, 8, 9}, {2, 2, 5, 7, 1, 9, 2, 8, 2, 1, 2, 5, 2, 
                7, 1, 10, 4, 6, 5, 8, 9}, {2, 2, 5, 8, 11, 9, 2, 8, 2, 1, 2, 
                5, 2, 7, 1, 10, 4, 6, 5, 8, 9}, {2, 2, 5, 8, 1, 10, 2, 8, 2, 
                1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 9}, {2, 2, 5, 8, 1, 9, 1, 
                8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 9}, {2, 2, 5, 8, 1, 
                9, 2, 7, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 9}, {2, 2, 5, 
                8, 1, 9, 2, 8, 1, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 9}, {2, 
                2, 5, 8, 1, 9, 2, 8, 2, 11, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
                9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 3, 5, 2, 7, 1, 10, 4, 6, 
                5, 8, 9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 1, 2, 7, 1, 10, 
                4, 6, 5, 8, 9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 1, 7, 1, 
                10, 4, 6, 5, 8, 9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 
                8, 1, 10, 4, 6, 5, 8, 9}, {2, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 
                5, 2, 7, 2, 10, 4, 6, 5, 8, 9}}, {}}}}}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(recombine[\ getCurChildren[btest], \ {1, 2}]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \({3, 2, 5, 8, 1, 9, 2, 8, 2, 1, 2, 5, 2, 7, 1, 10, 4, 6, 5, 8, 
      9}\)], "Output",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Open  ]],

Cell[BoxData[
    \(getCurNode[btest, 2]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(getCurChildren[btest]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell["Packages and JLink", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Get["\<RealTime3D`\>"]\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(<< Graphics`Shapes`\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \( (*Get["\<C:\spr2000\chooser\chooser.m\>"]*) \)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(IsLinux[] := $PathnameSeparator === "\</\>"\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotation matrices", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(\(yawMatrix[
          a_] := {{Cos[a], Sin[a], 0}, {\(-Sin[a]\), Cos[a], 0}, {0, 0, 
            1}};\)\), "\n", 
    \(\(pitchMatrix[
          a_] := {{Cos[a], 0, \(-Sin[a]\)}, {0, 1, 0}, {Sin[a], 0, 
            Cos[a]}};\)\), "\n", 
    \(\(rollMatrix[
          a_] := {{1, 0, 0}, {0, Cos[a], \(-Sin[a]\)}, {0, Sin[a], 
            Cos[a]}};\)\)}], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Biomorph construction, drawing, chromosome formatting", "Subsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell["randomBiomorphParams[ ]", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(randomBiomorphParams[] := 
      Flatten[Join[{Random[Integer, {1, 4}]}, 
          Table[randomSubBranchParameters[5, 10, 10, 10, 
              10], {4}]]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Drawing a biomorph", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(ClearAll[biomorph]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\[IndentingNewLine]Input : \ 
        Vector\ of\ indivuals, \[IndentingNewLine]Returns\ a\ list\ of\ \
biomorphs\ \((Graphics3D[])\)\ \
\[IndentingNewLine]*) \)\(\[IndentingNewLine]\)\(biomorph[params_?VectorQ, 
        opts___] := \ \[IndentingNewLine]biomorphSubgraph[Drop[params, 1], 
        If[\ \ params\[LeftDoubleBracket]1\[RightDoubleBracket] > 4, 4, 
          params\[LeftDoubleBracket]1\[RightDoubleBracket]\ \ ], \ 
        opts]\)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Take\ each\ row\ the\ bios\ matrix\ and\ pass\ it\ to\ biomorph[
          vector]\ *) \)\(\[IndentingNewLine]\)\(biomorph[bios_?MatrixQ, 
        opts___] := 
      Module[{}, \((biomorph[#1, opts] &)\) /@ bios]\)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Take\ each\ element\ in\ the\ bios\ list\ and\ pass\ it\ to\ biomorph[
          vector]\ *) \)\(\[IndentingNewLine]\)\(biomorph[bios_?ListQ, 
        opts___] := 
      Module[{}, 
        Show[GraphicsArray[\((biomorph[#1, opts] &)\) /@ 
              bios]]]\)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(Options[
          biomorph] = {\[IndentingNewLine]primitive \[Rule] \ 
            primLine\[IndentingNewLine]};\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Utility functions", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(yawScale[x_Integer] := Range[x] - Mean[Range[x]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Mean[l_List] := N[Plus @@ l\/Length[l]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Primitives", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(primCone[r_, h_, c_]\  := \ 
      TranslateShape[
        Graphics3D[{\[IndentingNewLine]SurfaceColor[c, c], 
            Cone[r, h/2, 7]}, \ Boxed \[Rule] False], {0, 0, h/2}]\)], "Input",\

  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell[BoxData[
    \(rr = 0.25; hh = 1; 
    live3D@Show[primCone[rr, hh, Hue@0.25], 
        primEllipsoid[rr, hh, Hue@0.75]];\)], "Input",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.63028 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.309111 1.6431 -0.0128206 1.6431 [
[ 0 0 0 0 ]
[ 1 1.63028 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.63028 L
0 1.63028 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58877 .51215 m .34481 .48406 L .34812 .50169 L p .691 .611 0 r
F P
0 g
s
.34812 .50169 m .37029 .61986 L p .45545 .57788 L .691 .611 0 r
F P
0 g
s
.58877 .51215 m .34812 .50169 L .45545 .57788 L .691 .611 0 r
F
.55576 .6675 m .55411 .64791 L p .5623 .65373 L .556 0 1 r
F P
0 g
s
.40896 .65549 m .41493 .62667 L p .4356 .62983 L .739 0 1 r
F P
0 g
s
.58877 .51215 m .37029 .61986 L .41493 .62667 L .691 .611 0 r
F
.57343 .66163 m .55576 .6675 L p .5623 .65373 L .556 0 1 r
F P
0 g
s
.41493 .62667 m .40896 .65549 L .38323 .64063 L p .886 0 1 r
F P
0 g
s
.55576 .6675 m .40896 .65549 L p .4356 .62983 L .739 0 1 r
F P
0 g
s
.57649 .65132 m .58528 .55171 L p .48238 .59699 L .691 .611 0 r
F P
0 g
s
.48238 .59699 m .41493 .62667 L .55411 .64791 L .691 .611 0 r
F
.48238 .59699 m .55411 .64791 L .57649 .65132 L F
.58528 .55171 m .58877 .51215 L p .41493 .62667 L F P
0 g
s
.54374 .52562 m .55411 .64791 L p .4356 .62983 L .739 0 1 r
F P
0 g
s
.55411 .64791 m .55576 .6675 L p .4356 .62983 L .739 0 1 r
F P
0 g
s
.40896 .65549 m .55576 .6675 L p .43607 .77072 L .735 0 1 r
F P
0 g
s
.38899 .81132 m .40397 .69443 L p .43607 .77072 L .735 0 1 r
F P
0 g
s
.40397 .69443 m .40896 .65549 L p .43607 .77072 L .735 0 1 r
F P
0 g
s
.21509 .33686 m .24882 .4549 L p .33425 .56565 L .77 .794 0 r
F P
0 g
s
.36843 .60998 m .34785 .57331 L .33425 .56565 L .77 .794 0 r
F
.34785 .57331 m .21509 .33686 L .33425 .56565 L F
.31551 .55511 m .29768 .59121 L .27737 .53363 L p .948 0 1 r
F P
0 g
s
.32858 .57475 m .35009 .60706 L .29768 .59121 L .886 0 1 r
F
.37487 .6443 m .36843 .60998 L p .30118 .52278 L .77 .794 0 r
F P
0 g
s
.30118 .52278 m .24882 .4549 L .36568 .63049 L .77 .794 0 r
F
.30118 .52278 m .36568 .63049 L .37487 .6443 L F
.29768 .59121 m .36568 .63049 L p .25608 .73704 L .902 0 1 r
F P
0 g
s
.256 .73549 m .29768 .59121 L p .25608 .73704 L .902 0 1 r
F P
0 g
s
.38753 .66697 m .25533 .73777 L .26325 .73008 L .902 0 1 r
F
.37529 .64654 m .26325 .73008 L .36568 .63049 L F
.38753 .66697 m .26325 .73008 L .37529 .64654 L F
.37029 .61986 m .37529 .64654 L p .4021 .62656 L .691 .611 0 r
F P
0 g
s
.37529 .64654 m .37487 .6443 L p .36568 .63049 L .77 .794 0 r
F P
0 g
s
.36568 .63049 m .40896 .65549 L p .38753 .66697 L .902 0 1 r
F P
0 g
s
.55576 .6675 m .55645 .68055 L p .38899 .81132 L .735 0 1 r
F P
0 g
s
.55645 .68055 m .56409 .825 L .47458 .818 L p .735 0 1 r
F P
0 g
s
.47458 .818 m .38899 .81132 L p .55645 .68055 L .735 0 1 r
F P
0 g
s
.78166 .40444 m .69065 .45526 L p .66524 .58674 L .191 .126 0 r
F P
0 g
s
.66853 .5866 m .66524 .58674 L .6638 .59421 L .191 .126 0 r
F
.78166 .40444 m .66524 .58674 L .66853 .5866 L F
.68783 .62362 m .67386 .58637 L p .6879 .58579 L .247 0 1 r
F P
0 g
s
.67386 .58637 m .68783 .62362 L .58017 .65939 L p .556 0 1 r
F P
0 g
s
.56409 .825 m .55645 .68055 L p .58139 .66974 L .521 0 1 r
F P
0 g
s
.57541 .66364 m .57546 .66306 L p .57468 .6629 L .691 .611 0 r
F P
0 g
s
.57695 .64614 m .57541 .66364 L p .69065 .45526 L .191 .126 0 r
F P
0 g
s
.69065 .45526 m .57541 .66364 L .666 .58283 L .191 .126 0 r
F
.55645 .68055 m .55576 .6675 L .57343 .66163 L p .521 0 1 r
F P
0 g
s
.57546 .66306 m .57649 .65132 L p .56102 .64896 L .691 .611 0 r
F P
0 g
s
.56102 .64896 m .57343 .66163 L .57546 .66306 L .691 .611 0 r
F
.57541 .66364 m .55645 .68055 L .57343 .66163 L .521 0 1 r
F
.55411 .64791 m .37029 .61986 L .57546 .66306 L .691 .611 0 r
F
.57343 .66163 m .58017 .65939 L p .57541 .66364 L .521 0 1 r
F P
0 g
s
.56102 .64896 m .55411 .64791 L .57343 .66163 L .691 .611 0 r
F
.58017 .65939 m .68783 .62362 L p .55645 .68055 L .521 0 1 r
F P
0 g
s
.40896 .65549 m .38899 .81132 L .25533 .73777 L p .902 0 1 r
F P
0 g
s
.37978 .9727 m .38899 .81132 L .56409 .825 L p .725 0 1 r
F P
0 g
s
.56409 .825 m .56793 .98669 L .37978 .9727 L p .725 0 1 r
F P
0 g
s
.38279 1.1265 m .37978 .9727 L .56793 .98669 L p .708 0 .849 r
F P
0 g
s
.56793 .98669 m .56668 1.13952 L .38279 1.1265 L p .708 0 .849 r
F P
0 g
s
.39877 1.25806 m .38279 1.1265 L .56668 1.13952 L p .676 0 .631 r
F P
0 g
s
.56668 1.13952 m .56002 1.26898 L .39877 1.25806 L p .676 0 .631 r
F P
0 g
s
.4273 1.35215 m .39877 1.25806 L .56002 1.26898 L p .601 0 .34 r
F P
0 g
s
.56002 1.26898 m .54811 1.36008 L .4273 1.35215 L p .601 0 .34 r
F P
0 g
s
.46643 1.39507 m .4273 1.35215 L .54811 1.36008 L p .304 0 0 r
F P
0 g
s
.54811 1.36008 m .53174 1.39929 L .46643 1.39507 L p .304 0 0 r
F P
0 g
s
.57541 .66364 m .4021 .62656 L .50852 1.35085 L .691 .611 0 r
F
.57468 .6629 m .4021 .62656 L .57541 .66364 L F
.5232 1.36518 m .52192 1.36585 L .53759 1.37833 L .516 0 1 r
F
.52192 1.36585 m .46643 1.39507 L .52339 1.38167 L F
.52192 1.36585 m .52339 1.38167 L .53759 1.37833 L F
.68783 .62362 m .62939 .71873 L .58139 .66974 L .521 0 1 r
F
.68783 .62362 m .7116 .72871 L p .56409 .825 L F P
0 g
s
.7116 .72871 m .72205 .77492 L .70164 .78139 L p .521 0 1 r
F P
0 g
s
.70164 .78139 m .56409 .825 L p .7116 .72871 L .521 0 1 r
F P
0 g
s
.68783 .62362 m .71981 .58445 L p .72072 .66244 L .169 0 1 r
F P
0 g
s
.72205 .77492 m .7116 .72871 L p .72072 .66244 L .169 0 1 r
F P
0 g
s
.7116 .72871 m .68783 .62362 L p .72072 .66244 L .169 0 1 r
F P
0 g
s
.74713 .52927 m .78166 .40444 L p .66853 .5866 L .191 .126 0 r
F P
0 g
s
.66853 .5866 m .6638 .59421 L .67386 .58637 L .191 .126 0 r
F
.66853 .5866 m .67386 .58637 L .74713 .52927 L F
.68819 .42883 m .67134 .35659 L p .73908 .49765 L 0 0 .723 r
F P
0 g
s
.77882 .24055 m .74181 .50935 L .74058 .51399 L .508 .977 0 r
F
.77882 .24055 m .74058 .51399 L .7403 .51094 L F
.74017 .50948 m .68819 .42883 L p .73908 .49765 L 0 0 .723 r
F P
0 g
s
.74713 .52927 m .687 .57613 L .73107 .5873 L .191 .126 0 r
F
.68819 .42883 m .74017 .50948 L p .71981 .58445 L .247 0 1 r
F P
0 g
s
.73383 .56727 m .71981 .58445 L p .74017 .50948 L .247 0 1 r
F P
0 g
s
.71981 .58445 m .68783 .62362 L p .6879 .58579 L .247 0 1 r
F P
0 g
s
.74987 .59207 m .72205 .77492 L .72072 .66244 L .169 0 1 r
F
.73107 .5873 m .72072 .66244 L .71981 .58445 L F
.74987 .59207 m .72072 .66244 L .73107 .5873 L F
.75404 .5043 m .73107 .5873 L p .78164 .35834 L .508 .977 0 r
F P
0 g
s
.687 .57613 m .6638 .59421 L .73107 .5873 L .191 .126 0 r
F
.56793 .98669 m .56409 .825 L .72205 .77492 L p .486 0 .984 r
F P
0 g
s
.72205 .77492 m .73788 .93543 L .56793 .98669 L p .486 0 .984 r
F P
0 g
s
.56668 1.13952 m .56793 .98669 L .73788 .93543 L p .443 0 .802 r
F P
0 g
s
.73788 .93543 m .7327 1.09184 L .56668 1.13952 L p .443 0 .802 r
F P
0 g
s
.56002 1.26898 m .56668 1.13952 L .7327 1.09184 L p .38 0 .552 r
F P
0 g
s
.73107 .5873 m .6638 .59421 L .52034 1.34897 L .191 .126 0 r
F
.78164 .35834 m .73107 .5873 L .74181 .50935 L .508 .977 0 r
F
.71981 .58445 m .75818 .53743 L p .74987 .59207 L .169 0 1 r
F P
0 g
s
.73107 .5873 m .52034 1.34897 L p .74181 .50935 L .508 .977 0 r
F P
0 g
s
.69065 .45526 m .58877 .51215 L .57695 .64614 L p .191 .126 0 r
F P
0 g
s
.68819 .42883 m .71981 .58445 L .6879 .58579 L .247 0 1 r
F
.67134 .35659 m .73331 .43476 L p .73908 .49765 L 0 0 .723 r
F P
0 g
s
.73337 .43545 m .73902 .5199 L .52034 1.34897 L .508 .977 0 r
F
.59447 .31927 m .67134 .35659 L .68819 .42883 L p .137 0 1 r
F P
0 g
s
.67134 .35659 m .59447 .31927 L .55297 .29219 L p 0 0 .778 r
F P
0 g
s
.55297 .29219 m .59147 .30428 L .67134 .35659 L p 0 0 .778 r
F P
0 g
s
.56777 .11801 m .78156 .2288 L .73331 .43476 L p .883 1 0 r
F P
0 g
s
.52034 1.34897 m .6638 .59421 L .51774 1.3501 L .191 .126 0 r
F
.54437 1.35403 m .51474 1.3514 L .54437 1.35403 L .516 0 1 r
F
.54931 1.33635 m .52484 1.34701 L .54437 1.35403 L F
.52484 1.34701 m .51474 1.3514 L .54437 1.35403 L F
.51474 1.3514 m .57541 .66364 L p .50852 1.35085 L .691 .611 0 r
F P
0 g
s
.62939 .71873 m .56409 .825 L .58139 .66974 L .521 0 1 r
F
.57541 .66364 m .51474 1.3514 L p .666 .58283 L .191 .126 0 r
F P
0 g
s
.51474 1.3514 m .46643 1.39507 L .54437 1.35403 L .516 0 1 r
F
.51474 1.3514 m .51244 1.37753 L p .51774 1.3501 L .191 .126 0 r
F P
0 g
s
.666 .58283 m .51474 1.3514 L .51774 1.3501 L .191 .126 0 r
F
.50898 1.35089 m .50397 1.35609 L .51474 1.3514 L .516 0 1 r
F
.50397 1.35609 m .46643 1.39507 L .51474 1.3514 L F
.63873 .49275 m .68819 .42883 L p .6879 .58579 L .247 0 1 r
F P
0 g
s
.67386 .58637 m .63873 .49275 L p .6879 .58579 L .247 0 1 r
F P
0 g
s
.63873 .49275 m .67386 .58637 L p .57343 .66163 L .556 0 1 r
F P
0 g
s
.58017 .65939 m .57343 .66163 L p .67386 .58637 L .556 0 1 r
F P
0 g
s
.63873 .49275 m .57343 .66163 L .5623 .65373 L .556 0 1 r
F
.54374 .52562 m .63873 .49275 L p .5623 .65373 L F P
0 g
s
.55411 .64791 m .54374 .52562 L p .5623 .65373 L .556 0 1 r
F P
0 g
s
.54374 .52562 m .52895 .40931 L .57878 .39149 L p .591 0 1 r
F P
0 g
s
.57878 .39149 m .63873 .49275 L .54374 .52562 L p .591 0 1 r
F P
0 g
s
.52895 .40931 m .47308 .40441 L p .59447 .31927 L .62 0 1 r
F P
0 g
s
.57878 .39149 m .52895 .40931 L p .59447 .31927 L .62 0 1 r
F P
0 g
s
.47308 .40441 m .43167 .37851 L p .59447 .31927 L .62 0 1 r
F P
0 g
s
.59447 .31927 m .60401 .35728 L .57878 .39149 L p .62 0 1 r
F P
0 g
s
.63873 .49275 m .57878 .39149 L .60401 .35728 L p .385 0 1 r
F P
0 g
s
.60401 .35728 m .68819 .42883 L .63873 .49275 L p .385 0 1 r
F P
0 g
s
.43167 .37851 m .42048 .34092 L p .59447 .31927 L .62 0 1 r
F P
0 g
s
.68819 .42883 m .60401 .35728 L .59447 .31927 L p .137 0 1 r
F P
0 g
s
.42048 .34092 m .4446 .30579 L p .59447 .31927 L .62 0 1 r
F P
0 g
s
.4446 .30579 m .49539 .28697 L p .59447 .31927 L .62 0 1 r
F P
0 g
s
.49539 .28697 m .55297 .29219 L .59447 .31927 L p .62 0 1 r
F P
0 g
s
.59147 .30428 m .47915 .29414 L p .59992 .35393 L .493 0 .191 r
F P
0 g
s
.61585 .35 m .73331 .43476 L .5617 .36623 L .883 1 0 r
F
.4021 .62656 m .38928 .63611 L .47454 1.11959 L .691 .611 0 r
F
.38928 .63611 m .37529 .64654 L .47454 1.11959 L F
.37529 .64654 m .50741 1.35075 L p .47454 1.11959 L F P
0 g
s
.47454 1.11959 m .50741 1.35075 L .50852 1.35085 L .691 .611 0 r
F
.38323 .64063 m .36568 .63049 L p .41493 .62667 L .886 0 1 r
F P
0 g
s
.36568 .63049 m .29768 .59121 L p .35009 .60706 L .886 0 1 r
F P
0 g
s
.41493 .62667 m .36568 .63049 L .35009 .60706 L .886 0 1 r
F
.36843 .60998 m .34481 .48406 L .28861 .42028 L p .77 .794 0 r
F P
0 g
s
.28861 .42028 m .21509 .33686 L p .36843 .60998 L .77 .794 0 r
F P
0 g
s
.29768 .59121 m .3582 .46861 L .43774 .5166 L p .886 0 1 r
F P
0 g
s
.23569 .89733 m .25533 .73777 L .38899 .81132 L p .904 0 .935 r
F P
0 g
s
.38899 .81132 m .37978 .9727 L .23569 .89733 L p .904 0 .935 r
F P
0 g
s
.37529 .64654 m .30465 .53951 L .50386 1.3475 L .77 .794 0 r
F
.24882 .4549 m .27092 .53224 L p .30465 .53951 L F P
0 g
s
.21324 .62706 m .25128 .52801 L p .26941 .55271 L .916 0 .806 r
F P
0 g
s
.29768 .59121 m .26559 .60484 L .26941 .55271 L .916 0 .806 r
F
.26559 .60484 m .21324 .62706 L .26941 .55271 L F
.27737 .53363 m .29768 .59121 L p .26941 .55271 L F P
0 g
s
.26941 .55271 m .25128 .52801 L .27092 .53224 L .916 0 .806 r
F
.26941 .55271 m .27092 .53224 L .27737 .53363 L F
.29768 .59121 m .25533 .73777 L .21324 .62706 L p F P
0 g
s
.27092 .53224 m .48202 1.25892 L p .30465 .53951 L .77 .794 0 r
F P
0 g
s
.50741 1.35075 m .37529 .64654 L p .50386 1.3475 L .77 .794 0 r
F P
0 g
s
.50386 1.3475 m .27092 .53224 L p .50676 1.34409 L .103 .151 0 r
F P
0 g
s
.36568 .63049 m .24882 .4549 L .37529 .64654 L .77 .794 0 r
F
.27092 .53224 m .23813 .41751 L p .27101 .53092 L .103 .151 0 r
F P
0 g
s
.23813 .41751 m .29402 .21751 L .27467 .48109 L .103 .151 0 r
F
.23813 .41751 m .27467 .48109 L .26455 .49624 L F
.23813 .41751 m .27194 .51825 L .27032 .52852 L F
.33523 .39791 m .2788 .4749 L p .3275 .40198 L .316 0 .464 r
F P
0 g
s
.3582 .46861 m .31551 .55511 L p .27376 .50678 L .948 0 1 r
F P
0 g
s
.3582 .46861 m .27376 .50678 L .27612 .49183 L .948 0 1 r
F
.25128 .52801 m .26385 .49531 L .27194 .51825 L p .916 0 .806 r
F P
0 g
s
.27194 .51825 m .27737 .53363 L p .27092 .53224 L .916 0 .806 r
F P
0 g
s
.27032 .52852 m .27194 .51825 L .27101 .53092 L .103 .151 0 r
F
.27092 .53224 m .25128 .52801 L .27194 .51825 L .916 0 .806 r
F
.27737 .53363 m .27194 .51825 L p .31551 .55511 L .948 0 1 r
F P
0 g
s
.3074 .16961 m .31761 .22973 L p .27289 .51224 L .103 .151 0 r
F P
0 g
s
.26455 .49624 m .27467 .48109 L .27194 .51825 L .103 .151 0 r
F
.31551 .55511 m .27194 .51825 L .27376 .50678 L .948 0 1 r
F
.29402 .21751 m .3074 .16961 L .27289 .51224 L .103 .151 0 r
F
.27194 .51825 m .27289 .51224 L .27101 .53092 L F
.29402 .21751 m .27289 .51224 L .27194 .51825 L F
.33523 .39791 m .3582 .46861 L p .27612 .49183 L .948 0 1 r
F P
0 g
s
.26385 .49531 m .2788 .4749 L p .27612 .49183 L .948 0 1 r
F P
0 g
s
.2788 .4749 m .33523 .39791 L p .27612 .49183 L .948 0 1 r
F P
0 g
s
.27194 .51825 m .26385 .49531 L p .27376 .50678 L .948 0 1 r
F P
0 g
s
.27101 .53092 m .27289 .51224 L .50676 1.34409 L .103 .151 0 r
F
.43774 .5166 m .41493 .62667 L p .35009 .60706 L .886 0 1 r
F P
0 g
s
.43774 .5166 m .35009 .60706 L .32858 .57475 L .886 0 1 r
F
.33523 .39791 m .42048 .34092 L .43167 .37851 L p .899 0 1 r
F P
0 g
s
.43167 .37851 m .3582 .46861 L .33523 .39791 L p .899 0 1 r
F P
0 g
s
.42048 .34092 m .33523 .39791 L .38059 .33063 L p .596 0 1 r
F P
0 g
s
.38059 .33063 m .33523 .39791 L p .3275 .40198 L .316 0 .464 r
F P
0 g
s
.31761 .22973 m .34293 .37888 L p .33379 .39257 L .103 .151 0 r
F P
0 g
s
.2788 .4749 m .29377 .38035 L .33379 .39257 L .103 .151 0 r
F
.29377 .38035 m .31761 .22973 L .33379 .39257 L F
.33379 .39257 m .38059 .33063 L p .3275 .40198 L .316 0 .464 r
F P
0 g
s
.43774 .5166 m .54374 .52562 L p .4356 .62983 L .739 0 1 r
F P
0 g
s
.41493 .62667 m .43774 .5166 L p .4356 .62983 L .739 0 1 r
F P
0 g
s
.52895 .40931 m .54374 .52562 L .43774 .5166 L p .733 0 1 r
F P
0 g
s
.47308 .40441 m .43774 .5166 L .3582 .46861 L p .845 0 1 r
F P
0 g
s
.43774 .5166 m .47308 .40441 L .52895 .40931 L p .733 0 1 r
F P
0 g
s
.3582 .46861 m .43167 .37851 L .47308 .40441 L p .845 0 1 r
F P
0 g
s
.55674 .3691 m .51395 1.3431 L p .34702 .39645 L .591 .745 0 r
F P
0 g
s
.34838 .39556 m .55674 .3691 L .34702 .39645 L .591 .745 0 r
F
.38059 .33063 m .33379 .39257 L p .38595 .37643 L .152 0 .106 r
F P
0 g
s
.35182 .39332 m .34472 .39591 L p .34602 .39711 L .269 0 .358 r
F P
0 g
s
.61585 .35 m .5617 .36623 L .5703 .36125 L .883 1 0 r
F
.5703 .36125 m .53867 .35843 L p .55674 .3691 L .646 0 .423 r
F P
0 g
s
.51395 1.3431 m .55674 .3691 L p .52 1.34527 L .883 1 0 r
F P
0 g
s
.55677 .36909 m .52 1.34527 L .55674 .3691 L .883 1 0 r
F
.55727 .36446 m .52 1.34527 L .55694 .36455 L F
.73331 .43476 m .52 1.34527 L p .55727 .36446 L F P
0 g
s
.45515 .45931 m .64819 .476 L p .52106 .38978 L .646 0 .423 r
F P
0 g
s
.46924 .33521 m .55674 .3691 L .3469 .39575 L .591 .745 0 r
F
.46521 .3519 m .45825 .42617 L p .52106 .38978 L .646 0 .423 r
F P
0 g
s
.45825 .42617 m .45515 .45931 L p .52106 .38978 L .646 0 .423 r
F P
0 g
s
.55674 .3691 m .55694 .36455 L p .55677 .36909 L .883 1 0 r
F P
0 g
s
.47915 .29414 m .46924 .33521 L p .58364 .35795 L .493 0 .191 r
F P
0 g
s
.47915 .29414 m .58364 .35795 L .59992 .35393 L .493 0 .191 r
F
.53867 .35843 m .62442 .36606 L p .46924 .33521 L F P
0 g
s
.55694 .36455 m .55937 .30924 L p .55727 .36446 L .883 1 0 r
F P
0 g
s
.59992 .35393 m .58364 .35795 L .62442 .36606 L .493 0 .191 r
F
.53867 .35843 m .55674 .3691 L .46924 .33521 L .591 .745 0 r
F
.46924 .33521 m .46521 .3519 L .53867 .35843 L p .493 0 .191 r
F P
0 g
s
.48561 .32711 m .53867 .35843 L .46924 .33521 L .591 .745 0 r
F
.34472 .39591 m .35182 .39332 L p .33379 .39257 L .152 0 .106 r
F P
0 g
s
.35182 .39332 m .46521 .3519 L p .38595 .37643 L .152 0 .106 r
F P
0 g
s
.33379 .39257 m .35182 .39332 L .38595 .37643 L .152 0 .106 r
F
.2788 .4749 m .3366 .38835 L .50676 1.34409 L .103 .151 0 r
F
.34602 .39711 m .50676 1.34409 L p .3366 .38835 L F P
0 g
s
.26385 .49531 m .32613 .4027 L p .3275 .40198 L .316 0 .464 r
F P
0 g
s
.2788 .4749 m .26385 .49531 L p .3275 .40198 L .316 0 .464 r
F P
0 g
s
.32613 .4027 m .33292 .40568 L .34602 .39711 L .269 0 .358 r
F
.34472 .39591 m .32613 .4027 L p .34602 .39711 L F P
0 g
s
.34293 .37888 m .34602 .39711 L p .3366 .38835 L .103 .151 0 r
F P
0 g
s
.45515 .45931 m .46521 .3519 L .35182 .39332 L p .269 0 .358 r
F P
0 g
s
.50676 1.34409 m .34602 .39711 L p .51395 1.3431 L .591 .745 0 r
F P
0 g
s
.34602 .39711 m .31727 .22772 L p .34702 .39645 L .591 .745 0 r
F P
0 g
s
.34702 .39645 m .51395 1.3431 L .34602 .39711 L .591 .745 0 r
F
.27289 .51224 m .2788 .4749 L .50676 1.34409 L .103 .151 0 r
F
.28706 .51904 m .45515 .45931 L p .33292 .40568 L .269 0 .358 r
F P
0 g
s
.32613 .4027 m .32294 .41221 L p .33292 .40568 L .269 0 .358 r
F P
0 g
s
.32294 .41221 m .28706 .51904 L p .33292 .40568 L .269 0 .358 r
F P
0 g
s
.33292 .40568 m .45515 .45931 L .35182 .39332 L .269 0 .358 r
F
.3469 .39575 m .34838 .39556 L .34702 .39645 L .591 .745 0 r
F
.38059 .33063 m .4446 .30579 L .42048 .34092 L p .596 0 1 r
F P
0 g
s
.38059 .33063 m .38595 .37643 L .44552 .34695 L .152 0 .106 r
F
.47915 .29414 m .49539 .28697 L .4446 .30579 L p 0 0 0 r
F P
0 g
s
.4446 .30579 m .38059 .33063 L .47915 .29414 L p 0 0 0 r
F P
0 g
s
.47915 .29414 m .38059 .33063 L p .44552 .34695 L .152 0 .106 r
F P
0 g
s
.46521 .3519 m .46924 .33521 L p .44552 .34695 L .152 0 .106 r
F P
0 g
s
.46924 .33521 m .47915 .29414 L p .44552 .34695 L .152 0 .106 r
F P
0 g
s
.3074 .16961 m .56777 .11801 L .56021 .29019 L p .591 .745 0 r
F P
0 g
s
.59147 .30428 m .55297 .29219 L .49539 .28697 L p .122 0 0 r
F P
0 g
s
.49539 .28697 m .47915 .29414 L .59147 .30428 L p .122 0 0 r
F P
0 g
s
.56021 .29019 m .55674 .3691 L p .49713 .32141 L .591 .745 0 r
F P
0 g
s
.3074 .16961 m .56021 .29019 L .49713 .32141 L .591 .745 0 r
F
.31727 .22772 m .48561 .32711 L .3469 .39575 L F
.44552 .34695 m .38595 .37643 L .46521 .3519 L .152 0 .106 r
F
.32613 .4027 m .33379 .39257 L p .3275 .40198 L .316 0 .464 r
F P
0 g
s
.33379 .39257 m .32613 .4027 L .34472 .39591 L p .152 0 .106 r
F P
0 g
s
.27612 .49183 m .27376 .50678 L .26385 .49531 L .948 0 1 r
F
.27101 .53092 m .50676 1.34409 L .27092 .53224 L .103 .151 0 r
F
.50898 1.35089 m .49892 1.3533 L .46643 1.39507 L .516 0 1 r
F
.52 1.34527 m .73331 .43476 L p .52034 1.34897 L .508 .977 0 r
F P
0 g
s
.73331 .43476 m .78156 .2288 L p .73358 .43455 L .508 .977 0 r
F P
0 g
s
.73358 .43455 m .52034 1.34897 L .73331 .43476 L .508 .977 0 r
F
.59147 .30428 m .62442 .36606 L .73201 .43578 L p .462 0 0 r
F P
0 g
s
.73358 .43455 m .74017 .50948 L .73337 .43545 L .508 .977 0 r
F
.74976 .42196 m .74017 .50948 L .73358 .43455 L F
.74017 .50948 m .73902 .5199 L .73337 .43545 L F
.73331 .43476 m .73634 .43859 L p .73908 .49765 L 0 0 .723 r
F P
0 g
s
.73201 .43578 m .73634 .43859 L p .73271 .43523 L .462 0 0 r
F P
0 g
s
.59147 .30428 m .73201 .43578 L .73271 .43523 L .462 0 0 r
F
.54811 1.36008 m .56002 1.26898 L .70528 1.22901 L p .257 0 .299 r
F P
0 g
s
.56005 1.29787 m .46651 1.34713 L .50898 1.35089 L .516 0 1 r
F
.4273 1.35215 m .46643 1.39507 L .41792 1.37272 L p .306 0 0 r
F P
0 g
s
.46651 1.34713 m .41792 1.37272 L .50898 1.35089 L .516 0 1 r
F
.50741 1.35075 m .51244 1.37753 L p .50852 1.35085 L .691 .611 0 r
F P
0 g
s
.50386 1.3475 m .51244 1.37753 L .50741 1.35075 L p .77 .794 0 r
F P
0 g
s
.50676 1.34409 m .51244 1.37753 L .50386 1.3475 L p .103 .151 0 r
F P
0 g
s
.41792 1.37272 m .46423 1.39405 L p .49892 1.3533 L .516 0 1 r
F P
0 g
s
.46423 1.39405 m .46643 1.39507 L p .49892 1.3533 L .516 0 1 r
F P
0 g
s
.52281 1.34187 m .50898 1.35089 L .51474 1.3514 L .516 0 1 r
F
.51688 1.34269 m .50898 1.35089 L .52281 1.34187 L F
.51244 1.37753 m .51474 1.3514 L p .50852 1.35085 L .691 .611 0 r
F P
0 g
s
.51395 1.3431 m .51244 1.37753 L .50676 1.34409 L p .591 .745 0 r
F P
0 g
s
.56005 1.29787 m .51688 1.34269 L .52281 1.34187 L .516 0 1 r
F
.46521 .3519 m .52106 .38978 L .55674 .3691 L .646 0 .423 r
F
.53867 .35843 m .46521 .3519 L p .55674 .3691 L F P
0 g
s
.31727 .22772 m .3074 .16961 L p .55674 .3691 L .591 .745 0 r
F P
0 g
s
.5703 .36125 m .5617 .36623 L .55727 .36446 L .883 1 0 r
F
.64819 .476 m .62442 .36606 L .5703 .36125 L p .646 0 .423 r
F P
0 g
s
.52106 .38978 m .64819 .476 L .5703 .36125 L .646 0 .423 r
F
.62442 .36606 m .61585 .35 L p .59992 .35393 L .493 0 .191 r
F P
0 g
s
.61585 .35 m .59147 .30428 L p .59992 .35393 L .493 0 .191 r
F P
0 g
s
.55937 .30924 m .61585 .35 L .55727 .36446 L .883 1 0 r
F
.51244 1.37753 m .52034 1.34897 L p .51774 1.3501 L .191 .126 0 r
F P
0 g
s
.56005 1.29787 m .51474 1.3514 L .54931 1.33635 L .516 0 1 r
F
.52 1.34527 m .51244 1.37753 L .51395 1.3431 L p .883 1 0 r
F P
0 g
s
.67134 .35659 m .59147 .30428 L p .72837 .4312 L .462 0 0 r
F P
0 g
s
.72837 .4312 m .73112 .43319 L .67134 .35659 L .462 0 0 r
F
.73331 .43476 m .67134 .35659 L p .73271 .43523 L F P
0 g
s
.55937 .30924 m .56777 .11801 L p .73331 .43476 L .883 1 0 r
F P
0 g
s
.72837 .4312 m .73271 .43523 L .73112 .43319 L .462 0 0 r
F
.73634 .43859 m .73331 .43476 L p .73271 .43523 L F P
0 g
s
.76152 .31476 m .74976 .42196 L .73358 .43455 L .508 .977 0 r
F
.77882 .24055 m .73902 .5199 L .76152 .31476 L F
.78156 .2288 m .78164 .35834 L p .74181 .50935 L F P
0 g
s
.78156 .2288 m .74181 .50935 L .77882 .24055 L .508 .977 0 r
F
.73634 .43859 m .75818 .53743 L p .73908 .49765 L 0 0 .723 r
F P
0 g
s
.75818 .53743 m .74017 .50948 L p .73908 .49765 L 0 0 .723 r
F P
0 g
s
.7403 .51094 m .74058 .51399 L .73902 .5199 L .508 .977 0 r
F
.74017 .50948 m .75818 .53743 L .73383 .56727 L p .247 0 1 r
F P
0 g
s
.78164 .35834 m .78166 .40444 L .75404 .5043 L p .508 .977 0 r
F P
0 g
s
.52034 1.34897 m .51244 1.37753 L .52 1.34527 L p .508 .977 0 r
F P
0 g
s
.46643 1.39507 m .53174 1.39929 L p .53759 1.37833 L .516 0 1 r
F P
0 g
s
.54437 1.35403 m .5232 1.36518 L .53759 1.37833 L .516 0 1 r
F
.23813 .41751 m .21509 .33686 L .23189 .30641 L p .103 .151 0 r
F P
0 g
s
.23189 .30641 m .3074 .16961 L p .23813 .41751 L .103 .151 0 r
F P
0 g
s
.25533 .73777 m .256 .73549 L p .25608 .73704 L .902 0 1 r
F P
0 g
s
.73788 .93543 m .72205 .77492 L .80752 .67584 L p .128 0 .74 r
F P
0 g
s
.75818 .53743 m .80752 .67584 L .72205 .77492 L p .169 0 1 r
F P
0 g
s
.80752 .67584 m .75818 .53743 L .73634 .43859 L p 0 0 .364 r
F P
0 g
s
.18958 .78341 m .21324 .62706 L .25533 .73777 L p .807 0 .444 r
F P
0 g
s
.25533 .73777 m .23569 .89733 L .18958 .78341 L p .807 0 .444 r
F P
0 g
s
.24212 1.05642 m .23569 .89733 L .37978 .9727 L p .891 0 .713 r
F P
0 g
s
.37978 .9727 m .38279 1.1265 L .24212 1.05642 L p .891 0 .713 r
F P
0 g
s
.28706 .51904 m .32613 .4027 L .26385 .49531 L p 0 0 0 r
F P
0 g
s
.26385 .49531 m .21324 .62706 L .28706 .51904 L p 0 0 0 r
F P
0 g
s
.7327 1.09184 m .73788 .93543 L .83051 .83367 L p .079 0 .421 r
F P
0 g
s
.80752 .67584 m .83051 .83367 L .73788 .93543 L p .128 0 .74 r
F P
0 g
s
.73634 .43859 m .78276 .56103 L .80752 .67584 L p 0 0 .364 r
F P
0 g
s
.83051 .83367 m .80752 .67584 L .78276 .56103 L p .388 0 0 r
F P
0 g
s
.19734 .95064 m .18958 .78341 L .23569 .89733 L p .599 0 .248 r
F P
0 g
s
.23569 .89733 m .24212 1.05642 L .19734 .95064 L p .599 0 .248 r
F P
0 g
s
.78276 .56103 m .73634 .43859 L .62442 .36606 L p .791 0 .282 r
F P
0 g
s
.2761 1.19943 m .24212 1.05642 L .38279 1.1265 L p .85 0 .401 r
F P
0 g
s
.38279 1.1265 m .39877 1.25806 L .2761 1.19943 L p .85 0 .401 r
F P
0 g
s
.26865 .67172 m .28706 .51904 L .21324 .62706 L p 0 0 .275 r
F P
0 g
s
.21324 .62706 m .18958 .78341 L .26865 .67172 L p 0 0 .275 r
F P
0 g
s
.7327 1.09184 m .70528 1.22901 L .56002 1.26898 L p .38 0 .552 r
F P
0 g
s
.70528 1.22901 m .7327 1.09184 L .82298 .99728 L p .011 0 .253 r
F P
0 g
s
.83051 .83367 m .82298 .99728 L .7327 1.09184 L p .079 0 .421 r
F P
0 g
s
.62442 .36606 m .64819 .476 L .78276 .56103 L p .791 0 .282 r
F P
0 g
s
.82298 .99728 m .83051 .83367 L .80457 .7152 L p .473 0 .246 r
F P
0 g
s
.78276 .56103 m .80457 .7152 L .83051 .83367 L p .388 0 0 r
F P
0 g
s
.23813 1.11156 m .19734 .95064 L .24212 1.05642 L p .415 0 0 r
F P
0 g
s
.24212 1.05642 m .2761 1.19943 L .23813 1.11156 L p .415 0 0 r
F P
0 g
s
.80457 .7152 m .78276 .56103 L .64819 .476 L p .885 0 .495 r
F P
0 g
s
.27469 .84708 m .26865 .67172 L .18958 .78341 L p .049 0 .446 r
F P
0 g
s
.18958 .78341 m .19734 .95064 L .27469 .84708 L p .049 0 .446 r
F P
0 g
s
.33632 1.30987 m .2761 1.19943 L .39877 1.25806 L p .723 0 .219 r
F P
0 g
s
.39877 1.25806 m .4273 1.35215 L .33632 1.30987 L p .723 0 .219 r
F P
0 g
s
.45038 .60973 m .45515 .45931 L .28706 .51904 L p .375 0 .652 r
F P
0 g
s
.28706 .51904 m .26865 .67172 L .45038 .60973 L p .375 0 .652 r
F P
0 g
s
.70528 1.22901 m .65651 1.33115 L .54811 1.36008 L p .257 0 .299 r
F P
0 g
s
.65651 1.33115 m .70528 1.22901 L .78329 1.15022 L p 0 0 0 r
F P
0 g
s
.82298 .99728 m .78329 1.15022 L .70528 1.22901 L p .011 0 .253 r
F P
0 g
s
.78329 1.15022 m .82298 .99728 L .79741 .88738 L p .725 0 .471 r
F P
0 g
s
.80457 .7152 m .79741 .88738 L .82298 .99728 L p .473 0 .246 r
F P
0 g
s
.64819 .476 m .65942 .62706 L .80457 .7152 L p .885 0 .495 r
F P
0 g
s
.65942 .62706 m .64819 .476 L .45515 .45931 L p .697 0 .73 r
F P
0 g
s
.30954 1.24729 m .23813 1.11156 L .2761 1.19943 L p 0 0 .403 r
F P
0 g
s
.2761 1.19943 m .33632 1.30987 L .30954 1.24729 L p 0 0 .403 r
F P
0 g
s
.79741 .88738 m .80457 .7152 L .65942 .62706 L p .916 0 .797 r
F P
0 g
s
.45515 .45931 m .45038 .60973 L .65942 .62706 L p .697 0 .73 r
F P
0 g
s
.30632 1.02626 m .27469 .84708 L .19734 .95064 L p .107 0 .823 r
F P
0 g
s
.19734 .95064 m .23813 1.11156 L .30632 1.02626 L p .107 0 .823 r
F P
0 g
s
.53174 1.39929 m .54811 1.36008 L .65651 1.33115 L p .114 0 0 r
F P
0 g
s
.41792 1.37272 m .33632 1.30987 L .4273 1.35215 L p .306 0 0 r
F P
0 g
s
.45195 .78968 m .45038 .60973 L .26865 .67172 L p .437 0 .889 r
F P
0 g
s
.26865 .67172 m .27469 .84708 L .45195 .78968 L p .437 0 .889 r
F P
0 g
s
.78329 1.15022 m .71343 1.27471 L .65651 1.33115 L p 0 0 0 r
F P
0 g
s
.71343 1.27471 m .78329 1.15022 L .7599 1.05937 L p .865 0 .914 r
F P
0 g
s
.79741 .88738 m .7599 1.05937 L .78329 1.15022 L p .725 0 .471 r
F P
0 g
s
.65651 1.33115 m .59003 1.38393 L .53174 1.39929 L p .114 0 0 r
F P
0 g
s
.59003 1.38393 m .65651 1.33115 L .71343 1.27471 L p .284 0 .623 r
F P
0 g
s
.65942 .62706 m .65573 .80573 L .79741 .88738 L p .916 0 .797 r
F P
0 g
s
.65573 .80573 m .65942 .62706 L .45038 .60973 L p .722 0 .933 r
F P
0 g
s
.40464 1.3402 m .30954 1.24729 L .33632 1.30987 L p 0 0 .946 r
F P
0 g
s
.33632 1.30987 m .41792 1.37272 L .40464 1.3402 L p 0 0 .946 r
F P
0 g
s
.7599 1.05937 m .79741 .88738 L .65573 .80573 L p .924 0 1 r
F P
0 g
s
.36108 1.18743 m .30632 1.02626 L .23813 1.11156 L p .159 0 1 r
F P
0 g
s
.23813 1.11156 m .30954 1.24729 L .36108 1.18743 L p .159 0 1 r
F P
0 g
s
.45038 .60973 m .45195 .78968 L .65573 .80573 L p .722 0 .933 r
F P
0 g
s
.53174 1.39929 m .59003 1.38393 L p .56005 1.29787 L .516 0 1 r
F P
0 g
s
.46012 .97928 m .45195 .78968 L .27469 .84708 L p .482 0 1 r
F P
0 g
s
.27469 .84708 m .30632 1.02626 L .46012 .97928 L p .482 0 1 r
F P
0 g
s
.71343 1.27471 m .6197 1.35437 L .59003 1.38393 L p .284 0 .623 r
F P
0 g
s
.6197 1.35437 m .71343 1.27471 L .69466 1.21056 L p .876 0 1 r
F P
0 g
s
.7599 1.05937 m .69466 1.21056 L .71343 1.27471 L p .865 0 .914 r
F P
0 g
s
.59003 1.38393 m .6197 1.35437 L p .56005 1.29787 L .516 0 1 r
F P
0 g
s
.40464 1.3402 m .41792 1.37272 L p .56005 1.29787 L .516 0 1 r
F P
0 g
s
.69466 1.21056 m .7599 1.05937 L .63646 .9924 L p .914 0 1 r
F P
0 g
s
.65573 .80573 m .63646 .9924 L .7599 1.05937 L p .924 0 1 r
F P
0 g
s
.43278 1.3097 m .36108 1.18743 L .30954 1.24729 L p .251 0 1 r
F P
0 g
s
.30954 1.24729 m .40464 1.3402 L .43278 1.3097 L p .251 0 1 r
F P
0 g
s
.63646 .9924 m .65573 .80573 L .45195 .78968 L p .737 0 1 r
F P
0 g
s
.6197 1.35437 m .60869 1.32142 L .56005 1.29787 L p .516 0 1 r
F P
0 g
s
.69466 1.21056 m .60869 1.32142 L .6197 1.35437 L p .876 0 1 r
F P
0 g
s
.45195 .78968 m .46012 .97928 L .63646 .9924 L p .737 0 1 r
F P
0 g
s
.47417 1.15483 m .46012 .97928 L .30632 1.02626 L p .521 0 1 r
F P
0 g
s
.30632 1.02626 m .36108 1.18743 L .47417 1.15483 L p .521 0 1 r
F P
0 g
s
.43278 1.3097 m .40464 1.3402 L p .56005 1.29787 L .516 0 1 r
F P
0 g
s
.60869 1.32142 m .69466 1.21056 L .60325 1.1639 L p .873 0 1 r
F P
0 g
s
.63646 .9924 m .60325 1.1639 L .69466 1.21056 L p .914 0 1 r
F P
0 g
s
.60325 1.1639 m .56005 1.29787 L .60869 1.32142 L p .873 0 1 r
F P
0 g
s
.4924 1.29333 m .47417 1.15483 L .36108 1.18743 L p .558 0 1 r
F P
0 g
s
.36108 1.18743 m .43278 1.3097 L .4924 1.29333 L p .558 0 1 r
F P
0 g
s
.60325 1.1639 m .63646 .9924 L .46012 .97928 L p .744 0 1 r
F P
0 g
s
.56005 1.29787 m .4924 1.29333 L .43278 1.3097 L p .516 0 1 r
F P
0 g
s
.46012 .97928 m .47417 1.15483 L .60325 1.1639 L p .744 0 1 r
F P
0 g
s
.56005 1.29787 m .60325 1.1639 L .47417 1.15483 L p .739 0 1 r
F P
0 g
s
.47417 1.15483 m .4924 1.29333 L .56005 1.29787 L p .739 0 1 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{329.312, 536.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400059000262000`400?l00000o`00003oo`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:
0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00^03oool3000008h0oooo002c
0?ooo`D000000P2D_@03000008`0oooo002^0?ooo`D0000000X0U;@009Bm002;]000U;d009Bd002D
_@00Rk@00000003No`00i_l00P00002:0?ooo`00Z@3oool5000000`0U;d000<000000=ko003No`00
0P3No`02000008P0oooo002T0?ooo`D0000001P0U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd00000000g_l00>Ko003No`00i_l00=ko
003Vo`02000008H0oooo002O0?ooo`D000005P2D_@000`000000g_l00=ko00060=ko00800000Q03o
ool009X0oooo1@0000009P2D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d0
08^d00000000g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00P0000220?ooo`00
U@3oool500000200U;d000<000000=ko003No`002P3No`0200000800oooo002@0?ooo`D0000003@0
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@00000003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00P00001n0?ooo`00RP3oool6000002X0U;d000<00000
0=ko003No`003P3No`02000007`0oooo00250?ooo`D0000002l0U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm00020000000B0=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00P00001j0?ooo`00P03oool5000003@0U;d000<000000=ko003No`004`3No`02000007P0
oooo001k0?ooo`D000000540U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@0000000>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`000P00001f0?ooo`00MP3oool5
000003h0U;d000<000000=ko003No`005`3No`02000007@0oooo001a0?ooo`D0000005l0U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d00000003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko000200000780oooo001/0?ooo`D00000B02D_@000`000000g_l00=ko000K0=ko
00800000L03oool006L0oooo1@000000K@2D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d00000003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`000P00001^0?ooo`00I03oool3
00000580U;d000<000000=ko003No`007`3No`02000006`0oooo001S0?ooo`80000007T0Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@0000000>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00000006/0
oooo001S0?ooo`800000E02D_@000`000000g_l00=ko000R0=ko00800000J@3oool00680oooo07h0
0000010H000H8000000009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@0000000>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`02000006L0oooo001R0?ooo`040000000@80004200000005<0
U;d000<000000=ko003No`009P3No`02000006D0oooo001Q0?ooo`230000000H800041P001PP0000
0000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm00000000i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`000P00001S0?ooo`00H@3oool01@0000004200010P000@
8000000000D0U;d000<0oooo09Bm002D_@00B`2D_@000`000000g_l00=ko000Z0=ko00800000H@3o
ool00600oooo08P00000010H000H800041P001PP00000000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm00000000i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00P00001O0?ooo`00H03oool00`0000004200010P0003010P00030000002D
_@00U;d00500U;d000<000000=ko003No`00;P3No`02000005d0oooo001O0?ooo`2=0000000H8000
41P001PP000@60006200010H00000000U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d00000003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l000800000F`3oool005l0oooo00<00000010P000@8000100@80000`000000
U;d009Bm000709Bm00030?ooo`2D_@00U;d004H0U;d000<000000=ko003No`00<P3No`02000005T0
oooo001N0?ooo`1J0000000@60006200010H000H800041P001PP000@6000000008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d0
08^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@00P000000=P3Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko00800000
E`3oool005h0oooo00<00000010P000@80001P0@80000`000000U;d009Bm001>09Bm00800000>03N
o`02000005D0oooo001M0?ooo`1K0000000H800041P00?ooo`0@60006200010H000H800041P001PP
00000000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000oooo08^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd00020000000j0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko00800000D`3oool005d0oooo00<00000010P000@80001`0@
80000`000000U;d009Bm001>09Bm00800000?03No`0200000540oooo001L0?ooo`2L0000000@6000
6200010H000H800041P001PP000@60006200010H000H8000000009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
00000=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00P00001?0?ooo`00F`3oool00`0000004200010P0009010P00030000002D
_@00U;d004h0U;d000<000000=ko003No`00?`3No`02000004d0oooo001K0?ooo`2Q0000000H8000
41P001PP000@60006200010H000H800041P001PP000@60006200010H00000000Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d00?ooo`2D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@00000003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`000P00001;0?ooo`00FP3oool00`000000
4200010P000;010P00030000002D_@00U;d004d0U;d000<000000=ko003No`00@`3No`02000004T0
oooo001J0?ooo`2W0000000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP000@6000000009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d0
08^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d00000000g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko00000000B03oool005T0oooo00<00000010P000@8000300@800E09Bm0003
0?ooo`2D_@00U;d003P0U;d000<000000=ko003No`00A@3No`000`000000oooo0?ooo`160?ooo`00
F@3oool0Z00000006200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000oooo09Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@00000003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l0000004P0oooo001H0?ooo`030000000@8000420000d04200D02D_@000`00
0000g_l00=ko00140=ko000307_f00000000oooo04L0oooo001H0?ooo`2Y0000000@60006200010H
000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H8000U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@00000003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00NoH00000
00180?ooo`00E`3oool00`0000004200010P0003010P00030?ooo`0@8000420000T042006@2D_@00
0`3oool0U;d009Bm000c09Bm00030000003No`00g_l004@0g_l000<0NoH00000003oool0A`3oool0
05L0oooo0:X0000001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP000@60006200010H000H8000Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm003oool0U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d0
08^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@00000003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00NoH0000004P0oooo001F0?ooo`030000000@8000420001004200
C`2D_@000`000000g_l00=ko00130=ko0080NoH000<000000?ooo`3oool0AP3oool005H0oooo0:/0
0000010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H8000
41P001PP000@6000620009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000oooo08^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d00000000g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00Pol007_f00000000B03oool005D0oooo00<00000010P000@80004@0@800N09Bm
00030?ooo`2D_@00U;d002h0U;d000<000000=ko003No`00@`3No`0207_f00030000003oool0oooo
04H0oooo001E0?ooo`2/0000000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H000H800041P001PP000@60006200010H000H800041P009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@00?ooo`2;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@00000003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko0023o`00NoH0000004P0oooo001D0?ooo`030000
000@8000420001<04200C@2D_@02000004@0g_l000@0000007_f001kmP000000B03oool005<0oooo
06@0000001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@
60006200010H000H800041P001PP000@60006200010H002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm003oool0U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d00P000000B03No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l007_f0023o`00NoH0000004P0oooo001C0?ooo`030000000@8000
420001@042008P2D_@000`3oool0U;d009Bm000X09Bm00800000A03No`0307_f00030000003oool0
oooo04H0oooo001B0?ooo`1U0000000@60006200010H000H800041P001PP000@60006200010H000H
800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@000P000000B03No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l007_f0023o`00NoH0000004P0
oooo001B0?ooo`030000000@8000420001D042009@2D_@000`3oool0U;d009Bm000U09Bm00800000
@`3No`001@000000oooo07_f001kmP00000004P0oooo001A0?ooo`1V0000000H800041P001PP000@
60006200010H000H800041P00?ooo`0@60006200010H000H800041P001PP000@60006200010H000H
800041P001PP000@60006200010H000H8000Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@00?ooo`2D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d00P000000B03No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00000007_f0023o`00NoH0000004P0oooo001A0?ooo`030000000@8000420001L042009P2D
_@000`3oool0U;d009Bm000S09Bm00030000003No`00g_l00480g_l0101kmP000`000000oooo0?oo
o`160?ooo`00D03oool0/@00000041P001PP000@60006200010H000H800041P001PP000@60006200
010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d0
08^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d0
08^d002D_@0000000>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00Pol007_f0023o`00NoH0
000000180?ooo`00D03oool00`0000004200010P000H010P02T0U;d000<0oooo09Bm002D_@00802D
_@000`000000g_l00=ko00120=ko00@0NoH000<000000?ooo`3oool0AP3oool004l0oooo0;800000
01PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200
010H000H800041P001PP000@60006200010H000H800041P001PP000@6000620008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d00?ooo`2D_@00Rk@009Bm002D]000U;d0
08^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@0
09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm00000000i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l000000023o`00NoH008?o001kmP000000B03oool004l0oooo
00<00000010P000@80006@0@800[09Bm00030?ooo`2D_@00U;d001h0U;d000<000000=ko003No`00
@@3No`0507_f00030000003oool0oooo04H0oooo001>0?ooo`2c0000000@60006200010H000H8000
41P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H000H800041P001PP000@60006200010H000H800041P009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000oooo08^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d00000003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00NoH00?ooo`1kmP00Pol007_f00000000B03oool004h0oooo00<00000010P000@
80006`0@800]09Bm00030000002D_@00U;d001/0U;d000<000000=ko003No`00@@3No`0507_f0003
0000003oool0oooo04H0oooo001=0?ooo`2d0000000H800041P001PP000@60006200010H000H8000
41P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H000H800041P001PP000@60006200010H002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000800H08^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm00000000i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
000007_f0023o`00NoH008?o001kmP000000B03oool004d0oooo00<00000010P000@8000700@800_
09Bm00030200602D_@00U;d001T0U;d000<000000=ko003No`00@03No`000`000000NoH007_f0003
07_f00030000003oool0oooo04H0oooo001<0?ooo`2e0000000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H800041P001PP000@60006200010H000H800041P001PP000@6000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d007<0
:@2D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@0000000>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l008?o001kmP00Pol007_f0023o`00NoH0000000180?ooo`00B`3oool00`0000004200
010P000N010P0380U;d000<0N`0Y09Bm002D_@005P2D_@000`000000g_l00=ko00100=ko00H0NoH0
00<000000?ooo`3oool0AP3oool004/0oooo0;H0000001PP000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H8000oooo01PP000@60006200010H000H800041P001PP000@6000620009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00L`0Y09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00000008?o001kmP00Pol007_f0023o`00NoH0000004P0oooo001:0?ooo`030000000@8000
420002004200<`2D_@0207/0:AD0U;d0@P3No`000`000000NoH00?ooo`0407_f00030000003oool0
oooo04H0oooo001:0?ooo`2g0000000@60006200010H000H800041P001PP000@60006200010H000H
800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@
60006200010H000H800041P001PP000@60006200010H000H8000Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d001k02T0U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko0000
0000Pol007_f0023o`00NoH008?o001kmP00000004P0oooo00190?ooo`030000000@800042000240
4200=P2D_@000`1k02T0U;d009Bm000A09Bm0480g_l01`1kmP000`000000oooo0?ooo`160?ooo`00
B03oool0^@00000041P001PP000@60006200010H000H800041P001PP000@60006200010H000H8000
41P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H000H800041P001PP000@60006200010H000H8000U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000
U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@007/0:@2D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00
Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00000001kmP00
Pol007_f0023o`00NoH008?o001kmP00000004P0oooo00180?ooo`030000000@8000420002804200
<02D_@000`1k02T0U;d009Bm000509Bm000307/0:@2D_@00U;d000h0U;d000<000000=ko003No`00
?`3No`000`000000NoH007_f000507_f00030000003oool0oooo04H0oooo00170?ooo`2j0000000H
800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@
60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H
800041P001PP000@60006200010H000H800041P009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D
_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d007<0:@2D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d007<0:@2D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d009Bd002D_@00Rk@00000003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00000001kmP00Pol007_f0023
o`00NoH008?o001kmP000000B03oool004L0oooo00<00000010P000@8000900@800[09Bm00030200
60000000U;d000`0U;d000<0N`0Y09Bm002D_@002`2D_@000`000000g_l00=ko000o0=ko00P0NoH0
00<000000?ooo`3oool0AP3oool004H0oooo0;/00000010H000H800041P001PP000@60006200010H
000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H800041P009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm
002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd
002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00600@0200
600H0100000007<0:@2D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00L`0Y09Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@00000
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko
003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko
003No`00i_l00=ko003Vo`00g_l008?o001kmP00oooo07_f0023o`00NoH008?o001kmP00000004P0
oooo00160?ooo`030000000@8000420002D042009`2D_@02020040030200600P0100000000D0N`0Y
5`2D_@110=ko00040000001kmP00NoH00?ooo`D0NoH000<000000?ooo`3oool0AP3oool004L0oooo
0;X0000001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@
60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H
800041P001PP000@60006200010H000H800041P001PP000@6000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D
_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;
]000U;d001P0400P01P0600@0200600H0100800H0000001k02T0L`0Y07/0:@1c02T0N`0Y07<0:@1k
02T0Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D
]000U;d008^d002D_@00U;@009Bm002;]000i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko00000000Pol007_f0023
o`00NoH008?o001kmP00Pol007_f000000180?ooo`00A`3oool00`0000004200010P000T010P02<0
U;d000D0800H0200400P0100800@02006003020040030000001k02T0N`0Y00P0N`0Y2@2D_@000`1k
02T0U;d009Bm000609Bm0440g_l02@1kmP000`000000oooo0?ooo`160?ooo`00A`3oool0^P000000
6200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H8000
41P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H000H800041P001PP000@60006200010H000H8000Rk@009Bm002D]000U;d008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm000H0100800H01P0400P01P0
600@0200600H0100800H01P040000000L`0Y07/0:@1c02T0N`0Y07<0:@1k02T0L`0Y07/0:@1c02T0
N`0Y07<0:@1k02T0L`0Y07/0:@2;]000U;d009Bd002D_@00Rk@009Bm002D]000N`0Y08^d002D_@00
U;@009Bm002;]000U;d009Bd003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l007_f0023o`00NoH008?o001kmP00
Pol007_f0023o`00NoH0000004P0oooo00170?ooo`8000009P0@800N09Bm0080800@00D0800H0200
400P0100800@0200600302004003020060000000000000@00000301k02T<09Bm0140g_l00`1k02T/
0=ko00030000001kmP00NoH000L0NoH000<000000?ooo`3oool0AP3oool004P0oooo05H00000010H
000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H800041P001PP000@60006200010H000H8000U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d
002D_@00U;@009Bm002;]000U;d001P0400P01P0600@0200600H0100800H01P0400P01P0600@0200
600H0100000003T0DP000000W01R0:@0JP2L0680Y01Z09`0HP`0000005L0N`0Y07<0:@2D_@00Rk@0
07/0:@2D]000U;d008^d002D_@00U;@009Bm002;]000i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l007<0:@1k02T0L`0Y07/0:@1c02T0N`0Y07<0:@1k02T00000
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00000001kmP00Pol0
07_f0023o`00NoH008?o001kmP00Pol007_f00000000B03oool004P0oooo00<00000010P000@8000
900@800J09Bm00050200600P0100800@0200400P01P00`0P01006@0P01P0800@0000000i0580@@1J
03T0DP11058000000:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R
0:@0JP2L0680Y01Z0:@0HP2T06X01`00000509Bm00T0g_l00P1k02T00`3No`00N`0Y07/0:@0807/0
:@030000003No`00g_l002L0g_l00`1kmP000`3oool0NoH007_f000407_f00030000003oool0oooo
04H0oooo00180?ooo`170000000@60006200010H000H800041P001PP000@60006200010H000H8000
41P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000
6200010H000H800041P001PP000@60006200010H000H800041P001PP000@6000620008^d002D_@00
U;@009Bm002;]000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000
U;d009Bd002D_@00Rk@009Bm002D]000U;d001P0400P01P0600@0200600H0100800H01P0400P01P0
0P000000:P0i0580@@1J03T0DP1105X0>@1B0440FP0i0580000009`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2D_@00W01R09Bm002D]000i_l00=ko003Vo`00g_l00>Ko00/00000
03/0i_l007<0:@1k02T0L`0Y07/0:@1c02T0000006X0003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003N
o`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003V
o`00g_l00>Ko003No`00Pol007_f0023o`00oooo08?o001kmP00Pol007_f0023o`00NoH000000018
0?ooo`00B@3oool00`0000004200010P000S010P01H0U;d00P0P01001@0P01P0800@0200400P0100
800H00<0000002D0@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X000000:@0JP2T0680
Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0
Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z0080U;d00P3No`00302L0680g_l0
0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JPX000000P1c000U0=ko00030000
001kmP00NoH000P0NoH000<000000?ooo`3oool0AP3oool004T0oooo0400000001PP000@60006200
010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200
010H000H800041P001PP000@6000U;d008^d002D_@00U;@009Bm002;]000U;d009Bd002D_@00Rk@0
09Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d001P0400P01P0600@0200600H0100800H
0`000000@@1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP000000
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP000000
g_l00:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z00<000000340L`000=ko003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l000000023o`00NoH008?o001kmP00Pol007_f0023o`00NoH008?o001kmP00000004P0oooo0019
0?ooo`030000000@8000420002@042004@2D_@001@0P01P0800@0200400P0100800H00<0000004D0
@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP000000
Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680
Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2D_@00
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680
Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP0000000P3504400`000000L`0007<0000R0=ko
00/0NoH000<000000?ooo`3oool0AP3oool004T0oooo0P000000>00@60006200010H000H800041P0
01PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200
010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP000@6000U;d009Bd002D_@00Rk@009Bm002D]000U;d008^d002D_@00U;@009Bm002;]000U;d0
09Bd002D_@00600@0200600H0100800H0`000000B`1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J0000002T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2;]000Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP000000a@110<d0@@020000000^06X0003Vo`00g_l00>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko001kmP00
Pol007_f0023o`00NoH008?o001kmP00Pol007_f0023o`00NoH0000004P0oooo001:0?ooo`030000
000@8000420002<042003@2D_@020200401@02006000000000000000001105X0>@1B0440DP0i0580
@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580
>@1B0000002L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680
Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680
Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP0000040<D0@@030000001c
0000g_l001h0g_l000<0000007_f001kmP002@1kmP000`000000oooo0?ooo`160?ooo`00BP3oool0
<`00000041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H800041P001PP000@60006200010H000H800041P009Bm002;]000U;d009Bd002D_@00Rk@009Bm
002D]000U;d008^d002D_@00600@020060030000001D0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP1105X000000:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R09Bm002L0680Y01Z09`0
HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R000000350440c@110<D0
@@3=0440a@110P000000:`1c0000g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
0>Ko003No`00i_l00=ko00000000NoH008?o001kmP00Pol007_f0023o`00NoH008?o001kmP00Pol0
07_f00000000B03oool004X0oooo0P00000T010P00T0U;d005H0800H02004000000000000440FP0i
0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP11
05X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i058000000:@0HP2T06X0W01R0:@0JP2T
0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T
06X0Y01R0:@0JP2D_@00Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L
0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T
06X0W01R0:@0JP2T0680Y01Z000000L0a@1100<0000007<0003No`006`3No`0407_f00030?ooo`1k
mP00NoH000D0NoH000<000000?ooo`3oool0AP3oool004/0oooo02d0000001PP000@60006200010H
000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H800041P001PP002D]000U;d008^d002D_@00U;@009Bm000H01000`000000G00i0580@@1J03T0
DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X000000:@0JP2L0680Y01Z09`0
HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0
HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R000000350440c@110<D0@@3=0440a@110<d0@@350440c@110P00
0000:01Z0000i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l0
0=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko0023o`00NoH0
08?o001kmP00Pol007_f0023o`00NoH008?o001kmP00Pol007_f000000180?ooo`00B`3oool00`00
00004200010P000A010P00030?ooo`0@8000420000l04200102D_@030000001H03T0DP110580>@1B
0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B
03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP000000W01R
0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z
09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R
0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z
0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R000000T0a@1100<0000007<0003No`00
603No`0<07_f00030000003oool0oooo04H0oooo001;0?ooo`80000002H041P001PP000@60006200
010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000000006200
010H000H8000Rk@009Bm0080000006D0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580
@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J0000002T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X000000<d0@@350440c@110<D0@@3=0440a@110<d0@@350440
c@110<D0@@020000000U0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00000008?o001kmP00
Pol007_f0023o`00NoH008?o001kmP00Pol007_f0023o`00NoH0000000180?ooo`00C03oool00`00
00004200010P000M010P00040000000P01P0800@02004080000005h0U;d00440DP0i0580@@1J03T0
DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440
FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0
DP1105X0>@1B0000002T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0
JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0
HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0
JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L068000003035
04400`000000L`000=ko000D0=ko00d0NoH000<000000?ooo`3oool0AP3oool004`0oooo02000000
010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
01PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200
010H00@0000006d0@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580
@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X000000:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP000000c@110<D0@@3=0440a@110<d0@@350440
c@110<D0@@3=0440a@110<d0@@350440c@11008000000280g_l00>Ko003No`00i_l00=ko003Vo`00
g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko001kmP00
Pol007_f0023o`00NoH008?o001kmP00Pol007_f0023o`00NoH008?o001kmP000000B03oool004`0
oooo00<00000010P000@8000700@80020000001S0440DP0@8000@@1J03T0DP110580>@1B0440FP0i
0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP11
05X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i
0580@@1J03T0DP110580>@1B0000002L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T
06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L
0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T
06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T
0680000000l0a@110P00000B0=ko00d0NoH000<000000?ooo`3oool0AP3oool004`0oooo0P000000
700H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP
000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60020000001d
0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J
03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP000000Y01Z
09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R
0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z
09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R
0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP000000a@110<d0@@350440c@11
0<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@3504420000000O0>Ko003No`00
i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko00000000
NoH008?o001kmP00Pol00?ooo`23o`00NoH008?o001kmP00Pol007_f0023o`00NoH0000000180?oo
o`00C@3oool00`0000004200010P000>010P00030?ooo`0@8000420000T0420006L000000440DP0i
0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP11
0580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i
0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP000000Y01Z0:@0HP2T
06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T
0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T
06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L
0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X000000140a@1100<000000=ko003N
o`003@3No`0507_f00030?ooo`1kmP00NoH000H0NoH000<000000?ooo`3oool0AP3oool004d0oooo
01`0000001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@
60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@600062000P000000
N00i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580000009`0
HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0
HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R000000350440c@110<D0
@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0
@@80000001/0g_l00>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00i_l00=ko003Vo`00g_l0
08?o001kmP00Pol007_f0023o`00NoH008?o001kmP00Pol007_f0023o`00NoH008?o00000000B@3o
ool004d0oooo0P00000I010P00<0000006H0@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP11
05X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i
0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP11
0580>@1B0440FP0i0580@@1B0000002T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L
0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T
06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T
0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T
06X0Y01R0:@0JP00000D0<D0@@030000003No`00g_l000X0g_l03@1kmP000`000000oooo0?ooo`17
0?ooo`00CP3oool06P00000041P001PP000@60006200010H000H800041P001PP000@60006200010H
000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P00P00
0000O01105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J
03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0000002L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z
09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R
0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z
09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP000000a@11
0<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@11
0<D0@@3=0440a@110<d0@@3504420000000H0>Ko003No`00i_l00=ko003Vo`00g_l00>Ko003No`00
i_l000000023o`00NoH008?o001kmP00Pol007_f0023o`00NoH008?o001kmP00Pol007_f0023o`00
0000B@3oool004h0oooo6@0@80030000001X03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0
>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580
@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580
>@1B0440FP0i0580@@1B03T0DP1105X000000:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680
Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680
Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0
Y01R0:@0JP2L0680Y01Z0:@0HP00000F0<D0@@030000003No`00g_l000H0g_l03P1kmP000`000000
oooo0?ooo`170?ooo`00CP3oool06000000041P001PP000@60006200010H000H800041P001PP000@
60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H00@0
000007l0@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP000000W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0
HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z0000
003=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0
@@350440c@110<D0@@3=0440a@110<d0@@350440c@110080000001@0g_l00>Ko003No`00i_l00=ko
003Vo`00NoH008?o001kmP00Pol007_f0023o`00NoH008?o001kmP00Pol007_f0023o`00NoH00000
04X0oooo001>0?ooo`030000000@8000420001D042000`000000J@110580>@1B0440FP0i0580@@1B
03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B
0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J
03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP000000Y01Z09`0HP2T06X0Y01R
0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z
0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R
0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z
09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0000000I0<D0@@040000003No`00g_l0
00000080g_l01@1kmP000`0Y6000NoH007_f000507_f00030000003oool0oooo04P0oooo001?0?oo
o`0F010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H8000
41P001PP000@60006200010H000H800041P001PP00@0000008<0>@1B0440FP0i0580@@1J03T0DP11
05X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i
0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP11
05X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580000009`0HP2T06X0W01R0:@0JP2L
0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T
06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L
0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T
06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP000000c@110<D0@@3=0440a@110<d0@@35
0440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=
0440a@110<d0@@350440c@110<D0@@020000000A0>Ko003No`00000007_f0023o`00NoH008?o001k
mP00:AP007_f0023o`00NoH008?o001kmP00Pol007_f00000000BP3oool004l0oooo5@0@80050000
001Y0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580
@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0
>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580
@@1J0000002T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0
Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680
Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680
000001`0a@110P00000>07_f00030000003oool0oooo04P0oooo001?0?ooo`0E0000000H800041P0
01PP000@60006200010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200
010H000H800041P000@0000008L0@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J
03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0440FP0i0580@@1J03T0DP1105X0>@1B0000002L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z
09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R
0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z
09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R
0:@0JP2L0680Y01Z09`0HP2T06X000000<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@11
0<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@11
0<d0@@350440c@110<D0@@3=04400P0000003@1kmP00Pol007_f0023o`00NoH008?o001kmP00Pol0
07_f0023o`00NoH008?o00000000B`3oool00500oooo4`0@80050000001[03T0DP110580>@1B0440
FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0
DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440
DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP000000Y01Z09`0
HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0
JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0
HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0
JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP0000007P350440
0`000000NoH007_f000907_f00030000003oool0oooo04T0oooo001@0?ooo`0B01PP000@60006200
010H000H800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H800041P0
1P000000UP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580
@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580000009`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L068000000<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440
c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440
a@110<d0@@350440c@1100000023o`00NoH008?o001kmP00Pol007_f0023o`00NoH008?o001kmP00
Pol0000004/0oooo001@0?ooo`030000000@8000420000l042001@000000K0110580>@1B0440FP0i
0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP11
05X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i
0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580000009`0HP2T
06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L
0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T
06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T
0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z000001l0
a@1100<0000007_f001kmP001`1kmP02000004/0oooo001@0?ooo`0A0000000@60006200010H000H
800041P001PP000@60006200010H000H800041P001PP000@60006200010H000H80001P000000UP0i
0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP11
05X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i
0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP11
05X000000:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L
0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T
06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L
0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T
06X0W01R000000350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@35
0440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=
0440a@110<d0@@350440000007_f0023o`00:AP008?o001kmP00Pol007_f0023o`00NoH0000004`0
oooo001A0?ooo`l042001`000000K01105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i
0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP11
05X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i
0580@@1J03T0DP110580>@1B0440FP0i058000000:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T
06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L
0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T
06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T
0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z00000200a@1100<0000007_f000Y60001P1kmP00
0`000000oooo0?ooo`1:0?ooo`00D@3oool03P0@60006200010H000H800041P001PP000@60006200
010H000H800041P001PP000@600062001`000000U`1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580
@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0
>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J0000002T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X000000<d0@@350440
c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440
a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@000000
Pol007_f0023o`00NoH008?o001kmP00Pol007_f00000000C03oool00540oooo00<00000010P000@
80002`0@80070000001^03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580
@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580
>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580
@@1B03T0DP1105X0>@1B0440DP0i0580000009`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680
Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0
Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680
Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP00000O0<D0@@030000001kmP00NoH000D0NoH0
00<000000?ooo`3oool0B`3oool00580oooo00`06200010H000H800041P001PP000@60006200010H
000H800041P001PP000@60080000000^0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J
03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J
03T0DP1105X0>@1B0440FP0i0580@@1J03T0DPP000000600Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680
Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0
W01R0:@0JP2L0680Y01Z0000003=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440
c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440
a@110<d0@@350440c@110<D0@@3=0440a@110000001kmP00Pol007_f0023o`00NoH008?o0000001=
0?ooo`00DP3oool;010P00P0000002`0@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580
>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580
@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0
>@1B0440DP0i0580@@1J03T0DP<0000000<0FP2T0000002/0;@01@2/0;@<0000000/09`0HP2T06X0
Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680
Y01Z0:@0HP2T06X0W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP00000P0<D0@@030000001k
mP00NoH000@0NoH000<000000?ooo`3oool0B`3oool00580oooo00/06200010H000H800041P001PP
000@60006200010H000H800041P001PP00080000000Y03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP1105X0>@1B0440FP0i05800`0000005`1B09`0FP2T05X0W01J0:@000000;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d00d0
000004L0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0
JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0HP2T06X0W01R0:@0JP2L0680Y01Z09`0
HP2T06X000000<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0
@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0
@@3=0440a@110<d0@@350440000007_f0023o`00NoH008?o001kmP00Pol00000001=0?ooo`00DP3o
ool00`0000004200010P0007010P00P0000002L0>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440
DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0
DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440
FP0i05800`00000705X0Y0030000002/0;@0[02d01d0[02d3@0000004`2L0680Y01Z0:@0HP2T06X0
W01R0:@0JP2T0680Y01Z09`0HP2T06X0Y01R0:@0JP2L0680Y01Z0:@0HP2T06X0W01R0:@0JP000000
803504400`000000NoH007_f000207_f00030000003oool0oooo04`0oooo001C0?ooo`08010H000H
800041P001PP000@60006200010H000H80090000000T0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0
DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0`00
0000=`1B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@000000;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@030000000;@2T06X0W01R
0:@0JP2L0680Y01Z09`0HP000000a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@11
0<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@11
0<d0@@350440c@110<D0@@3=0440a@110<d0@@000000Pol007_f0023o`00NoH00000001>0?ooo`00
D`3oool8010P00T000000280>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0
DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440
DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B0P00000=05X0Y0030000002/0;@0[02d03H0
[02d1`00000Q0<D0@@050000001kmP00NoH007_f00000000CP3oool005<0oooo00L0000001PP000@
60006200010H000H800041P000T000000200>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i
0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP11
05X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP<0000004h0FP2T05X0W01J0:@0DP2L05X0
Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@000000;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@30000000R
0<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@11
0<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@11
0<D0@@000000NoH008?o00800000CP3oool005<0oooo00<00000010P000@80000`0@800:0000000M
0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J
03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP1105800`00
000B05X0Y0030000002/0;@0[02d03`0[02d00@000000=h0N`3N07/000007P35044010000000NoH0
07_f0000001?0?ooo`00E03oool01@0H800041P001PP000@6000620000X0000001X0>@1B0440FP0i
0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP11
05X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP<0000005P0FP2T05X0W01J0:@0DP2L05X0
Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580
W01J0:@000000;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@000000=h0L`3V07/0gP1c0P000000803=0440a@110<d0@@350440c@11
0<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@11
0<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@1100000023o`000000C`3oool005@0oooo
100@800:0000000H03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B
03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B0`00000H05X0Y003
0000002/0;@0[02d03`0[02d00<000000=h0N`3N07/00`3N07/2000001/0a@1100<0000007_f0000
0000C`3oool005@0oooo00<00000010H000H80002`0000005@1105X0>@1B0440FP0i0580@@1J03T0
DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440
FP030000001m05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0
Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0000
002d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0000003N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<000000<D0@@3=0440a@110<d0
@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0
@@3=0440a@110<d0@@350440c@110<D0@@3=04400P00001@0?ooo`00E@3oool2010P00/000000180
>@1B0440DP0i0580@@1J03T0DP110580>@1B0440FP0i0580@@1B03T0DP1105X0>@1B0440DP0i0580
@@1J03T0DP110583000001h0FP2T00<000000:`0]02/0;@0?02/0;@00`000000gP1k0=h0N`060=h0
N`8000006@3504400`000000oooo0?ooo`1>0?ooo`00E@3oool00`0@60000000000000090000000@
03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP1105X0>@1B
0440FP<0000008D0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@000000;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0000003V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`000000c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440
a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440
00000500oooo001E0?ooo``0000000d0@@1B03T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580
>@1B0440FP0i0580@@1B00<000008`1J0:@00`000000[02d0:`0]00n0:`0]0030000003N07/0gP1k
00P0gP1k0P00000G0<D0@@030000003oool0oooo04d0oooo001E0?ooo``0000000/0>@1B0440FP0i
0580@@1J03T0DP1105X0>@1B0440FP0i0580@@1J03T0DP020000002<05X0Y01J09`0FP2T0580W01J
0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`000000:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@000000iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<000000<D0@@3=0440a@110<d0@@350440c@110<D0@@3=
0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@00
001?0?ooo`00E@3oool;0000000903T0DP1105X0>@1B0440DP0i0580@@1J03T0DP110580>@1B00<0
0000:01J0:@00`000000[02d0:`0]00n0:`0]0030000003N07/0gP1k00/0gP1k0P00000D0<D0@@03
0000003oool0oooo04d0oooo001D0?ooo``0000000H0@@1J03T0DP1105X0>@1B0440FP0i05830000
001l05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W0000000
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0000003V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`80000001@0a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@35
0440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@11000004h0oooo001D0?ooo``0
000000<0>@1B0440DP0i05800`00000^05X0Y0030000002/0;@0[02d03h0[02d00<000000=h0N`3N
07/03`3N07/00`000000a@110<D0@@0@0<D0@@030000003oool0oooo04`0oooo001D0?ooo`/00000
08T0>@1B000000000000000005X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W0000000[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0000003V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`020000000A0<d0@@350440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=
0440a@110<d0@@350440c@110<D0@@000000CP3oool005<0oooo3@00000d05X0Y0030000002/0;@0
[02d03h0[02d00<000000=h0N`3N07/04P3N07/00`000000a@110<D0@@0>0<D0@@030000003oool0
oooo04/0oooo001C0?ooo``0000008`0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W0000000
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0000003V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`80000000l0a@110<d0@@35
0440c@110<D0@@3=0440a@110<d0@@350440c@110<D0@@3=0440a@110<d0@@000000C@3oool00580
oooo3@00000e05X0Y0030000002/0;@0[02d03h0[02d00<000000=h0N`3N07/05@3N07/00`000000
a@110<D0@@0<0<D0@@030000003oool0oooo04X0oooo001B0?ooo`/000000940000i0000001J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0
FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L0000002/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d000000>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0080000000d0c@110<D0@@3=0440a@110<d0@@350440
c@110<D0@@3=0440a@110<d0@@350440000004`0oooo001B0?ooo`X000000P0004400`000000FP2T
05X0Y00c05X0Y0030000002/0;@0[02d03h0[02d00<000000=h0N`3N07/0603N07/2000000X0a@11
00<000000?ooo`3oool0BP3oool00540oooo2`000000XP000440000005X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J
0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L0000002/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0000003N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`000000a@110<d0@@350440c@110<D0@@3=
0440a@110<d0@@350440c@11000004/0oooo001A0?ooo`X000000P0004400`000000FP2T05X0Y00d
05X0Y0030000002/0;@0[02d03l0[02d00<000000=h0N`3N07/06P3N07/2000000P0a@1100<00000
0?ooo`3oool0B@3oool00540oooo2@000000Y0000440000i0000@@000000FP2T05X0W01J0:@0DP2L
05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T
0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L
05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T
05X0W01J0:@0DP2L05X0Y01J09`000000:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@000000=h0L`3V07/0gP1c
0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k
0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0000003=0440a@11
0<d0@@350440c@110<D0@@3=04400000B`3oool00500oooo2P0000030000@@030000001J0:@0FP2T
03@0FP2T00<000000:`0]02/0;@0?`2/0;@00`000000gP1k0=h0N`0M0=h0N`8000001P3504400`00
0000oooo0?ooo`180?ooo`00D03oool90000002V0000>@000440000i0000@@000000FP2T0580W01J
0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`000000:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@000000=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c000000350440c@110<D0@@3=0440a@11000004X0oooo001?0?ooo`T000001@0004400`00
0000FP2T05X0Y00d05X0Y0030000002/0;@0[02d03l0[02d00<000000=h0N`3N07/0803N07/20000
00@0a@1100<000000?ooo`3oool0A`3oool004l0oooo2@000000X`000440000i0000@@0003T00011
0000001J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L
05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T
05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L
05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W0000000[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]0000000gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c
0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k
0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/00P0000000`350440c@11000000190?ooo`00
C`3oool8000000H0001100<0000005X0Y01J0:@0=01J0:@00`000000[02d0:`0]00o0:`0]0030000
003N07/0gP1k02@0gP1k00<000000<D0@@000000B@3oool004h0oooo20000000Z0000440000i0000
@@0003T000110000>@000000FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580
W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0
Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0
W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L0000
002/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0
]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0
_@2/0;@0]02m0:`0]02d0;d0[02d0000003N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0
L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0
N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0
L`<00000B03oool004h0oooo200000060000@@030000001J0:@0FP2T03D0FP2T00<000000:`0]02/
0;@0?`2/0;@00`000000gP1k0=h0N`0W0=h0N`030000003oool0oooo04H0oooo001>0?ooo`L00000
0:`0000i0000@@0003T000110000>@000440000i0000001B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J
0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`000000:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@000000=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<00000B03oool004d0oooo1`0000080000@@030000001J
0:@0FP2T03D0FP2T00<000000:`0]02/0;@0?`2/0;@00`000000gP1k0=h0N`0W0=h0N`030000003o
ool0oooo04H0oooo001=0?ooo`L000000:`000110000>@000440000i0000@@0003T000110000>@00
0000FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L0000002/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0000003N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0P000017
0?ooo`00C@3oool6000000T0001100<0000005X0Y01J0:@0=01J0:@00`000000[02d0:`0]0110:`0
]0030000003N07/0gP1k02L0gP1k00<000000?ooo`3oool0A@3oool004`0oooo1P000000/0000440
000i0000@@0003T000110000>@000440000i0000@@0003T000000580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0
FP2L05X0Y01B09`0FP2T0000002d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d000000>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/00000A`3oool004`0oooo1P00000:0000
@@030000001J0:@0FP2T03@0FP2T00<000000:`0]02/0;@0@@2/0;@00`000000gP1k0=h0N`0W0=h0
N`030000003oool0oooo04D0oooo001;0?ooo`H000000;00000i0000@@0003T000110000>@000440
000i0000@@0003T000110000>@000000FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0
FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
00000;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@000000iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`800000AP3oool004/0oooo1@00000;0000@@030000001J0:@0FP2T
03D0FP2T00<000000:`0]02/0;@0@@2/0;@00`000000gP1k0=h0N`0W0=h0N`800000AP3oool004/0
oooo1@000000/@000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000001J
0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J
0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B
09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@000000;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@000000iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`02
000004H0oooo001:0?ooo`D00000300004400`000000FP2T05X0Y00e05X0Y0030000002/0;@0[02d
0440[02d00<000000=h0N`3N07/0:03N07/00`000000oooo0?ooo`140?ooo`00BP3oool40000002d
0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000i0000@@000000FP2T
05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L
05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T
0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L
05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0000002d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d000000>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c
0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k
0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c
0P0000150?ooo`00BP3oool4000000d0001100<0000005X0Y01J0:@0=@1J0:@00`000000[02d0:`0
]0110:`0]0030000003N07/0gP1k02P0gP1k0P0000150?ooo`00B@3oool40000002e0000>@000440
000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000005X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0
FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y0000000]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0000003V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`020000
04D0oooo00190?ooo`<000003`0004400`000000FP2T05X0Y00e05X0Y0030000002/0;@0[02d0440
[02d00<000000=h0N`3N07/0:03N07/2000004D0oooo00190?ooo`<000000;T000110000>@000440
000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000005X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0
FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y0000000]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0
[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0
]02m0000003V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`000000
FP00000000140?ooo`00B03oool3000000l0001100<0000005X0Y01J0:@0=@1J0:@7000003l0[02d
00<000000=h0N`3N07/0:03N07/2000004@0oooo00180?ooo`80000004D000110000>@000440000i
0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000i0000001J09`0FP2T
0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L
05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T
05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L
05X0Y01J09`0FP2T0580W01J0:@00`0000001`1Z0>H000000;@0kP2d0>H0]03^0;@0iP2d0>h03000
0000GP2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d
0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m
0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]0000000gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c
0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k
0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c
0>H0N`3N07<0iP1k0=h0L`3V07/2000004@0oooo00170?ooo`<00000400004400`000000FP2T05X0
Y00_05X0Y0<000000P1Z0=h00`1Z0>H0JP3N0000000A0;@0kP/00000:02/0;@00`000000gP1k0=h0
N`0X0=h0N`800000A03oool004L0oooo0P000000@@0003T000110000>@000440000i0000@@0003T0
00110000>@000440000i0000@@0003T000110000>@000440000i0000001B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0
FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L0080000002@0
JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0000002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H<0000001:0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/
0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d0;d0[02d0;@0_@2/0;@0]02m0:`0]02d
0;d0[02d0;@0_@2/0;@0]02m0:`0]0000000gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/000000680000000130?ooo`00A`3oool00`00000000110000@@0@0000@@03
0000001J0:@0FP2T02X0FP2T0`0000000`1Z0=h0JP3V06X0gP0206X0gP0506X0iP1Z0=h0JP3N06X0
gP000000:02d0>h;00000140[02d00<000000=h0N`3N07/0:03N07/00`000000FP00000000130?oo
o`00AP3oool20000000l0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440
000i0000@@0003T000110000>@000440000i0000001J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0
FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0
DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0
FP2T0580W01J0:@0FP2L0`000000@01Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP000000]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h<0000000c0:`0]02d0;d0[02d0;@0
_@2/0;@000000=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0
L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0
N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0000
001R0000000004<0oooo00160?ooo`0300000000044000110140001100<0000005X0Y01J0:@0901J
0:@30000000306X0gP1Z0>H0JP3N0080JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0306X0
iP1Z0=h0000003l0]03^1P00000Z0=h0N`030000001J0000000004<0oooo00160?ooo`0h00000000
03T000110000>@000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@00
0440000i0000@@0003T000000580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J
0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`30000001G06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0000
002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V00<0000002T0gP1c0>H0N`3N07<0iP1k0=h0
L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0
N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0
L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`02000004<0oooo00160?ooo`0300000000044000110140
001100<0000005X0Y01J0:@07`1J0:@20000000306X0gP1Z0>H0JP3N0080JP3N00D0JP3V06X0gP1Z
0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h00`000000]03^0;@0kP12
0;@0kP030000003V0<d0iP35008000009`3N07/00`000000FP00000000120?ooo`00AP3oool0<`00
0000000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000i0000@@00
03T000110000>@000440000005X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J
09`0FP2T0580W01J0:@0FP2L05X0Y0030000002;06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z
0>H000000;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H000000>H0a@3^0<d0iP350>h0c@00
0000iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`000000FP00000000120?ooo`00A@3oool0
0`00000000110000@@0A0000@@030000001J0:@0FP2T01X0FP2T0`0000001@1Z0>H0JP3N06X0gP1Z
0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z
0>H00`1Z0=h00`1Z0>H0JP3N000000140;@0kP060000003V0<d0iP350>H0c@3V0<D0iP3=0P00000T
0=h0N`030000001R000000000480oooo00150?ooo`0^000000000440000i0000@@0003T000110000
>@000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000005X0
Y01B09`0FP2T05X0W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0
W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y0<0000006X0JP3V0680gP1Z0>H0JP3N
06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V
06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP000000]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP000000iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350P0000009@3V07/0
gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`3N07<0000005X000000000@P3oool004D0oooo00<000000000@@0004404@0004400`00
0000FP2T05X0Y00D05X0Y0<0000000D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0
JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0
JP3N06X0iP0306X0gP030000002d0>h0]03^0480]03^00/000000>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0000000Q0=h0N`040000001J0000FP0000000440oooo00150?ooo`0Y0000
00000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000i0000
@@0003T000110000>@000440000005X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0
W01J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`00P000000L`1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V0000002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0000003V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d00P0000008`3N07<0iP1k0=h0L`3V07/0gP1c0>H0
N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0
L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0000001R000000000440
oooo00150?ooo`0300000000044000110140001100<0000005X0Y01J0:@03`1J0:@3000000<0JP3N
00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z
0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0306X0iP1Z
0=h0000004@0]03^00d000000>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V
0<d0iP35008000007P3N07/00`000000FP00000000110?ooo`00A@3oool08`00000000110000>@00
0440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440000i0000@@00
03T000110000001J0:@0DP2L05X0Y01J09`0FP2T0580W01J0:@0FP2L05X0Y01B09`0FP2T05X0W01J
0:@0DP2L00<0000009d0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0000002d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0000003V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0000003V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N
07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0000001R000000000440oooo00140?ooo`030000
0000044000110180001100<0000005X0Y01J0:@02@1J0:@3000000<0JP3N00D0JP3V06X0gP1Z0=h0
JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0
JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H0
0`1Z0=h00`000000]03^0;@0kP120;@0kP0@0000003V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@8000006`3N07/010000000FP00068000000010
0?ooo`00A03oool07P000000000i0000@@0003T000110000>@000440000i0000@@0003T000110000
>@000440000i0000@@0003T000110000>@000440000i0000001B09`0FP2T05X0W01J0:@0DP2L05X0
Y01J09`0FP2T0580W0<0000008D0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V
06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N
06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V
0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V0000002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0000003V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350080000001d0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c
0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k
0000001R0000FP00000000100?ooo`00A03oool00`00000000110000@@0A0000@@030000001J0:@0
FP2T00D0FP2T0P00000306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0
gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0
gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00L0JP3V06X0gP1Z0=h0JP3N06X0
iP1Z0=h0000004@0]03^01D000000>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@000000603N07/010000000FP0005X0
000000100?ooo`00A03oool06@000000000i0000@@0003T000110000>@000440000i0000@@0003T0
00110000>@000440000i0000@@0003T000110000>@000440000i0000001J09`0FP2T0580W01J0:@0
0`000000S@1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0
JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0
JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0
HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP000000]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP000000iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@020000000J0=h0L`3V07/0gP1c0>H0N`3N07<0
iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0
gP1c0>H0N`000000HP0005X0000000100?ooo`00A03oool00`00000000110000@@0A0000@@030000
001J0:@00000008000000P1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z
0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z
0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z
0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0000004@0]03^01P000000>H0c@3V0<D0iP3=0>H0a@3V
0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V
0<D0iP3=0>H0a@00000F0=h0N`040000001R0000FP00000003l0oooo00140?ooo`0D0000000003T0
00110000>@000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000440
000i0000@@0003T20000002F06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z
0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R
0=h0JP3V0000002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0000003V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@3^0<d0iP350P000000603V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0
N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0000001J0000HP000000
03l0oooo00130?ooo`030000000004400011014000110P0000001@1Z0>H0JP3N06X0gP1Z0=h0JP3V
00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z
0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP05
06X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00<0JP3V
06X0gP000000A02d0>h06P000000iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0P00000B0=h0N`040000001J0000FP00000003l0oooo00130?ooo`0D000000000440000i0000@@00
03T000110000>@000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@00
04420000002a06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP000000]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP000000iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D000000=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0
L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0000005X0001R0000000003l0
oooo00130?ooo`0300000000044000110100001100<0000000P0JP0000000P1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N
06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N
06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V
00<0JP3N00<000000;@0kP2d0>h0@P2d0>h07@000000iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35008000003`3N07/010000000HP0005X00000000o0?ooo`00
@`3oool0]000000000110000>@000440000i0000@@0003T000110000>@000440000i0000@@0003T0
00110000>@000440000i0000@@000000201c00P0JP000000HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0
JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0
JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0
HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0
JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V0000002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0000003V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@8000000140gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V
07/0gP1c0000001J0000HP000000000o0?ooo`00@`3oool00`00000000110000@@0>0000@@060000
000806X0201Z00P0JP000000JP3V0`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V
06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N
06X0gP1Z0>H00`1Z0=h01`1Z0>H0JP3N06X0gP1Z0=h0JP3V06X0gP000000A02d0>h08P000000iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@00000=0=h0N`040000001J0000HP00000003h0oooo00130?ooo`2g000000000440000i0000
@@0003T000110000>@000440000i0000@@0003T000110000>@000440000i0000@@0003T0000000P0
JP0807<0201Z0000001Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H000000;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H000000>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350080
000000l0iP1k0=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/0gP1c0>H0N`000000HP0005X0
00000000?P3oool004<0oooo00<000000000@@0004403@0004400`000000201Z00P0JP0200P0JP04
0000001Z0=h0JP3N06X0iP<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0
JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0
JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0
JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N000000140;@0kP0T0000003V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0P0000090=h0N`040000001J0000FP00000003h0oooo00120?ooo`390000000003T000110000
>@000440000i0000@@0003T000110000>@000440000i0000@@0003T000110000>@000000201Z00P0
L`0806X0201c00P0JP000000HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V0000002d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0000003V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D000000=h0L`3V07/0gP1c0>H0N`3N07<0iP1k0=h0L`3V07/000000680
001J0000000003h0oooo00120?ooo`03000000000440001100`0001100<0000000P0JP0806X01008
06X00`000000JP3V06X0gP0206X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N
06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N
06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00P1Z0=h00`000000]03^0;@0kP110;@0kP0W
0000003V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35008000001P3N07/010000000FP000680
0000000n0?ooo`00@P3oool0_`000000000i0000@@0003T000110000>@000440000i0000@@0003T0
00110000>@000440000i0000@@000000201c00P0JP0807<0201Z00P0L`0806X0000006X0gP1Z0>H0
HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0
JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0
JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0
JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h000000;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP000000iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0080000000P0gP1c0>H0N`3N07<0iP1k0000001R0000FP00000003h0oooo00120?ooo`030000
00000440001100/0001100<0000000P0JP0806X01@0806X010000000JP3N06X0gP1Z0>H306X0gP05
06X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V
06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0606X0iP1Z0=h0JP3N
06X0gP1Z0>H00000@`2d0>h0;0000000iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D00000103N07/00`000000FP000000000n0?ooo`00@P3oool0`P000000000i0000
@@0003T000110000>@000440000i0000@@0003T000110000>@000440000000P0L`0806X0201c00P0
JP0807<0201Z00P0L`0806X000000680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h000000;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP000000iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350P0000001@3V07/0gP1c
0000001J0000000003h0oooo00120?ooo`03000000000440001100X0001100<0000000P0JP0806X0
1P0806X00`000000JP3V06X0gP0206X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0
JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0
JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0
JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00P1Z0=h00`000000]03^0;@0kP110;@0
kP0^0000003V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@<0000000<0HP0005X000000000?@3oool00440oooo0</000000000@@0003T000110000
>@000440000i0000@@0003T000110000>@000440000i0000000806X0201c00P0JP0807<0201Z00P0
L`0806X0201c00P0JP000000JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP000000]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0000003V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350000
001J0000HP000000000m0?ooo`00@@3oool00`00000000110000@@090000@@030000000806X0201Z
00T0201Z00<0000006X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V
06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N
06X0gP1Z0>H00`1Z0=h01P1Z0>H0JP3N06X0gP1Z0=h0JP3V00000480]03^038000000>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=00000080FP0000<000000?ooo`3oool0>`3oool00440oooo0</000000000@@0003T000110000
>@000440000i0000@@0003T000110000>@000000201Z00P0L`0806X0201c00P0JP0807<0201Z00P0
L`0806X0201c00P0JP0807<0000006X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP000000]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h000000>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350000
001J0000HP000000000m0?ooo`00@@3oool00`00000000110000@@080000@@030000000806X0201Z
00X0201Z00D0000006X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z
0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP05
06X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V
06X0gP1Z0=h0JP3N06X0iP0306X0gP0406X0iP1Z0=h0JP3N00000480]03^034000000>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0080000000<0FP000000003oool0?03oool00440oooo0<L000000000@@0003T000110000>@00
0440000i0000@@0003T000110000000807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`08
06X0201c00P0JP0807<0000006X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z
0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R
0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h0JP3V0680gP000000]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h000000>h0c@3V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP3500800000
00<0HP000000003oool0?03oool00440oooo00<000000000@@0004401P0004400`000000201Z00P0
JP0<00P0JP030000001Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0
iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0
gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0
gP1Z0=h0JP3V00<0JP3N00H0JP3V06X0gP1Z0=h0JP3N06X0iP0000120;@0kP0a0000003V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@020000000305X000000000oooo03`0oooo00110?ooo`37000000000440000i0000@@0003T0
00110000>@000440000i0000000806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0
201Z00P0L`0806X0201c0000001Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0
JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0
JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0
JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0
HP3N06X0iP1Z0=h000000;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0000003^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@020000
00030680001J0000000003`0oooo00100?ooo`03000000000440001100H0001100<0000000P0JP08
06X03@0806X01@000000JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP03
06X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N
00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z
0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00@0JP3V06X0gP1Z0=h00000@P2d0>h0<@000000iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d00P00000205X000030000003oool0oooo03X0oooo00100?ooo`3=0000000003T000110000
>@000440000i0000@@0003T0000000P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0
L`0806X0201c00P0JP0807<0201Z00P0L`000000JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N0000002d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP000000kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0000007<0<@000000FP000000000l0?ooo`00@03oool00`00000000110000@@040000@@03
0000000806X0201Z00l0201Z00<0000006X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V
00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z
0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP05
06X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01P1Z0>H0JP3N06X0gP1Z0=h0JP3V00000480]03^03H0
00000>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0000001c03T0000006800000000l0?ooo`00@03oool0c@000000000i0000
@@0003T000110000>@000440000000P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0
JP0807<0201Z00P0L`0806X0201c00P0JP0807<0000006X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP000000]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h000000>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0000007<0>@1c0340000005X000000000?03oool00400oooo00<000000000@@0004400`00
04400`000000201Z00P0JP0@00P0JP050000001Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N
06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N
06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h0101Z0>H0JP3N06X0gP0000120;@0
kP0a0000003V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350000000207<0>@030000001J0000000003`0oooo00100?ooo`3=00000000
03T000110000>@000440000000P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`000000JP3V0680gP1Z0>H0JP3N06X0iP1R
0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z
0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N0000002d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP00
0000kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@000000N`0i07<0<@000000FP000000000l0?ooo`00?`3oool00`00000000110000
@@020000@@030000000806X0201Z0180201Z00<0000006X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0
gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0
gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0
iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01P1Z0>H0JP3N06X0gP1Z0=h0JP3V0000
0480]03^034000000>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0000000<0L`0i00<0000005X000000000>`3oool003l0oooo0<l0
00000000@@0003T000110000>@000000201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0
201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`000000JP3V06X0gP1Z0>H0
HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0
JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0
JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0
JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N0000002d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0
]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0
]03V0;@0kP000000kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@000000L`0i07<0<@1k03T00000068000000000>`3oool003l0oooo
00D000000000@@00044000110000000E00P0JP050000001Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z
0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z
0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z
0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h0101Z0>H0JP3N06X0gP00
00120;@0kP0a0000003V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350000000307<0>@030000001J0000000003/0oooo000o0?ooo`3?
000000000440000i0000000806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z
00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0000006X0iP1R0=h0JP3V
06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N
06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V
0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N
06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP000000]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h000000>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0000007/0>@1c0340L`0i0000001R0000000003/0oooo000o0?oo
o`040000000004400011000001H0201Z00<0000006X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z
0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z
0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP03
06X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01P1Z0>H0JP3N06X0gP1Z0=h0JP3V00000480
]03^034000000>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0000000<0L`0i00<0000005X000000000>`3oool003l0oooo0<d00000
0000@@000000201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c
00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`000000JP3V06X0gP1Z0>H0HP3N
06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V
0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N
06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V
06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N0000002d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP000000kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@000000L`0i07<0<@1k03T0L`0a00800000>`3oool003h0oooo00<00000
0000@@000000600806X01@000000JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N
06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V
00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z
0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00@0JP3V06X0gP1Z0=h00000@P2d0>h0<@000000
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@000000101c03T2000003/0oooo000n0?ooo`8000000<`0201c00P0JP0807<0201Z00P0
L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0
JP0807<0201Z00P0L`0806X0201c0000001Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680
gP1Z0>H0JP3N06X0iP1R0=h000000;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0
iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0000003^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0000
001k03T0L`0a07<0>@1c0342000003/0oooo000n0?ooo`8000006@0806X00`000000JP3N06X0iP03
06X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N
00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z
0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0606X0iP1Z
0=h0JP3N06X0gP1Z0>H00000@P2d0>h0<@000000iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@000000101c03T00`000000FP000000
000j0?ooo`00?P3oool0c`000000201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c
00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z
00P0L`000000JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V
06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N
06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V
0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N
0000002d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP000000kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@000000L`0i07<0<@1k03T0L`0a
07<0>@02000003X0oooo000n0?ooo`030000000806X0201Z01P0201Z00D0000006X0gP1Z0=h0JP3N
06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V
00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z
0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP04
06X0iP1Z0=h0JP3N00000480]03^034000000>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0000000D0L`0i0P00000j0?ooo`00?P3o
ool0E@000000201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z
00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`000000JP3V
0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N
06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V
06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N
06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H01`000000L`2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V
0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^
0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h00000
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0000007/0>@1c0340L`0i07<0<@1k03T00P00000j0?ooo`00?P3oool00`000000201Z
00P0JP0H00P0JP030000001Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP05
06X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V
06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N
06X0gP1Z0=h0JP3V00<0JP3N00/0JP3V000000000000000007/0o`000000_@3o0;@0o`2m0?l0]03o
0;d0o`0;00000380]03^034000000>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0000000D0L`0i0P00000j0?ooo`00?P3oool0C`00
0000201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`08
06X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`000000JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z
0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R
0=h0JP3V06X0gP1Z0>H00`0000005@1k0?l0L`3o07/0o`1c0?l000000;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`0;0000001M0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d
0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d
0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0000003^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0000001c03T0L`0a07/0>@1c
0340L`0i00800000>P3oool003h0oooo00<0000000P0JP0806X0600806X01@000000JP3N06X0gP1Z
0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z
0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP03
06X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H00000000000000000N`3o00<0L`3o
01l0N`3o07<0o`1c0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o00`000006`2d0>h0<@000000iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@0000001P1c03T00`000000oooo0?ooo`0h0?oo
o`00?P3oool0B@000000201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`00
0000JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z
0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R
0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H00`000000<P1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l000000;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o2`000000A`2d0>H0]03^0;@0iP2d0>h0]03V0;@0
kP2d0>H0]03^0;@0iP2d0>h0]03V0;@0kP2d0>H0]03^0;@0iP2d0>h000000>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@000000L`0a07/0
>@1c0340L`0i07<0<@1k03T0L`0a00800000>@3oool003h0oooo00<0000000P0JP0806X06@0806X0
0`000000JP3V06X0gP0206X0gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0
gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0
gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0000000D0N`3o07<0o`1c0?l0L`3o07/0
o`0307<0o`0h07/0o`1c0?l0L`3o07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l;000000D0
]03^030000000>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@00000707<0>@800000>@3oool003h0oooo04<0000000P0JP0807<0201Z00P0
L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0
JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z0000001Z0=h0JP3V0680gP1Z0>H0JP3N06X0
iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0
gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0
iP1Z0=h0JP3V00<0000004h0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l60000000f0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=
0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@000000L`0a07<0>@1c0340N`0i
07<0<@1c03T0L`0a0P00000i0?ooo`00?P3oool00`000000201Z00P0JP0I00P0JP040000001Z0=h0
JP3N06X0iP<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z
0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP03
0000000507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o
04H0N`3o07<0o`1c0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0`000000;@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0000000707<0>@800000
>@3oool003h0oooo03d0000000P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`08
06X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z0000001R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R
0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V00<0000005`0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o0000002d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`80000003@0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0000007<0<@1k03T0L`0a07<0>@1c0340N`0i07<0
<@1c03T00000>@3oool003h0oooo00<0000000P0JP0806X06@0806X00`000000JP3V06X0gP0206X0
gP0506X0iP1Z0=h0JP3N06X0gP1Z0>H00`1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00D0
JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP00000000000000001k0?l00`1c0?l01@1k0?l0
L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1=07/0o`1c0?l0
L`3o07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0
0P000000:@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0000000P0L`0i00<0
00000?ooo`3oool0=`3oool003h0oooo03H0000000P0JP0807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`08
06X0201c00P0JP0807<0201Z0000001Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z
0=h40000002H07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0000
003V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@000000L`0a07<0>@1c0340N`0i07<0
<@1c03T0L`0a07/0>@00000i0?ooo`00?P3oool00`000000201Z00P0JP0I00P0JP040000001Z0=h0
JP3N06X0iP<0JP3N00D0JP3V06X0gP1Z0=h0JP3N06X0iP0306X0gP0506X0iP1Z0=h0JP3N06X0gP1Z
0>H00`1Z0=h30000000307<0o`1k0?l0L`3o0080L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0
o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o04h0
N`3o07<0o`1c0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l20000000V0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V
0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V
0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@00000807<0>@030000
003oool0oooo03L0oooo000o0?ooo`0_0000000807<0201Z00P0L`0806X0201c00P0JP0807<0201Z
00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c
00P0JP0807<0201Z0000001R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h0JP3V0680gP1Z0>H0JP3N
06X0iP1R0=h0JP3V06X0gP1Z0>H0HP3N06X0iP1Z0=h00`000000L01c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l20000000/0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0000007<0<@1k03T0L`0a07<0>@1c0340
N`0i07<0<@1c03T2000003P0oooo000o0?ooo`030000000806X0201Z01P0201Z00<0000006X0iP1Z
0=h00P1Z0=h01@1Z0>H0JP3N06X0gP1Z0=h0JP3V00<0JP3N00@0JP3V06X0gP1Z0=h0JP3N0`000000
0`1c0?l0N`3o07<0o`0207<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0
o`1k0?l00`1c0?l0D01k0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0P0000008P3V0<d0iP350>H0c@3V0<D0iP3=
0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP35
0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@00000907<0
>@030000003oool0oooo03H0oooo000o0?ooo`0Y0000000807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`08
06X0201c00P0JP0807<0201Z0000001Z0=h0JP3V0680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP1Z
0>H0HP3N06X0iP1Z0=h00`000000NP1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0P000000:P3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0
a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0000007<0<@1c03T0L`0a07/0
>@1c0340L`0i07<0<@1k03T0L`0a000003P0oooo000o0?ooo`030000000806X0201Z01P0201Z00@0
000006X0gP1Z0=h0JP3V0`1Z0=h0101Z0>H0JP3N06X0gP1Z0=h30000000307<0o`1k0?l0L`3o0080
L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0
1@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0
o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0LP000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000003^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l000000>H0
a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0000
00T0L`0i00<000000?ooo`3oool0=P3oool003l0oooo02<0000000P0L`0806X0201c00P0JP0807<0
201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0
201c00P0JP0807<0201Z00P0L`0806X000000680gP1Z0>H0JP3N06X0iP1R0=h0JP3V06X0gP030000
002307<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l00P0000009`3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0
kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0000007<0<@1k03T0
L`0a07<0>@1c0340N`0i07<0<@1c03T0L`0a0000000h0?ooo`00?`3oool00`000000201Z00P0JP0H
00P0JP030000001Z0>H0JP3N0080JP3N0`0000000`1c0?l0N`3o07<0o`0207<0o`0507/0o`1c0?l0
L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0
L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0
N`3o00<0L`3o05/0N`3o07<0o`1c0?l0L`3o07/0o`1c0?l000000;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0080000001/0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0
iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@0000002@1c03T00`000000oooo0?ooo`0f0?ooo`00?`3oool07@000000201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`08
06X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP000000JP3N00<0000008d0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l00P0000008`3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@00
0000L`0a07<0>@1c0340N`0i07<0<@1c03T0L`0a07/0>@1c0340000003P0oooo000o0?ooo`030000
000806X0201Z01P0201Z0P0000000`1c0?l0N`3o07<0o`0207<0o`0507/0o`1c0?l0L`3o07<0o`1k
0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`03
07<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o
00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1f07/0o`1c0?l0L`3o07<0o`000000]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0000003^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0000003V0<d0iP350>H0c@3V
0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V
0<d0iP350>H0c@3V0<D0iP3=000000T0L`0i00<000000?ooo`3oool0=P3oool003l0oooo01X00000
00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c
00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`80000009@0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o0000002m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0P000000803V0<D0kP3=0>H0a@3^
0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V
0<D0kP3=0>H0a@000000L`0a07/0>@1c0340L`0i07<0<@1k03T0L`0a07<0>@1c03400000>03oool0
03l0oooo00<0000000P0JP0806X05P0806X010000000403=0000001k0?l307<0o`0507/0o`1c0?l0
L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0
L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0
N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1R07/0o`1c0?l0L`3o07<0o`1k0?l0
L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l20000000D0>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V
0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@00000907<0>@030000003oool0oooo03H0
oooo000o0?ooo`2d0000000807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c
00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP000000403=
01P0e@000000N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l00000
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0000003^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0P000000703V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0
iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350000001c0340L`0i07<0<@1k03T0L`0a07<0>@1c0340
N`0i07<0<@00000h0?ooo`00?`3oool00`000000201Z00P0JP0E00P0JP070000000@0<d0603=0100
c@000000L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0
o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0
o`0307<0o`1e07/0o`1c0?l0L`3o07<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`000000iP350>H0
c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0iP350>H0c@3V0<D0000000X0
L`0i00<000000?ooo`3oool0=P3oool003l0oooo0;L0000000P0L`0806X0201c00P0JP0807<0201Z
00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c
00P0JP000000403=01P0e@0@0<d0603E0000001k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l00P0000006@3^0<d0iP35
0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0>H0a@3^0<d0000007<0>@1c0340N`0i
07<0<@1c03T0L`0a07/0>@1c0340L`0i07<0<@000000>03oool003l0oooo00<0000000P0JP0806X0
4`0806X00`000000403=01P0c@030100c@050000001c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0
L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0
L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0
L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0I@1k0?l0L`3o0000002d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0080000000`0iP350>H0c@3V0<D0iP3=0>H0a@3V0<d0
iP350>H0c@3V0<D0iP3=0>H0a@00000:07<0>@030000003oool0oooo03H0oooo000o0?ooo`2k0000
000807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0
L`0806X0201c00P0JP0807<0201Z00P0L`000000603E0100c@0H0=D0403=01P0e@000000N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000
003^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`020000000E0>h0c@3V0<D0kP3=0>H0a@3^0<d0iP350>h0
c@3V0<D0kP3=0000001k03T0L`0a07<0>@1c0340N`0i07<0<@1c03T0L`0a07/0>@1c0340000003P0
oooo000o0?ooo`030000000806X0201Z0180201Z00<0000001P0c@0@0<d00P0@0<d01@0H0<d0403=
0000001c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o
07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o
07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o
00<0L`3o06/0N`3o07<0o`1c0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`02000000080>H0a@3V0<d0iP350>H0c@3V0<D0iP3=0>H0a@00000:07<0
>@030000003oool0oooo03H0oooo000o0?ooo`3B0000000807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0000001P0e@0@
0<d0603E0100c@0H0=D0403=01P0e@0@0<d0000007<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l000000>H0a@3^0<d0iP350>h0c@3V0<D0kP3=0000001c03T0L`0a07/0>@1c
0340L`0i07<0<@1k03T0L`0a07<0>@1c03400000>03oool003l0oooo00<0000000P0JP0806X04008
06X00`000000603=0100c@020100c@0601P0c@0@0<d0403=0100c@0H0<d000000P1c0?l01@1k0?l0
L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0
L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0
L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0L01k0?l0L`3o07<0o`1c0?l0
N`3o07<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l2000000050>H0c@3V0<D0iP3=0>H0a@0000002@1c03T00`000000oooo0?ooo`0g
0?ooo`00?`3oool0`P000000201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0
L`0806X0201c00P0JP0807<0201Z00P0L`0806X000000100c@0H0=D0403=01P0e@0@0<d0603E0100
c@0H0=D0403=0000001c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o0000
002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0P0000003@3V0<D0kP3=0000001k03T0L`0a07<0>@1c0340N`0i07<0<@1c03T0L`0a
07/0>@000000>@3oool003l0oooo00<0000000P0JP0806X03`0806X01@000000403=0100c@0@0<d0
603=00<0403=00D0603=0100c@0@0<d0000007/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l0
0`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0
o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0
N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1b07/0o`1c0?l0L`3o07<0o`1k0?l000000;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0`00000907<0>@030000003oool0oooo03L0oooo000o0?ooo`3A0000000807<0201Z00P0L`08
06X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X000000100c@0H
0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0000007<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0000001c
03T0L`0a07/0>@1c0340L`0i07<0<@1k03T0L`0a07<0>@000000>@3oool003l0oooo00<0000000P0
JP0806X03@0806X01@000000403=0100c@0@0<d0603=00<0403=00H0603=0100c@0@0<d0403=01P0
c@00000207<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o
00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c
0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`05
07/0o`1c0?l0L`3o07<0o`1k0?l00P1c0?l0L0000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000003^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`00000907<0
>@030000003oool0oooo03L0oooo000o0?ooo`360000000807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0L`000000603E0100c@0H0=D0403=01P0e@0@
0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0000001k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0P0000002@1c0340L`0i07<0
<@1k03T0L`0a07<0>@1c0340N`0i0000000i0?ooo`00?`3oool00`000000201Z00P0JP0<00P0JP04
0000000@0<d0403=01P0c@<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@050000001c0?l0
L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0
L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0
N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l0
0`1c0?l0LP1k0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`000000]01c000000P0L`0i00<000000?ooo`3o
ool0=`3oool003l0oooo0=40000000P0L`0806X0201c00P0JP0807<0201Z00P0L`0806X0201c00P0
JP0807<0201Z00P0L`000000603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0
e@0@0<d0603E0100c@0H0=D0000007/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l000000;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`000000]01c0000001c0340N`0i07<0<@1c03T0L`0a07/0
>@1c0340L`0i0000000i0?ooo`00?`3oool00`000000201Z00P0JP0:00P0JP040000000@0<d0403=
01P0c@<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0000007<0o`1k0?l0
0`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0
o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0
N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0M01k0?l0
L`3o07<0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0000002d07<00000201c03T00`000000oooo0?ooo`0g
0?ooo`00?`3oool0d@000000201c00P0JP0807<0201Z00P0L`0806X0201c00P0JP0807<0201Z00P0
L`000000603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100
c@0H0=D0403=01P0e@000000N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0000002d07<0_@1c0000001c03T0L`0a07/0>@1c0340L`0i07<0
<@1k03T0000003T0oooo000o0?ooo`030000000806X0201Z00T0201Z00<000000100c@0H0<d00`0@
0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=0000000307<0o`05
07/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o
07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o
07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1d07/0o`1c0?l0L`3o
07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`0000020;@0L`030000001c03T0L`0i00D0L`0i00<0
00000?ooo`3oool0=`3oool00400oooo0<D0000000P0JP0807<0201Z00P0L`0806X0201c00P0JP08
07<0201Z0000000@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@
0<d0603E0100c@0H0=D0403=01P0e@0@0<d0000007<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l000000;d0L`020;@0L`090000001k03T0L`0a07<0>@1c
0340N`0i07<0<@1c03T0000003T0oooo00100?ooo`030000000806X0201Z00H0201Z00<000000100
c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0
c@020100c@030000001k0?l0L`3o0080L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0
o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0
o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o0740N`3o07<0o`1c0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o000000030;@0L`030000
001c03T0L`0i00D0L`0i00<000000?ooo`3oool0=`3oool00400oooo0<@0000000P0JP0807<0201Z
00P0L`0806X0201c00P0JP000000403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0000007<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l000000P2d07<02P2m07<0
]01c0000001c0340N`0i07<0<@1c03T0L`0a07/0>@00000i0?ooo`00@03oool00`000000201Z00P0
JP0500P0JP030000000H0<d0403=0080403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0
c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0000007<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0
o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0
o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o06l0N`3o0000002m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`000000102d07<00`000000L`0i07<0>@0407<0>@030000003oool0oooo03L0oooo00100?ooo`35
0000000806X0201c00P0JP0807<0201Z00P0L`000000603E0100c@0H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
0000001c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l000000;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000003^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l00000
0;@0L`2m07<00`2d07<020000000L`0a07<0>@1c0340N`0i07<0<@1c03T00000>@3oool00400oooo
00<0000000P0JP0806X00`0806X00`000000603=0100c@020100c@0501P0c@0@0<d0403=0100c@0H
0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0000007/0o`03
07<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o
00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k
0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1`07/0o`1c
0?l0L`3o0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o000000D0]01c00<0000007<0>@1c03T0101c03T00`000000oooo0?oo
o`0g0?ooo`00@03oool0``000000201Z00P0L`0806X0201c0000000H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
01P0e@0@0<d0603E0100c@0H0=D0000007/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o000000030;@0L`0:0;d0L`2d07<0]01c0000001k03T0L`0a07<0>@1c0340N`0i
000003T0oooo00100?ooo`030000000806X0201Z0080201Z00D000000100c@0@0<d0403=01P0c@03
0100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=
00D0603=0100c@000000L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k
0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c
0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c
0?l0L`3o07/0o`0307<0o`1^07/0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`0000060;@0L`030000001c03T0L`0i00<0
L`0i00<000000?ooo`3oool0=`3oool00400oooo0<D0000000P0JP0807<0201Z0000000@0<d0603E
0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0000001k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`000000]01c0;d0L`030;@0L`080;d0L`000000L`0i
07<0<@1k03T0L`0a07<0>@00000i0?ooo`00@03oool010000000201Z00P0JP0000030100c@0501P0
c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100
c@0@0<d0403=01P0c@030100c@050000001c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0
o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0
o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00P1c0?l0K0000000_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o000000L0]01c00<00000
07<0>@1c03T00`1c03T00`000000oooo0?ooo`0g0?ooo`00@03oool0``000000201Z0000000@0<d0
603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0
403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0000007/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l000000;d0L`030;@0L`0:0;d0L`2d07<0
]01c0;@0L`000000L`0a07<0>@1c0340N`0i000003T0oooo00100?ooo`030000000806X000000080
403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d0
1@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@000000L`3o07/0o`0307<0o`0507/0
o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0
o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1]07/0o`000000_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0000
00080;@0L`030000001c03T0L`0i0080L`0i00<000000?ooo`3oool0=`3oool00400oooo0P000000
`00H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0
e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100
c@000000L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l000000;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o00000080]01c00`0_@1c
0;@0L`2d07<0]01c0;d0L`2d07<0000007<0<@1k03T0L`0a07<0>@00000i0?ooo`00@03oool01000
0000403=0100c@0H0<d30100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100
c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@000000L`3o07<0
o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0
o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0
L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0
J`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000
003^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0000000P0]01c00<0000007<0>@1c03T00P1c03T00`000000oooo0?ooo`0g0?ooo`00@03o
ool0``000000403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D0403=0000001c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o
07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o
07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`000000_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`000000]01c
0;d0L`030;@0L`0:0;d0L`2d07<0]01c0;@0L`2m07<0000007<0>@1c0340N`0i000003T0oooo0011
0?ooo`050000000@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=
00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00P0@0<d00`00
0000N`3o07<0o`0207<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c
0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k
0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`03
07<0o`1/07/0o`1c0?l000000;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l000002P2d07<010000000L`0i07<0>@00000j0?ooo`00@@3oool0`0000000
603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0
403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0
000007<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o0000002m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o000000<0]01c00D0_@1c0;@0L`2d
07<0]01c0;d0L`020;@0L`040000001k03T0L`0a000003X0oooo00110?ooo`030000000@0<d0603=
00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@
0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0000001c0?l0L`3o07/0o`0307<0o`05
07/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o
07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o
07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`1Z0000002d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`000000iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o000000X0]01c00@0
000007<0>@1c03T00000>P3oool00440oooo0<80000001P0e@0@0<d0603E0100c@0H0=D0403=01P0
e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100
c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@000000N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`000000]01c0;d0L`<0]01c00T0_@1c0;@0L`2d07<0]01c0;d0L`2d07<00000
07<0<@000000>P3oool00480oooo00@000000100c@0@0<d0603=0`0@0<d01@0H0<d0403=0100c@0@
0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0403=0100c@0H
0<d00`0@0<d01@000000L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`03
07<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o
00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l0K`1k
0?l0L`3o07<0o`1c0?l0N`3o07<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0000000<0;@0L`030000001c03T0000003X0oooo00120?ooo`2o0000
000@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100
c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0
e@000000N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`000000_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0000002m07<00`2d07<01@2m07<0]01c0;@0
L`2d07<0_@1c00<0]01c00<0000007<0<@000000>P3oool00480oooo00<0000001P0c@0@0<d00P0@
0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@05
01P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0000001c0?l0N`3o00<0L`3o00D0N`3o
07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o
07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o
07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o06T000000;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`000000302d07<00`000000L`0i
0000000j0?ooo`00@P3oool0E0000000403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0
603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0
403=01P0e@0@0<d0603E0100c@0H0=D0000007/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`L00000
06<0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000003^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`0000000P2d07<01@2m07<0]01c0;@0L`2d
07<0_@1c00<0]01c00<0_@1c0;@0L`2d07<00P00000j0?ooo`00@`3oool00`000000403=01P0c@03
0100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=
00D0603=0100c@0@0<d0403=01P0c@030100c@050000001c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k
0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c
0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c
0?l0L`3o07/0o`0307<0o`0307/0o`1c0?l000000080000000<0N`3o0000002m0?l0102m0?l<0000
001F0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0000003^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`00000>0;@0L`800000>P3o
ool004<0oooo04d0000001P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0
403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0
603E0100c@0H0=D0403=0000001c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0
N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0
L`3o07/0o`1c0?l0N`3o07<0o`030000000F07/0o`230?l0N`3o08<0o`000000_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`/00000
04d0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`00
0000]01c0;d0L`030;@0L`050;d0L`2d07<0]01c0;@0L`2m07<00`2d07<00`2m07<000000000000j
0?ooo`00@`3oool01@000000403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0
c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=0080
403=00<0000007/0o`1c0?l00P1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0
o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0
o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`040000000507/0o`230?l0P`3o08<0
o`1k0?l00P230?l00`000000_@3o0;d0o`0J0;d0o`/000000400_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`000000kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l000003P2d07<2
000003X0oooo00130?ooo`160000000H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@
0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H
0=D0403=01P0e@0@0<d0603E0100c@000000L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`<0
000003<0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`000000_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l030000000=02d0?l0_@3o0;@0o`2m0?l0]03o0000
003V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`0000030;@0L`050;d0L`2d07<0]01c0;@0L`2m07<00`2d07<01@2m07<0]01c0;@0L`2d07<00000
03X0oooo00140?ooo`030000000H0<d0403=0080403=00D0603=0100c@0@0<d0403=01P0c@030100
c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0
603=0000001c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0
L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0L`3o07/0o`0307<0o`0507/0o`1c0?l0
L`3o07<0o`1k0?l00`0000000`230?l0N`3o08<0o`0208<0o`0507/0o`230?l0P`3o08<0o`1k0?l0
0`230?l00`1k0?l000000;d0o`0b0;d0o`H0000002h0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o
0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o
0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l000003`2d07<00`000000oooo0?ooo`0h0?oo
o`00A03oool0?`000000403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H
0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@
0<d0603E0100c@000000L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c
0?l0N`3o07<0o`1k0?l0L`3o07/0o`030000001:08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l000000;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l30000000[0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o000000020;@0L`050;d0L`2d07<0]01c0;@0L`2m07<00`2d07<0
1`2m07<0]01c0;@0L`2d07<0_@1c0;@0L`000000>P3oool004@0oooo00@000000100c@0@0<d0603=
0`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100
c@0501P0c@0@0<d0403=0100c@0H0<d00P0@0<d00`000000N`3o07<0o`0207<0o`0507/0o`1c0?l0
L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o00D0N`3o07<0o`1c0?l0
L`3o07/0o`0307<0o`0607/0o`0000000000000000230?l0N`3o0`230?l01@1k0?l0P`3o08<0o`23
0?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0208<0o`030000002m0?l0_@3o03H0_@3o
00<000000>H0o`3V0?l00P000000:@3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l000000100]01c00<000000?ooo`3oool0>03oool004@0oooo03P000000100c@0H0=D0403=01P0
e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100
c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0000001k0?l0L`3o07/0
o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0
o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`@000000500P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l000000;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o00000080iP3o00<0
kP3o0>H0o`3V0?l00P000000:03V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0000002m07<3
0;@0L`050;d0L`2d07<0]01c0;@0L`2m07<00`2d07<0102m07<0]01c0;@0L`00000k0?ooo`00A@3o
ool01@000000403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@05
01P0c@0@0<d0403=0100c@0H0<d00`0@0<d02@0H0<d0403=0100c@0@0<d0603=0100c@000000L`3o
07/0o`0307<0o`0507/0o`1c0?l0L`3o07<0o`1k0?l00`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o
00<0L`3o0`00000208<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`23
0?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0307/0o`230?l0000003H0_@3o
00<000000>H0o`3V0?l01@3V0?l20000000U0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0000000?0;@0
L`030000003oool0oooo03T0oooo00150?ooo`0a0000000H0=D0403=01P0e@0@0<d0603E0100c@0H
0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@
0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0000001k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k
0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`030000001H07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`00
0000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`<0iP3o00D0kP3o0>H0
o`3V0?l0iP3o0>h0o`020000000S0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`0000000P2d07<01@2m07<0]01c0;@0
L`2d07<0_@1c00<0]01c00H0_@1c0;@0L`2d07<0]01c0;d0L`00000k0?ooo`00A@3oool00`000000
403=01P0c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0
603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@050000001c0?l0L`3o07<0o`1k0?l0
0`1c0?l01@1k0?l0L`3o07<0o`1c0?l0N`3o00<0L`3o0`00000208<0o`0507/0o`230?l0P`3o08<0
o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0
o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l00`000000_@3o0;d0o`0d0;d0o`030000
003V0?l0iP3o00T0iP3o0P000000803^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l00000402d07<00`000000oooo0?ooo`0i0?ooo`00AP3o
ool0:P000000403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E
0000001k0?l0L`3o07/0o`1c0?l0N`3o07<0o`1k0?l0L`3o07/0o`1c0?l0N`3o07<0o`<0000005d0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`0000000P3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o02D0kP3o0>H0o`3V0?l0
00000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0000002d07<0_@1c00<0]01c00D0_@1c0;@0L`2d07<0]01c0;d0L`030;@0L`030;d0L`2d07<0
000003`0oooo00160?ooo`040000000@0<d0403=01P0c@<0403=00D0603=0100c@0@0<d0403=01P0
c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@0<d02@0H0<d0403=0100c@0@0<d0603=0100
c@000000L`3o07/0o`0307<0o`0307/0o`1c0?l0L`3o00@000000P230?l01@1k0?l0P`3o08<0o`23
0?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k
0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00L0N`3o08<0o`230?l0P`3o07/0o`23
0?l0000003H0_@3o00<000000>H0o`3V0?l0303V0?l20000000M0>H0o`3^0?l0iP3o0>h0o`3V0?l0
kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`0000003`2d07<00`000000oooo0?ooo`0j0?oo
o`00AP3oool08`000000403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H
0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@
0<d0603E0100c@000000L`3o07/0o`1c0?l0N`3o00<0000006D0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`000000iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l0103^
0?l0iP3o0>H0o`3V0?l20000000K0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0000000<0]01c00D0_@1c0;@0L`2d07<0]01c0;d0L`030;@0L`050;d0L`2d07<0]01c0;@0
L`000000?03oool004H0oooo00<0000001P0c@0@0<d00P0@0<d01@0H0<d0403=0100c@0@0<d0603=
00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0403=0100c@0H0<d00`0@
0<d00`0H0<d0000007<0o`03000000<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0
o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0
o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0
o`230?l0000003D0_@3o00<000000>H0o`3V0?l04@3V0?l20000000I0>H0o`3^0?l0iP3o0>h0o`3V
0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0000000?0;@0L`030000003oool0oooo03X0oooo00170?ooo`0M0000
000H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0
e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d00P000000
J@230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000
00030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0
iP3o01X0kP3o0>H0o`00000000000>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o00000080]01c00D0_@1c
0;@0L`2d07<0]01c0;d0L`030;@0L`060;d0L`2d07<0]01c0;@0L`2m07<00000?@3oool004L0oooo
00<000000100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00D0603=0100c@0@
0<d0403=01P0c@030100c@0601P0c@0@0<d0403=0100c@0H0<d0403=0P0000000`230?l0N`3o08<0
o`0208<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0
P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l0
1@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00L0N`3o08<0o`230?l0P`3o07/0o`230?l0000003D0
_@3o00<000000>H0o`3V0?l05@3V0?l20000000D0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`00000?0;@0L`030000
003oool0oooo03/0oooo00170?ooo`0L0000000H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D0403=00000080803o06`0000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l000000;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l30>H0o`050>h0o`3V0?l0iP3o0>H0o`3^
0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00@0kP3o0>H0o`3V0?l0iP3o0P000000
4`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0
o`3V0?l0kP3o0000002m07<00`2d07<01@2m07<0]01c0;@0L`2d07<0_@1c00<0]01c00@0_@1c0;@0
L`2d07<00000?@3oool004L0oooo00D000000100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0
403=0100c@0H0<d00`0@0<d01@0H0<d0403=0100c@0@0<d0603=00<0403=00@0603=0100c@0@0<d0
00000P0P0?l010000000P`3o08<0o`1k0?l308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l0
1@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0
o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0
o`230?l0P`3o0000000d0;d0o`030000003V0?l0iP3o01X0iP3o0P000000403V0?l0kP3o0>H0o`3^
0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`00000?0;@0L`030000
003oool0oooo03/0oooo00180?ooo`0J0000000@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=
01P0e@0000030200o`1Z000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0000002d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l000000>h0o`<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V
0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o0140kP3o0>H0o`00
0000iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o00000003
0;@0L`050;d0L`2d07<0]01c0;@0L`2m07<00`2d07<01@2m07<0]01c0;@0L`2d07<0000003h0oooo
00180?ooo`030000000H0<d0403=0080403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0
c@0@0<d0403=0100c@0H0<d00`0@0<d0100H0<d0403=0100c@0000050200o`05000000230?l0P`3o
08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o
07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o
00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0307/0o`230?l0000003@0_@3o00<00000
0>H0o`3V0?l07@3V0?l20000000<0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V0?l0kP3o0>H0
o`3^0?l000003`2d07<00`000000oooo0?ooo`0l0?ooo`00B03oool060000000403=01P0e@0@0<d0
603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0
403=01P0e@0@0<d0603E000000H0803o06P0000007/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l000000;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o00000080iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0
o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0
o`3V0?l0iP3o0>h0o`020>H0o`80000000`0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0iP3o0>h0o`3V
0?l000000;@0L`2m07<30;@0L`050;d0L`2d07<0]01c0;@0L`2m07<00`2d07<00`2m07<0]01c0000
000n0?ooo`00B03oool010000000403=0100c@0H0<d30100c@0501P0c@0@0<d0403=0100c@0H0<d0
0`0@0<d01@0H0<d0403=0100c@0@0<d0603=0080403=00<000000200o`0P0?l01@0P0?l00`000000
P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0
N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l0
0`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00H0N`3o08<0o`230?l0P`3o07/0o`00000c
0;d0o`030000003V0?l0iP3o0240iP3o0P000000203^0?l0iP3o0>h0o`3V0?l0kP3o0>H0o`3^0?l0
00003`2d07<00`000000oooo0?ooo`0l0?ooo`00B@3oool05P000000603E0100c@0H0=D0403=01P0
e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100
c@0000080200o`1X000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0000003^0?l30>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0
kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l0
0`3V0?l02@3^0?l000000000003V0?l0kP3o0>H0o`3^0?l0iP3o000000030;@0L`050;d0L`2d07<0
]01c0;@0L`2m07<00`2d07<0102m07<0]01c0;@0L`00000o0?ooo`00B@3oool01@000000403=0100
c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0501P0c@0@0<d0403=0100
c@0000002@0P0?l010000000P`3o08<0o`1k0?l308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`23
0?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`05
07/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00@0N`3o
08<0o`230?l00000<P2m0?l00`000000iP3o0>H0o`0V0>H0o`80000000<0kP3o0>H0o`0000003`2d
07<00`000000oooo0?ooo`0m0?ooo`00B@3oool050000000603E0100c@0H0=D0403=01P0e@0@0<d0
603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d000002P0P0?l0IP00
0000P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o000000<0iP3o00D0kP3o0>H0
o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0
o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0
o`3^0?l00P3V0?l300000080]01c00D0_@1c0;@0L`2d07<0]01c0;d0L`030;@0L`060;d0L`2d07<0
]01c0;@0L`2m07<00000?`3oool004X0oooo00<0000001P0c@0@0<d00P0@0<d01@0H0<d0403=0100
c@0@0<d0603=00<0403=00D0603=0100c@0@0<d0403=0000000<0200o`05000000230?l0P`3o08<0
o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0
o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0
P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0307/0o`000000_@3o0340_@3o00<000000>H0
o`3V0?l0:P3V0?l00`000000]01c0;@0L`0=0;@0L`030000003oool0oooo03d0oooo001:0?ooo`0B
0000000@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E
0100c@0H0=D00000300P0?l0I`000000N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
00000>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0
iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0
kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`020>H0o`030000002m07<0]01c0080]01c00D0
_@1c0;@0L`2d07<0]01c0;d0L`030;@0L`030;d0L`2d07<000000400oooo001:0?ooo`040000000@
0<d0403=01P0c@<0403=00D0603=0100c@0@0<d0403=01P0c@030100c@0301P0c@000000803o00`0
803o00<0000008<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0
o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0
o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0407/0o`230?l0P`3o0000
0380_@3o00<000000>H0o`3V0?l0:@3V0?l00`000000gP3V0000000=0;@0L`030000003oool0oooo
03h0oooo001:0?ooo`0@0000000@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0
403=01P0e@0@0<d0603E000000l0803o06@0000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l000000;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l000000`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0
o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0
iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050000003E0>H000000;@0L`2m07<00`2d07<0
1@2m07<0]01c0;@0L`2d07<0_@1c00<0]01c00<000000?ooo`3oool0?P3oool004/0oooo00D00000
0100c@0@0<d0403=01P0c@030100c@0601P0c@0@0<d0403=0100c@0H0<d00000400P0?l010000000
P`3o08<0o`1k0?l308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`23
0?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k
0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00<0N`3o0000002m0?l0<02m0?l00`00
0000iP3o0>H0o`0Y0>H0o`040000003E0>H0gP3V000000d0]01c00<000000?ooo`3oool0?P3oool0
04/0oooo00d0000001P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d0603E0100c@0H0=D00000
0140803o06<0000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`0000000P3V0?l01@3^0?l0iP3o
0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o
0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o
0>h0o`030>H0o`050>h0o`000000gP3V0=D0iP0000000`2d07<01@2m07<0]01c0;@0L`2d07<0_@1c
00<0]01c00<0_@1c0000003oool0@03oool004/0oooo00<000000100c@0H0<d00`0@0<d01`0H0<d0
403=0100c@0@0<d0603=0100c@0000004P0P0?l01@000000P`3o08<0o`230?l0N`3o00<0P`3o00D0
N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0
P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0
P`3o08<0o`1k0?l00P230?l00`000000_@3o0;d0o`0_0;d0o`030000003V0?l0iP3o02P0iP3o00H0
00000=h0iP3N0>H0gP3V0=D0iP00000;0;@0L`030000003oool0oooo03l0oooo001;0?ooo`0<0000
000H0=D0403=01P0e@0@0<d0603E0100c@0H0=D0403=01P0e@0@0<d000004`0P0?l0H`000000N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V
0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`05
0>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l03@3^0?l0iP3o0>H0o`3V0?l0kP3o0>H0o`000000e@3V
0=h0kP3E0>H0gP3V0000002m07<00`2d07<01@2m07<0]01c0;@0L`2d07<0_@1c0080]01c00<00000
0?ooo`3oool0?`3oool004`0oooo00@000000100c@0@0<d0603=0`0@0<d00`0H0<d0403=0000000D
0200o`03000000230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`23
0?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`23
0?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l00`1k0?l000000;d0o`0`
0;d0o`030000003V0?l0iP3o02P0iP3o00<000000=h0iP3E0>H00P3N0>H00`000000]01c0;@0L`09
0;@0L`030000003oool0oooo03l0oooo001<0?ooo`090000000@0<d0603E0100c@0H0=D0403=01P0
e@0@0<d0000001H0803o0600000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`0000030>H0o`050>h0o`3V0?l0iP3o
0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o
0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o
0080iP3o00L000000=h0kP3E0>H0gP3V0=D0iP3N0>h000000080]01c00D0_@1c0;@0L`2d07<0]01c
0;d0L`030;@0L`030000003oool0oooo0400oooo001<0?ooo`030000000H0<d0403=0080403=00<0
603=0100c@0000005`0P0?l010000000P`3o08<0o`1k0?l308<0o`0507/0o`230?l0P`3o08<0o`1k
0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`03
08<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o
00<000000;d0o`2m0?l0;@2m0?l00`000000iP3o0>H0o`0X0>H0o`030000003E0>H0gP3V0080gP3V
00<0e@3V0=h0iP0000002@2d07<00`000000oooo0?ooo`100?ooo`00C03oool020000000403=01P0
e@0@0<d0603E0100c@0H0=D000005`0P0?l0HP000000P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000003V0?l0kP3o
0`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0
o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00d0
kP3o0>H0o`3V0?l0iP3o0000003E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0000000<0]01c00L0
_@1c0;@0L`2d07<0]01c0;d0L`2d07<000000480oooo001=0?ooo`030000000@0<d0603=0080403=
00<000000200o`0P0?l05`0P0?l01@000000P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`23
0?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`23
0?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0707/0o`230?l0P`3o08<0o`1k
0?l0P`3o0000000_0;d0o`030000003V0?l0iP3o02L0iP3o00D000000=h0iP3N0>H0gP3V0=D0iP03
0=h0iP030000002d07<0]01c00L0]01c00<000000?ooo`3oool0@03oool004d0oooo00D0000001P0
e@0@0<d0603E0000000J0200o`1O0000001k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`0000000`3V0?l01@3^0?l0iP3o0>H0
o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0
o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o0140kP3o0>H0o`3V0?l0iP3o0>h0
o`000000gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP000000]01c0;d0L`030;@0L`040;d0
L`2d07<0]01c000004<0oooo001=0?ooo`040000000@0<d0403=000001/0803o00<0000008<0o`1k
0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`03
08<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o
00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`030000002m0?l0_@3o02d0_@3o00<000000>H0o`3V
0?l09P3V0?l010000000gP3V0=h0iP3E0>H30=h0iP040=D0iP3N0>H0gP3V000000L0]01c00<00000
0?ooo`3oool0@@3oool004d0oooo00@0000001P0e@0@0<d00000700P0?l0G@000000P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`000000]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o00000002
0>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o
00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^
0?l0iP3o0>H0o`3V0?l0kP3o0080iP3o00/000000=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E
0>H0gP3^000000020;@0L`060;d0L`2d07<0]01c0;@0L`2m07<00000@`3oool004h0oooo0P00000M
0200o`04000000230?l0P`3o07/0o`<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0
o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0
o`230?l0P`3o07/0o`0308<0o`0707/0o`230?l0P`3o08<0o`1k0?l0P`3o0000000^0;d0o`030000
003V0?l0iP3o02H0iP3o00<000000=h0iP3E0>H00`3N0>H01P3E0>H0gP3V0=h0iP3N0>H0e@3V0000
00L0]01c00<000000?ooo`3oool0@@3oool004h0oooo00<000000200o`0P0?l07@0P0?l0G@000000
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0000002d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
00000>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0
kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l0
0`3V0?l04@3^0?l0iP3o0>H0o`3V0?l000000=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0
e@3V0=h0iP3E0>H0000000<0]01c00<0_@1c0;@0L`000000A03oool004h0oooo0P00000N0200o`05
000000230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o
08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o
08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o0000000^0;d0o`030000003V0?l0iP3o
02D0iP3o00<000000=D0iP3N0>H00P3N0>H01@3E0>H0gP3V0=h0iP3N0>H0e@3V00<0gP3V00<00000
0;@0L`2d07<00`2d07<00`000000oooo0?ooo`120?ooo`00C`3oool00`000000803o0200o`0L0200
o`1L0000001k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
00000;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`0000020>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V
0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^
0?l00`3V0?l05@3^0?l0iP3o0>H0o`3V0?l0kP3o0000003N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N
0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP000000]01c0;d0L`030;@0L`030000003oool0oooo0480oooo
001?0?ooo`8000007P0P0?l00`000000N`3o08<0o`0208<0o`0507/0o`230?l0P`3o08<0o`1k0?l0
0`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0
o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01`1k0?l0P`3o08<0o`230?l0N`3o08<0o`000000
;@2m0?l00`000000iP3o0>H0o`0U0>H0o`050000003N0>H0gP3V0=h0iP3E0>H00`3N0>H01`3E0>H0
gP3V0=h0iP3N0>H0e@3V0=h0iP0000001@2d07<00`000000oooo0?ooo`120?ooo`00D03oool00`00
0000803o0200o`0L0200o`1L000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l000000>H0o`3^0?l30>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l0
1@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0
o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l04P3^0?l0iP3o0000003E0>H0gP3^0=D0iP3N0>H0e@3V0=h0
kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^00000080]01c00<0_@1c0000003oool0A03o
ool00500oooo0P00000M0200o`04000000230?l0P`3o07/0o`<0P`3o00D0N`3o08<0o`230?l0P`3o
07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o
00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`000000;@2m
0?l00`000000iP3o0>H0o`0U0>H0o`030000003N0>H0e@3V00<0gP3V00D0e@3V0=h0iP3N0>H0gP3V
0=D0iP030=h0iP030=D0iP000000]01c0080]01c00<000000?ooo`3oool0@`3oool00500oooo0P00
000N0200o`1I0000001k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0000
002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`0000000`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0
o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0
iP3o01D0kP3o0>H0o`3V0?l000000=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0
iP3N0>H0e@3V0=h0kP3E0>H0gP3V0000002m07<00P2d07<00`000000oooo0?ooo`130?ooo`00D@3o
ool2000001d0803o00D0000008<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k
0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`03
08<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l0101k0?l0P`3o08<0o`00000/0;d0o`030000
003V0?l0iP3o02@0iP3o00<000000=D0iP3N0>H00P3N0>H01@3E0>H0gP3V0=h0iP3N0>H0e@3V00<0
gP3V00@0e@3V0=h0iP3N0>H000000`2d07<00`000000oooo0?ooo`130?ooo`00D@3oool2000001d0
803o05/0000007/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o0000
002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0000
003V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0
o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0
o`030>H0o`0E0000003E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0
kP3E0>H0gP3V0=D0iP3N0>h0e@3V0000002d07<0000004H0oooo001B0?ooo`8000007@0P0?l00`00
0000N`3o08<0o`0208<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`23
0?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k
0?l00`230?l01P1k0?l0P`3o08<0o`230?l0N`3o000002/0_@3o00<000000>H0o`3V0?l0903V0?l0
1@000000gP3V0=h0iP3N0>H0e@3V00<0gP3V00D0e@3V0=h0iP3N0>H0gP3V0=D0iP030=h0iP050=D0
iP3N0>H000000;@0L`000000AP3oool00580oooo0P00000M0200o`1H000000230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000>h0o`<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0
o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0
iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`0G0>h0o`000000gP3V0=D0iP3N0>h0e@3V0=h0
iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H000000;@0
L`000000AP3oool005<0oooo0P00000L0200o`04000000230?l0P`3o07/0o`<0P`3o00D0N`3o08<0
o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0
o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0407/0o`230?l0P`3o0000
02/0_@3o00<000000>H0o`3V0?l08`3V0?l010000000gP3V0=h0iP3E0>H30=h0iP050=D0iP3N0>H0
gP3V0=h0iP3E0>H00`3N0>H01`3E0>H0gP3V0=h0iP3N0>H000000;@0L`000000AP3oool005<0oooo
0P00000M0200o`1F0000001k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l00000
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`0000020>H0
o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0
kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l0603^0?l0
iP3o0>H0o`000000gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0
gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V000004L0oooo001C0?ooo`03000000000680000001`0
803o00D0000008<0o`230?l0P`3o07/0o`0308<0o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l0
1@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0o`0507/0
o`230?l0P`3o08<0o`1k0?l00`230?l00`1k0?l000000;d0o`0Z0;d0o`030000003V0?l0iP3o0280
iP3o00<000000=h0iP3E0>H00`3N0>H01@3E0>H0gP3V0=h0iP3N0>H0e@3V00<0gP3V00D0e@3V0=h0
iP3N0>H0gP3V0=D0iP020=h0iP030000003oool0oooo04D0oooo001D0?ooo`800000700P0?l0:000
0000N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l90000000V0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0000003^0?l30>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o
0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o
0>H0o`3^0?l00`3V0?l05@000000e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V
0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V000000180?ooo`00E03oool00`000000
001R0000000L0200o`030000001k0?l0P`3o0080P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0
o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00H0
N`3o08<0o`230?l0P`3o07/0o`230?l40000000308/0o`000000]03o00<0_@3o00<0]03o0;d0o`2m
0?l03P00000E0;d0o`030000003V0?l0iP3o0280iP3o00<000000=D0iP3N0>H00P3N0>H01@3E0>H0
gP3V0=h0iP3N0>H0e@3V00<0gP3V00D0e@3V0=h0iP3N0>H0gP3V0=D0iP030=h0iP030000003oool0
oooo04H0oooo001E0?ooo`800000700P0?l080000000P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o0`0000006`2;0?l0P`3o08/0o`230?l0
R`3o0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`0>000000080;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`0000030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V
0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o0>H0o`3^
0?l00`3V0?l05P3^0?l000000=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N
0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP0000190?ooo`00E@3oool00`000000001R
0000000K0200o`04000000230?l0P`3o07/0o`<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`0308<0
o`0507/0o`230?l0P`3o08<0o`1k0?l00`230?l01P1k0?l0P`3o08<0o`230?l0N`3o08<0o`<00000
202;0?l010000000_@3o0;d0o`2d0?l30;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d
0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m
0?l0_@3o0;d0o`2d0?l02000000S0>H0o`050000003N0>H0gP3V0=h0iP3E0>H00`3N0>H01@3E0>H0
gP3V0=h0iP3N0>H0e@3V00<0gP3V00H0e@3V0=h0iP3N0>H0gP3V0=D0iP0000190?ooo`00E@3oool0
0`000000001R0000000L0200o`0H0000001k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o1000
0000=P2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`000000]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`<000000`3V0?l01@3^0?l0iP3o
0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`050>h0o`3V0?l0iP3o
0>H0o`3^0?l00`3V0?l06`3^0?l0iP3o0>H0o`3V0?l0kP3o0>H0o`000000e@3V0=h0kP3E0>H0gP3V
0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V
0000001:0?ooo`00EP3oool00`000000001R0000000K0200o`05000000230?l0P`3o08<0o`1k0?l0
0`230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o00D0N`3o08<0o`230?l0P`3o07/0o`030000
0100R`3o00D000000;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m
0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`05
0;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l00`2d0?l000000=h0o`020=h0o`8000007`3V0?l00`00
0000gP3V0=D0iP030=h0iP050=D0iP3N0>H0gP3V0=h0iP3E0>H00`3N0>H01`3E0>H0gP3V0=h0iP3N
0>H0e@3V0=h0iP000000BP3oool005H0oooo00<000000000HP0000006`0P0?l04P000000N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`<0000003d0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o
08/0o`230?l0R`3o08<0o`2;0?l0P`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0000000<0gP3o00H0e@3o0=h0o`00000000000>H0o`3^0?l30>H0o`050>h0o`3V0?l0
iP3o0>H0o`3^0?l00`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0
iP3o0>h0o`020>H0o`0E0000003N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0
gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0000004/0oooo001G0?ooo`0300000000
0680000001/0803o00<0000007/0o`230?l00P230?l01@1k0?l0P`3o08<0o`230?l0N`3o00<0P`3o
1000000F08/0o`030000002m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`05
0;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o
0;d0o`2m0?l0_@3o0;@0o`030;d0o`040;@0o`2m0?l0_@3o000000L0gP3o0P00000J0>H0o`030000
003E0>H0gP3V0080gP3V00D0e@3V0=h0iP3N0>H0gP3V0=D0iP030=h0iP070=D0iP3N0>H0gP3V0=h0
iP3E0>H0gP3V0000001<0?ooo`00E`3oool010000000001R0000HP00000J0200o`0:000000230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`<0000004<0R`3o08<0o`2;0?l0P`3o08/0o`23
0?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;
0?l0P`3o08/0o`230?l0R`3o08<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l000000080gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`8000000`3V0?l01@3^0?l0iP3o
0>H0o`3V0?l0kP3o00<0iP3o00D0kP3o0>H0o`3V0?l0iP3o0>h0o`030>H0o`0I0>h0o`3V0?l0iP3o
0>H0o`000000e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V
0=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0000001<0?ooo`00F03oool00`000000001R0000000J0200
o`04000000230?l0P`3o07/0o`<0P`3o0`00000M08/0o`050000002m0?l0_@3o0;d0o`2d0?l00`2m
0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`05
0;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00<00000
0=h0o`3N0?l02P3N0?l2000001D0iP3o00D000000=h0iP3N0>H0gP3V0=D0iP030=h0iP050=D0iP3N
0>H0gP3V0=h0iP3E0>H00`3N0>H0103E0>H0gP3V0=h0iP00001=0?ooo`00F03oool010000000001J
0000HP00000J0200o`030000001k0?l0000000<0000004X0R`3o08<0o`2;0?l0P`3o08/0o`230?l0
R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0
P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`000000]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000=D0o`<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`03
0=h0o`060=D0o`3N0?l000000000003V0?l0kP3o0`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0
iP3o01X0kP3o0>H0o`3V0?l0iP3o0>h0o`000000gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0
iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^000004d0oooo001H0?oo
o`04000000000680001R000001X0803o0P00000T08/0o`030000002m0?l0]03o00<0_@3o00D0]03o
0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o
0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`030;@0o`000000gP3o
0100gP3o0P00000@0>H0o`040000003N0>H0gP3V0=D0iP<0gP3V00D0e@3V0=h0iP3N0>H0gP3V0=D0
iP030=h0iP050=D0iP3N0>H0gP3V0=h0iP000000CP3oool005T0oooo00@000000000HP0005X00000
600P0?l0C`000000>@3o0000002;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0
R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0
P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l000000;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`0000000`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0
e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`8000000`3V0?l01@3^0?l0iP3o0>H0o`3V0?l0kP3o00<0
iP3o01L0kP3o0>H0o`3V0?l000000=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0
iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0000001>0?ooo`00F@3oool010000000001R
0000HP00000G0200o`040000000i0?l0>@3o000002D0R`3o00@000000;d0o`2m0?l0]03o0`2m0?l0
1@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0
o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o0080_@3o00<000000=h0
o`3N0?l04`3N0?l2000000/0iP3o00<000000=h0iP3E0>H00`3N0>H01@3E0>H0gP3V0=h0iP3N0>H0
e@3V00<0gP3V00H0e@3V0=h0iP3N0>H0gP3V0=D0iP00001?0?ooo`00FP3oool010000000001R0000
HP00000E0200o`030000000i0?l0>@3o0080>@3o04/0000008<0o`2;0?l0P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o
08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o
0000002m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`0000000P3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o
00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`060=D0o`3N0?l0gP3o0=h0o`3E0?l0gP3o
0P0000000`3V0?l0kP3o0>H0o`020>H0o`0G0>h0o`3V0?l0iP3o0>H0o`000000e@3V0=h0iP3E0>H0
gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP000000
D03oool005X0oooo00@000000000HP0006800000500P0?l00`000000>@3o03T0o`0303T0o`030000
002;0?l0R`3o0280R`3o00<000000;@0o`2m0?l00P2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0
_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l0
1@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00<000000=h0o`3N0?l0603N0?l2000000H0iP3o00<0
00000=D0iP3N0>H00P3N0>H01@3E0>H0gP3V0=h0iP3N0>H0e@3V00<0gP3V00L0e@3V0=h0iP3N0>H0
gP3V0=D0iP3N0>H000000500oooo001K0?ooo`04000000000680001R000001<0803o00<0000003T0
o`0i0?l0100i0?l0B`000000R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0
o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0
o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`000000_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l000000=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l01@3E0?l0gP3o0=h0
o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`8000000`3V0?l0503^0?l0
00000=h0iP3E0>H0gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0
gP3^0=D0iP3N0>H00000D@3oool005/0oooo00@000000000HP00068000004P0P0?l00`000000>@3o
03T0o`0603T0o`030000002;0?l0R`3o0200R`3o00@000000;d0o`2m0?l0]03o0`2m0?l01@2d0?l0
_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0
_@3o0;d0o`2d0?l00`2m0?l01P2d0?l0_@3o0;d0o`2m0?l0]03o000001l0gP3o0P0000000`3V0?l0
00000=h0iP020=h0iP050=D0iP3N0>H0gP3V0=h0iP3E0>H00`3N0>H01@3E0>H0gP3V0=h0iP3N0>H0
e@3V0080gP3V00<000000?ooo`3oool0C`3oool005`0oooo00@000000000FP0006800000400P0?l0
0`000000>@3o03T0o`0703T0o`18000000230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0
o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0
o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l000000;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l000000`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o
0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l01P3E0?l0gP3o0=h0o`3N0?l0e@3o
0=h0o`8000000180e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP3N0>H0
e@3V0=h0kP3E0>H0gP3V0=D0iP00001B0?ooo`00G03oool010000000001R0000HP00000?0200o`03
0000000i0?l0>@3o00T0>@3o00<0000008/0o`2;0?l07`2;0?l00`000000]03o0;d0o`020;d0o`05
0;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o
0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00P2m0?l00`000000gP3o
0=h0o`0O0=h0o`80000000<0gP3V0=D0iP3N0>H00P3N0>H01@3E0>H0gP3V0=h0iP3N0>H0e@3V00<0
gP3V00@0e@3V0=h0iP3N0>H00000D`3oool005d0oooo00@000000000HP0005X000003@0P0?l00`00
0000>@3o03T0o`0:03T0o`160000002;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`23
0?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;
0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l000000;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o00000080
gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l0
1@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`020=h0o`0D0000
003N0?l0gP3o0000003N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0
iP3N0>H0e@3V0=h0kP00001C0?ooo`00G@3oool010000000001R0000HP00000<0200o`030000000i
0?l0>@3o00`0>@3o00<0000008/0o`2;0?l07`2;0?l00`000000_@3o0;@0o`030;d0o`050;@0o`2m
0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m
0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`0000008@3N0?l010000000gP3o0=h0o`00
00020=h0iP050=D0iP3N0>H0gP3V0=h0iP3E0>H00`3N0>H01@3E0>H0gP3V0=h0iP3N0>H0000005@0
oooo001N0?ooo`04000000000680001R000000X0803o00<0000003T0o`0i0?l03P0i0?l0A@000000
R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0
P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0
R`3o08<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l0
0`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0
o`050=D0o`3N0?l0gP3o0=h0o`0000000`3N0?l040000000gP3^0=D0iP3N0>H0e@3V0=h0kP3E0>H0
gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0=D0iP00001D0?ooo`00GP3oool010000000001R0000
HP0000090200o`030000000i0?l0>@3o00l0>@3o00<0000008/0o`2;0?l07P2;0?l01@000000_@3o
0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o
0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00<0]03o0000003N0?l07`3N
0?l00`000000gP3o0=h0o`020=h0o`030000003E0>H0gP3V0080gP3V00D0e@3V0=h0iP3N0>H0gP3V
0=D0iP030=h0iP030=D0iP000000oooo05@0oooo001O0?ooo`04000000000680001R000000L0803o
00<0000003T0o`0i0?l04@0i0?l0@P000000P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`23
0?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;
0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o000000<0gP3o00D0e@3o0=h0
o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l01@3E0?l0gP3o0=h0
o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o000000060=h0o`0>0000003E0>H0gP3^0=D0
iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0e@3V0=h0iP00001E0?ooo`00H03oool00`000000
001R000000060200o`030000000i0?l0>@3o0180>@3o00<0000008/0o`2;0?l07@2;0?l00`000000
_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0
]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`030;@0o`2m0?l000000200gP3o00<0
00000=h0o`3N0?l0103N0?l00`000000gP3V0=D0iP030=h0iP070=D0iP3N0>H0gP3V0=h0iP3E0>H0
gP3V0000001F0?ooo`00H03oool010000000001J0000HP0000050200o`030000000i0?l0>@3o01<0
>@3o0400000008/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0
o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0
o`2;0?l0P`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0
o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0
o`2m0?l0]03o0;d0o`2d0?l000000P3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o
0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l01P3E0?l0gP3o
0=h0o`3N0?l0e@3o000000L0gP3o00`000000=D0iP3N0>H0e@3V0=h0kP3E0>H0gP3V0=D0iP3N0>h0
e@3V0=h0iP00001G0?ooo`00H@3oool00`000000001R000000040200o`030000000i0?l0>@3o01D0
>@3o00<0000008/0o`2;0?l0702;0?l010000000_@3o0;d0o`2d0?l30;d0o`050;@0o`2m0?l0_@3o
0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o
0;@0o`030;d0o`030000003N0?l0gP3o01`0gP3o00<000000=h0o`3N0?l01`3N0?l010000000gP3V
0=h0iP3E0>H30=h0iP040=D0iP3N0>H0gP3V000005L0oooo001Q0?ooo`04000000000680001J0000
0080803o00<0000003T0o`0i0?l05P0i0?l0@0000000P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o
08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l000000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000=h0o`3E0?l30=h0o`050=D0o`3N0?l0
gP3o0=h0o`3E0?l00`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0
gP3o0=D0o`030=h0o`030=D0o`000000gP3o00T0gP3o00X000000=h0kP3E0>H0gP3V0=D0iP3N0>h0
e@3V0=h0iP3E0>H00000F03oool00680oooo00D000000000HP000000803o0000000J03T0o`030000
002;0?l0R`3o01/0R`3o00<000000;@0o`2m0?l00P2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0
_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l0
0`2d0?l000000=h0o`0L0=h0o`030000003N0?l0gP3o00T0gP3o00<000000=D0iP3N0>H00P3N0>H0
1@3E0>H0gP3V0=h0iP3N0>H0000005P0oooo001R0?ooo`04000000000680001R000001/0>@3o03d0
000008/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0
R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0
00000;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
000000<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l0
0`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00<0e@3o0=h0o`0000002`3N0?l02@000000
gP3V0=D0iP3N0>h0e@3V0=h0iP3E0>H0gP3^0000001I0?ooo`00H`3oool010000000001R00000000
000K03T0o`030000002;0?l0R`3o01X0R`3o00@000000;d0o`2m0?l0]03o0`2m0?l01@2d0?l0_@3o
0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`070;@0o`2m0?l0_@3o
0;d0o`2d0?l0_@3o0000000M0=h0o`030000003N0?l0gP3o00/0gP3o00<000000=h0iP3E0>H00`3N
0>H00`3E0>H000000?ooo`1H0?ooo`00H`3oool00`000000001R0000HP02000001/0>@3o03X00000
08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o0000002m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l000000P3N0?l01@3E0?l0
gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0
gP3o0=h0o`3E0?l00`3N0?l00`3E0?l0gP3o0000000>0=h0o`070000003E0>H0gP3V0=D0iP3N0>h0
e@3V0000001J0?ooo`00I03oool01@000000001R000000000>h0000001X0>@3o00<0000008/0o`2;
0?l06@2;0?l00`000000]03o0;d0o`020;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d
0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`030000003N
0?l0gP3o01T0gP3o00<000000=h0o`3N0?l03@3N0?l01P000000gP3V0=h0iP3N0>H0e@3V000005/0
oooo001U0?ooo`0500000000068000000000mP0000006P0i0?l0>P000000P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o
08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`000000_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l000000=h0o`3E0?l30=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l0
0`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00L0e@3o0=h0o`3N0?l0gP3o0=D0o`3N0?l0
00000140gP3o00D000000=h0kP3E0>H0gP3V0000001K0?ooo`00I@3oool00`000000001R00000002
0000kP030000000i0?l0>@3o01L0>@3o00<0000008/0o`2;0?l06@2;0?l00`000000_@3o0;@0o`03
0;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o
00H0]03o0;d0o`2m0?l0_@3o0;@0o`00000K0=h0o`030000003N0?l0gP3o00l0gP3o00@000000=D0
iP3N0>H00000G03oool006H0oooo00H000000000FP000000003^0000mP00000I03T0o`0g0000002;
0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`23
0?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o0000002d0?l0_@3o0;@0o`2m
0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d
0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o000000030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E
0?l00`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`02
0=h0o`030000003N0?l0gP3o0100gP3o00@000000=h0iP3E0>H00000G03oool006H0oooo00<00000
0000HP0000000`000>h00`000000>@3o03T0o`0G03T0o`030000002;0?l0R`3o01L0R`3o00D00000
0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l01@2d0?l0_@3o
0;d0o`2m0?l0]03o00<0_@3o00<0]03o0;d0o`0000006P3N0?l00`000000gP3o0=h0o`0A0=h0o`03
0000003N0>H0000005d0oooo001W0?ooo`80000000D0003^0000mP000>h0003f0000000H03T0o`0e
000000230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l000000;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`0000000P3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o
00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00P3N
0?l00`000000gP3o0=h0o`0C0=h0o`800000G@3oool006L0oooo00<000000000HP00000010000>h0
0`000000>@3o03T0o`0F03T0o`030000002;0?l0R`3o01H0R`3o00<000000;d0o`2d0?l00`2m0?l0
1@2d0?l0_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`050;@0
o`2m0?l0_@3o0;d0o`0000006@3N0?l00`000000gP3o0=h0o`0C0=h0o`030000003oool0oooo05`0
oooo001X0?ooo`80000000H0003f0000kP000?H0003^0000mP00000G03T0o`0e0000002;0?l0P`3o
08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`000000]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o
0;@0o`2m0?l000000=h0o`3E0?l00`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o
0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0gP3o0=h0o`0000005@3N0?l00`000000oooo
0?ooo`1M0?ooo`00J03oool00`000000001R000000050000kP030000000i0?l0>@3o01D0>@3o00<0
000008/0o`2;0?l05@2;0?l01@000000_@3o0;d0o`2m0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0
_@3o0;@0o`030;d0o`050;@0o`2m0?l0_@3o0;d0o`2d0?l00`2m0?l00`2d0?l000000=h0o`0G0=h0
o`030000003N0?l0gP3o01<0gP3o00<000000?ooo`3oool0GP3oool006T0oooo0P0000001`000>h0
003f0000kP000?H0003^0000mP0000005`0i0?l0<@000000R`3o08<0o`2;0?l0P`3o08/0o`230?l0
R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0
P`3o0000002d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`0000000`3N0?l01@3E0?l0
gP3o0=h0o`3N0?l0e@3o00<0gP3o00D0e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`050=D0o`3N0?l0
gP3o0=h0o`000000503N0?l200000640oooo001Z0?ooo`8000001P000>h00`000000>@3o03T0o`0D
03T0o`030000002;0?l0R`3o01D0R`3o00<000000;@0o`2m0?l00P2m0?l01@2d0?l0_@3o0;d0o`2m
0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`030;@0o`2m0?l0000001L0gP3o
00<000000=h0o`3N0?l04P3N0?l200000680oooo001Z0?ooo`80000000P0003f0000kP000?H0003^
0000mP000>h0003f000001H0>@3o02l0000008<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0
P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`000000
_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0
]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o000000020=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l0
0`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00H0e@3o0=h0o`3N0?l0gP3o0=D0o`00000C
0=h0o`800000H`3oool006/0oooo00<000000000kP000>h01P000>h00`000000>@3o03T0o`0C03T0
o`030000002;0?l0R`3o01@0R`3o00@000000;d0o`2m0?l0]03o0`2m0?l01@2d0?l0_@3o0;d0o`2m
0?l0]03o00<0_@3o00D0]03o0;d0o`2m0?l0_@3o0;@0o`030;d0o`030000003N0?l0gP3o01@0gP3o
00<000000=h0o`3N0?l04@3N0?l2000006@0oooo001[0?ooo`80000000T0003^0000mP000>h0003f
0000kP000?H0003^0000mP0000005@0i0?l05@000000R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o
08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`0<0000000>
0;d0o`2d0?l0_@3o0;@0o`2m0?l0]03o0;d0o`2d0?l0_@3o0;@0o`2m0?l000000=h0o`3E0?l30=h0
o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l01@3E0?l0gP3o0=h0o`3N0?l0e@3o00<0gP3o00<0
e@3o0000003N0?l04P3N0?l2000006D0oooo001/0?ooo`03000000000>h0003^00L0003^00<00000
03T0o`0i0?l04`0i0?l00`000000R`3o08/0o`0=08/0o`@0000000`0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l<000001D0gP3o00<000000=h0o`3N0?l04@3N0?l2
000006H0oooo001/0?ooo`80000000X0003f0000kP000?H0003^0000mP000>h0003f0000kP000?H0
0000500i0?l030000000P`3o08/0o`230?l0R`3o08<0o`2;0?l0P`3o08/0o`230?l0R`3o08<0o`@0
000001`0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0P00
00000`3N0?l0e@3o0=h0o`020=h0o`050=D0o`3N0?l0gP3o0=h0o`3E0?l00`3N0?l01P3E0?l0gP3o
0=h0o`3N0?l0e@3o000001<0gP3o0P00001W0?ooo`00K@3oool00`000000003^0000kP080000kP03
0000000i0?l0>@3o0180>@3o00<0000008/0o`2;0?l0102;0?l40000000R07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`800000403N0?l00`000000gP3o0=h0o`0?0=h0o`<00000J03oool006d0oooo0P0000002`000>h0
003f0000kP000?H0003^0000mP000>h0003f0000kP000?H0000001<0>@3o00<0000008/0o`230?l0
10000000:0230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l2000000<0gP3o00D0
e@3o0=h0o`3N0?l0gP3o0=D0o`030=h0o`030=D0o`3N0?l000000140gP3o00<000000440W0000000
J@3oool006h0oooo00<000000000kP000>h02@000>h00`000000>@3o03T0o`0A03T0o`80000002h0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o0P00000:0=h0o`030000003N0?l0gP3o00l0gP3o00<000000440W0000000JP3oool006l0oooo
00d000000000mP000>h0003f0000kP000?H0003^0000mP000>h0003f0000kP000?H000000140>@3o
03<0000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l00P0000000`3N0?l0e@3o0=h0o`020=h0o`030=D0o`3N
0?l000000140gP3o00<000000440W0000000J`3oool00700oooo0P00000:0000kP030000000i0?l0
>@3o00d0>@3o03H0000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l2000000D0gP3o00<0
00000=h0o`3N0?l03P3N0?l00`000000@@2L0000001/0?ooo`00LP3oool030000000003^0000mP00
0>h0003f0000kP000?H0003^0000mP000>h0003f000000d0>@3o03T0000008<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l00P0000020=h0o`030000003N0?l0gP3o00h0gP3o
00<000000440W0000000K@3oool007<0oooo00<000000000kP000>h020000>h00`000000>@3o03T0
o`0903T0o`0l000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`2D0580N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o0P00000@0=h0o`030000001109`0000006h0oooo001d0?ooo`80000000X0003f0000
kP000?H0003^0000mP000>h0003f0000kP000?H000002@0i0?l0?`000000P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o0000000>0=h0o`80
000000<0@@2L0000003oool0KP3oool007H0oooo00<000000000kP000>h01`000>h00`000000>@3o
03T0o`0503T0o`11000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`000000303N0?l010000000@@2L0440W000001`0?oo
o`00M`3oool02`000000003f0000kP000?H0003^0000mP000>h0003f0000kP000?H0000000D0>@3o
0480000008<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`00000;0=h0o`040000001109@0@@2L00000740oooo001h0?oo
o`03000000000>h0003^00L0003^04L0000003T0o`0i0?l0>@3o000000230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o0000000:0=h0o`040000001109`0@@2L00000780oooo001i0?ooo`80000004l0003^0000mP00
0>h0003f0000kP000?H0003^0000mP000000>@3o000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0000000P0gP3o00@000000440U00000000000L`3oool007/0oooo00<000000000kP000>h01P00
0>h0AP000000P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`0000070=h0o`030000001109`0
000007D0oooo001l0?ooo`1?000000000>h0003f0000kP000?H0003^0000mP000>h0000007/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o0000001k0?l0000007/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o000000050=h0o`030000001109@0000007H0oooo
001m0?ooo`8000001P000>h080000000N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0P000000902D_@0000000=ko00000000P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o000000<0
gP3o1000001g0?ooo`00O`3oool09P000000003f0000kP000?H0003^0000mP000000P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o0P000000
902;]00000000=ko00000000N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o00000080gP3o00<000000440W0000000N@3oool00800oooo00<0
00000000kP000>h00`000>h08@000000P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o0:bD00020000000R0=ko00000000P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`800000
00<0@@2L0000003oool0N@3oool00840oooo02H000000000mP000>h0003f0000kP000000N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0:bL
00@0000002<0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`000000@@2L0000001k0?ooo`00PP3oool2000000<0003^01l0000007/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o00@0
00000200N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`<00000O03oool008@0oooo02<000000000kP000?H0000008<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`030000000O
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`02000007h0oooo00250?ooo`0R000000000>h0003^000000230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`<0000001h0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l2000007l0oooo0026
0?ooo`<0000001h0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l30000000M08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l00P0000200?ooo`00R03oool20000000M07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l00P00000070230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l200000880oooo00290?ooo`80000003T0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`000000
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l00P0000230?ooo`00
R`3oool20000000f08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
000000230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o0P0000240?ooo`00
S@3oool20000000d07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o000008H0oooo002?0?ooo`80000002l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0
N`3o08<0o`02000008L0oooo002A0?ooo`80000002T0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o
07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o
08<0o`1k0?l0P`3o07/0o`04000008T0oooo002C0?ooo`80000002<0P`3o07/0o`230?l0N`3o08<0
o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0
o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0
o`04000008d0oooo002E0?ooo`80000001d0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k
0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`23
0?l0N`3o08<0o`1k0?l0P`3o07/0o`0400000940oooo002G0?ooo`d0000000`0N`3o08<0o`1k0?l0
P`3o07/0o`230?l0N`3o08<0o`1k0?l0P`3o07/0o`230?l4000009D0oooo002T0?ooo``00000V@3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3oool00?l0ooooBP3o
ool00?l0ooooBP3oool00001\
\>"],
  ImageRangeCache->{{{0, 328.312}, {535.812, 0}} -> {0.188124, 0.0072683, \
0.00185376, 0.00185376}}]
}, Closed]],

Cell[BoxData[
    \(primEllipsoid[r_, h_, c_]\  := \ 
      TranslateShape[\[IndentingNewLine]AffineShape[\[IndentingNewLine]\
Graphics3D[{SurfaceColor[c, c], Sphere[1, 10, 10]}, \ 
            Boxed \[Rule] False], \[IndentingNewLine]{r, r, 
            h/2}], \[IndentingNewLine]{0, 0, h/2}]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(primLine[r_, h_, c_]\  := \ 
      Graphics3D[\[IndentingNewLine]{Thickness[0.01*r], c, 
          Line[{{0, 0, 0}, {0, 0, h}}]}\[IndentingNewLine], \ 
        Boxed \[Rule] False, \ AspectRatio \[Rule] 1]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Recursion", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\(\(**\)\(\ \)\(Recursively\)\)\ draw\ each\ line\ segment\ of\ \
the\ biomorph\ \
***) \)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(biomorphSubgraph[
        params_List, level_Integer, opts___] := 
      Module[\[IndentingNewLine]{branches, angle, bLength, thisLevelGraphics, 
          subLevelGraphics, \ 
          prim}, \[IndentingNewLine]\[IndentingNewLine]prim\  = \ \(primitive \
/. {opts}\) /. Options[biomorph]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Init\ process\ params\ *) \[IndentingNewLine]branches = 
          params\[LeftDoubleBracket]1\[RightDoubleBracket]; 
        angle = 18*\ 
            params\[LeftDoubleBracket]2\[RightDoubleBracket]\ \[Degree]; 
        bLength = 
          params\[LeftDoubleBracket]3\[RightDoubleBracket]; \
\[IndentingNewLine]bThick = 
          0.2  params\[LeftDoubleBracket]4\[RightDoubleBracket]; 
        bColor = 
          0.1\ params\[LeftDoubleBracket]5\[RightDoubleBracket]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
          Determine\ current\ iteration' 
            s\ primitives\ *) \[IndentingNewLine]thisLevelGraphics\  = \ \
\(\((RotateShape[prim[bThick, bLength, 
                    Hue[bColor]], \[IndentingNewLine]0, \((angle)\), \((#1 + 
                        Mean[Range[branches]])\)*2*Pi/branches])\) &\) /@ 
            yawScale[branches]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Determine\ primitives\ at\ sublevels\ \((iterations)\)\ \
*) \[IndentingNewLine]If[
          level\  \[NotEqual] \ 
            1, \[IndentingNewLine]\[IndentingNewLine]subLevelGraphics\  = \ \
\[IndentingNewLine]\(Module[{transVector\  = \ {0, 0, 
                        1}}, \[IndentingNewLine]transVector\  = \ 
                    Rotate3D[bLength*transVector, 
                      0, \((angle)\), \((#1 + Mean[Range[branches]])\)*2*
                        Pi/branches]; \[IndentingNewLine]TranslateShape[\
\[IndentingNewLine]RotateShape[
                      biomorphSubgraph[Drop[params, 5], level - 1, 
                        opts], \ \[IndentingNewLine]0, \((angle)\), \((#1 + 
                            Mean[Range[branches]])\)*2*
                        Pi/branches], \[IndentingNewLine]transVector\
\[IndentingNewLine]]] &\) /@ yawScale[branches]; \[IndentingNewLine]Show[
            thisLevelGraphics, \ subLevelGraphics, \ 
            DisplayFunction \[Rule] 
              Identity]\[IndentingNewLine]\[IndentingNewLine], \
\[IndentingNewLine]Show[thisLevelGraphics, \ 
            DisplayFunction \[Rule] 
              Identity]\[IndentingNewLine]]\[IndentingNewLine]]\)\)\)], \
"Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(randomSubBranchParameters[branches_, angle_, len_, thick_, 
        col_] := {Random[Integer, {1, branches}], 
        Random[Integer, {1, angle}], \[IndentingNewLine]Random[
          Integer, {1, len}], Random[Integer, {1, thick}], 
        Random[Integer, {1, col}]}\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(On[General::"\<spell1\>"]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Formating Chromosome Into a Table", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    RowBox[{\(formatChromosome[chromo_List]\), " ", ":=", " ", 
      RowBox[{"Module", "[", "\[IndentingNewLine]", 
        RowBox[{\({chromosomeLabels\  = \ {"\<Branches\>", \ "\<Angle\>", \ "\
\<Length\>", \ "\<Thickness\>", \ "\<Color\>"}\ }\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{"FrameBox", "[", 
            RowBox[{"GridBox", "[", "\[IndentingNewLine]", 
              
              RowBox[{\(Insert[\[IndentingNewLine]MapThread[\ \
\[IndentingNewLine]\((\((Insert[#1, #2, \ 
                            1])\) &)\), \ \
\[IndentingNewLine]{MapThread[\(({#1, #2, #3, #4})\) &, 
                        Partition[Drop[chromo, 1], \ 5]], \ 
                      chromosomeLabels}\[IndentingNewLine]]\[IndentingNewLine]\
, \ {"\<\!\(\*
StyleBox[\"Iteration\",\nFontSlant->\"Italic\"]\) \!\(\*
StyleBox[\"#\",\nFontSlant->\"Italic\"]\)\>", "\<\!\(\*
StyleBox[\"1\",\nFontSlant->\"Italic\"]\)\>", "\<\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\>", "\<\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\>", "\<\!\(\*
StyleBox[\"4\",\nFontSlant->\"Italic\"]\)\>"}, 1\[IndentingNewLine]]\), 
                " ", \( (*Insert*) \), "\[IndentingNewLine]", 
                ",", \(ColumnAlignments \[Rule] Left\), "\[IndentingNewLine]",
                 ",", \(RowLines \[Rule] \ {True, False}\), 
                "\[IndentingNewLine]", ",", 
                RowBox[{
                  FormBox["ColumnLines",
                    "TraditionalForm"], "\[Rule]", \({True, False}\)}], 
                "\[IndentingNewLine]", 
                ",", \(ColumnSpacings \[Rule] {3, 3.5}\)}], "]"}], 
            "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
        "]"}]}]], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(\(condensedPrint[{}, 
          selection___]\  := \ {};\)\), "\[IndentingNewLine]", 
    \(\(condensedPrint[chromosomes_List, {}]\  := \ {};\)\)}], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    RowBox[{\(condensedPrint[chromosomes_List, selection_List]\), " ", ":=", 
      " ", 
      RowBox[{"Module", "[", "\[IndentingNewLine]", 
        RowBox[{\({chromosomeLabels\  = \ {"\<Gen\>", "\<Indiv\>", \
"\<Iters\>", "\<Branches\>", \ "\<Angle\>", \ "\<Length\>", \ \
"\<Thickness\>", \ "\<Color\>"}, \
\[IndentingNewLine]chromosomeWithSelection}\), ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          
          RowBox[{\(chromosomeWithSelection\  = \ chromosomes\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              Partition\ chromosome\ and\ group\ together\ attributes\ \
\[IndentingNewLine]\((eg . \ branching, \ angle, \ 
                  color, \ \(\(etc\)\(.\)\))\)\ \[IndentingNewLine]*) \), 
            "\[IndentingNewLine]", \(chromosomeWithSelection\  = \ \
\(\((Prepend[\[IndentingNewLine]MapThread[{#1, #2, #3, #4} &, \
\[IndentingNewLine]Partition[Drop[#1, 1], \ 
                          5]\[IndentingNewLine]]\[IndentingNewLine], \ 
                      Take[#1, 1]])\) &\) /@ \ chromosomeWithSelection\), ";",
             "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              Label\ each\ chromosome\ with\ their\ corresponding\ selection\ \
#\ \((\(ie . \ gen\  &\)\ indiv)\)*) \), 
            "\[IndentingNewLine]", \(chromosomeWithSelection\  = \ \
\[IndentingNewLine]MapIndexed[\((Prepend[
                      Prepend[
                        chromosomeWithSelection[\([\ \ #2[\([1]\)]\ \ ]\)], \
{#1[\([2]\)]}\ \ ], {#1[\([1]\)]}])\) &, \ \ selection]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( \
(*\[IndentingNewLine]\(MapThread[\((Insert[
                        chromosomeWithSelection[\([#1]\)], {#2}, \ 
                        1])\) &, \ \ {Range@\(Length@selection\), 
                    selection}];\)\[IndentingNewLine]*) \), 
            "\[IndentingNewLine]", 
            RowBox[{"FrameBox", "[", 
              RowBox[{"GridBox", "[", "\[IndentingNewLine]", 
                
                RowBox[{\(Insert[\(\((\(\((StringTake[
                                  ToString[#1], {2, \(-2\)}])\) &\)\  /@ \ \
#1)\) &\)\  /@ \ chromosomeWithSelection, chromosomeLabels, \ 1]\), " ", 
                  "\[IndentingNewLine]", 
                  ",", \(ColumnAlignments \[Rule] Center\), 
                  "\[IndentingNewLine]", ",", \(RowLines \[Rule] \ {True}\), 
                  "\[IndentingNewLine]", ",", 
                  RowBox[{
                    FormBox["ColumnLines",
                      "TraditionalForm"], "\[Rule]", \({True}\)}], 
                  "\[IndentingNewLine]", 
                  ",", \(ColumnSpacings \[Rule] {1, 1}\)}], "]"}], 
              "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
        "]"}]}]], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Printing Chromosome", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(printChromosome[chromo_List]\  := \ 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine]Print["\<# of \
Iterations = \>", 
          First[chromo]]; \[IndentingNewLine]formatChromosome[chromo] // 
          DisplayForm\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation and Recombination", "Subsection",
  ShowGroupOpenCloseIcon->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(PointMutation[params_List, index_Integer] := 
      Module[{modTable}, 
        modTable = Flatten[{4, Table[{5, 10, 10, 10, 10}, {4}]}]; 
        MapThread[
          Modulo[#1, #2] + 1 &, {ReplacePart[params, 
              params\[LeftDoubleBracket]index\[RightDoubleBracket] + 
                randomSelect[{\(-1\), 1}], index], modTable}]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(randomSelect[l_] := 
      l\[LeftDoubleBracket]Random[
          Integer, {1, Length[l]}]\[RightDoubleBracket]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Modulo[x_, m_] := 
      Module[{}, 
        If[x == 0, m, If[Mod[x, m] == 0, m - 1, Mod[x, m] - 1]]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(recombine[children_List]\  := \ 
      Module[\[IndentingNewLine]{initChild, \ 
          selectionSize}, \[IndentingNewLine]selectionSize\  = \ 
          Length@children; \[IndentingNewLine]initChild\  = \ 
          First@children; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Replace\ the\ ith\ part\ of\ the\ initChild' 
            s\ chromosome\ with\ the\ ith\ part\ of\ a\ randomly\ choosen\ \(\
\(chromosome\)\(.\)\)\[IndentingNewLine]*) \[IndentingNewLine]For[i = 1, \ 
          i \[LessEqual] \ 21, \ \(i++\), \[IndentingNewLine]initChild\  = \ 
            ReplacePart[\ 
              initChild, \ \[IndentingNewLine]\(children[\([\ \ Random[
                      Integer, \ {1, \ 
                        selectionSize}]\ \ ]\)]\)\ \ [\([i]\)], \
\[IndentingNewLine]i]\[IndentingNewLine]]; \[IndentingNewLine]initChild\
\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(On[General::"\<spell1\>"]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Button Definitions", "Subsection",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell["\<\
invarLRBoxMargin[  maxLen_Integer,   str_String,   opts___  ]\
\>", \
"Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Utility\ Function\ for\ determining\ the\ proper\ left/
          right\ box\ margins\ for\ a\ particular\[IndentingNewLine]string\ \
given\ a\ maximum\ string\ field\ length . \ \ Note\ this\ function\ doesn' 
        t\ take\ into\ \[IndentingNewLine]account\ different\ font\ sizes\ \
and\ styles . \ \ Currently\ it\ only\ works\ with\ the\ default\
\[IndentingNewLine]font\ and\ font\ size . \ \ To\ accommodate\ different\ \
fonts\ and\ font\ sizes, \ 
      one\ must\ adjust\ the\ \[IndentingNewLine]"\<charWidth\>"\ local\ \
constant . \ \ Also\ spaces\ within\ strings\ aren' 
          t\ as\ wide\ as\ regular\ chars\[IndentingNewLine]so\ they' 
          ll\ make\ the\ button\ slightly\ smaller . \[IndentingNewLine]\
\[IndentingNewLine]\(Input : \ \ 1. \ Maximun\ string\ field\ length\
\[IndentingNewLine]
            \ \ \ \ \ \ 2. \ Display\ string\[IndentingNewLine]
            \(Returns : \ {\ leftMarginSize, \ 
                rightMarginSize\ }\[IndentingNewLine]\[IndentingNewLine]
            
            Eg\ of\ \(usage : \ \[IndentingNewLine]BoxMargins\)\)\) \[Rule] \
{invarLRBoxMargin[maxLen, \ "\<hello\>", \ leftMargin \[Rule] \ 1, \ 
            rightMargin \[Rule] 0.5], {0.5, 
            0.5}}\ \[IndentingNewLine]*) \)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(invarLRBoxMargin[maxLen_Integer, \ str_String, \ 
        opts___]\  := \ 
      Module[\[IndentingNewLine]{charWidth\  = \ 0.28, \ theLeftMargin, \ 
          theRightMargin}, \
\[IndentingNewLine]\[IndentingNewLine]theLeftMargin\  = \ \(leftMargin /. \
{opts}\) /. Options[
              invarLRBoxMargin]; \[IndentingNewLine]theRightMargin\  = \ \
\(rightMargin /. {opts}\) /. 
            Options[invarLRBoxMargin]; \
\[IndentingNewLine]\[IndentingNewLine]{theLeftMargin\  + \ 
            charWidth*\((maxLen - 
                  StringLength[
                    str])\), \[IndentingNewLine]theRightMargin\  + \ 
            charWidth*\((maxLen - 
                  StringLength[str])\)}\[IndentingNewLine]]\)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(Options[
          invarLRBoxMargin]\  = \ {\[IndentingNewLine]leftMargin \[Rule] \ 
            0.7, \ rightMargin \[Rule] \ 
            0.7\[IndentingNewLine]};\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["newBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(newBT\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<New\>", \ \ FontColor\  \
\[Rule] \ RGBColor[0, 0, 0]], BoxMargins\  \[Rule] \ {{2, 2}, {0.5, 0.5}}], \ 
        ButtonEvaluator \[Rule] \ Automatic, \ 
        Active \[Rule] \ True\[IndentingNewLine], \ 
        ButtonFunction \[RuleDelayed] \ \
\((\[IndentingNewLine]clearAllSelection@\(getNumGens@
                biomorphModel\); \[IndentingNewLine]biomorphModel\  = \ 
              newBioTree[
                randomBiomorphParams[]]; \[IndentingNewLine]refreshAll[\ 
              biomorphModel];)\)\[IndentingNewLine], 
        ButtonExpandable \[Rule] \ True]\)\(\ \)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["quitBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(quitBT\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Quit\>", \ \ FontColor\  \
\[Rule] \ RGBColor[0, 0, 0]], BoxMargins\  \[Rule] \ {{2, 2}, {0.5, 0.5}}], \ 
        ButtonEvaluator \[Rule] \ Automatic, \ Active \[Rule] \ True, \ 
        ButtonFunction \[RuleDelayed] \((\[IndentingNewLine]parentSelections\ \
 = \ {}; \[IndentingNewLine]\(\((closeNB[#1])\) &\)\  /@ \ 
              allNBs;\[IndentingNewLine])\)\[IndentingNewLine], 
        ButtonExpandable \[Rule] \ True]\)\(\ \)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["curBioBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(curBioBT\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Current\>", \ \ \
FontColor\  \[Rule] \ 
              RGBColor[0, 0, 
                0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ {{0, 0}, {0.5, 
                0.5}}], \ \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ 
        Active \[Rule] \ 
          True, \ \[IndentingNewLine]ButtonFunction \[RuleDelayed] \ \((\
\[IndentingNewLine]If[
              MemberQ[Notebooks[], 
                curBiomorphNBObj], \[IndentingNewLine]closeNB[
                curBiomorphNBObj], \[IndentingNewLine]curBiomorphNBObj\  = \ 
                spawnNB[
                  curBiomorphNB[]]; \[IndentingNewLine]curBiomorphNBRefresh[
                curBiomorphNBObj, \ getCurParent[biomorphModel], 
                extraInfo \[Rule] \((StyleBox["\<Generation   \>" <> 
                        ToString[
                          getNumGens[
                            biomorphModel]], \[IndentingNewLine]FontWeight \
\[Rule] "\<Bold\>"])\)]\[IndentingNewLine]]; \
\[IndentingNewLine]refreshCtrlWin[];\[IndentingNewLine])\)\[IndentingNewLine],\
 ButtonExpandable \[Rule] \ True\[IndentingNewLine], 
        If[MemberQ[Notebooks[], curBiomorphNBObj], 
          Background\  \[Rule] \ RGBColor[1, 1, 0], 
          Background\  \[Rule] \ 
            GrayLevel[0.75]]\[IndentingNewLine]]\)\(\ \)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["chooserOKBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(chooserOKBT\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Evolve\>", \ \ FontColor\
\  \[Rule] \ RGBColor[0, 0, 0]], 
          BoxMargins\  \[Rule] \ {invarLRBoxMargin[8, "\<Evolve\>"], {0.5, 
                0.5}}], \ \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ Active \[Rule] \ True\[IndentingNewLine], \ 
        ButtonFunction \[RuleDelayed] \ \
\[IndentingNewLine]Module[{allSelections}, \[IndentingNewLine]allSelections = 
              getAllSelection@\(getNumGens@
                  biomorphModel\); \[IndentingNewLine]If[
              allSelections\  =!= \ {}, \[IndentingNewLine]clearAllAndUpdate@\
\(getNumGens@biomorphModel\); \[IndentingNewLine]SelectionMove[
                ButtonNotebook[], After, Notebook]; 
              biomorphModel\  = \ \[IndentingNewLine]createNewGen[
                  biomorphModel, \ \[IndentingNewLine]newPopNode@\(recombine@
                      selectionsToBiomorphs[biomorphModel, 
                        allSelections]\)\[IndentingNewLine]]\
\[IndentingNewLine]];\[IndentingNewLine]] (*Module*) \[IndentingNewLine]]\)\(\
\ \)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["infoBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(infoBT\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Compare\>", \ \ \
FontColor\  \[Rule] \ 
              RGBColor[0, 0, 
                0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ \
{invarLRBoxMargin[8, "\<Compare\>"], {0.5, 
                0.5}}], \ \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ Active \[Rule] \ True\[IndentingNewLine], \ 
        ButtonFunction \[RuleDelayed] \ 
          Module[{allSelections}, \[IndentingNewLine]allSelections = 
              getAllSelection@\(getNumGens@
                  biomorphModel\); \[IndentingNewLine]If[
              allSelections\  =!= \ {}, \[IndentingNewLine]refreshInfoNB[\
\[IndentingNewLine]selectionsToBiomorphs[biomorphModel, 
                  allSelections], \ \[IndentingNewLine]allSelections, \ \
\[IndentingNewLine]spawnNB[
                  infoNB]]\[IndentingNewLine]]]\[IndentingNewLine]]\)\(\ \)\)\
\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["profileBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(profileBT\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Profile\>", \ \ \
FontColor\  \[Rule] \ 
              RGBColor[0, 0, 
                0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ \
{invarLRBoxMargin[8, "\<Profile\>"], {0.5, 
                0.5}}], \ \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ 
        Active \[Rule] \ 
          True, \ \[IndentingNewLine]ButtonFunction \[RuleDelayed] \ \
\((Module[{allSelections}, \[IndentingNewLine]allSelections = 
                getAllSelection@\(getNumGens@
                    biomorphModel\); \[IndentingNewLine]If[\(! \
\((allSelections\  === \ {})\)\), \[IndentingNewLine]MapIndexed[\
\[IndentingNewLine]curBiomorphNBRefresh[
                      spawnNB[
                        curBiomorphNB[\[IndentingNewLine]WindowTitle \[Rule] \
\ \(("\<Choice \>" <> 
                                ToString[\ #1[\([1]\)]\ ])\), \
\[IndentingNewLine]WindowMargins \[Rule] {{100 + #2[\([1]\)]*20, 
                                Automatic}, {Automatic, #2[\([1]\)]*20}}\
\[IndentingNewLine]]], \ #1[\([1]\)], \ \[IndentingNewLine]extraInfo \[Rule] \
\((StyleBox["\<Generation   \>" <> 
                              ToString[\ #1[\([2]\)]\ ], \
\[IndentingNewLine]FontWeight \[Rule] "\<Bold\>"])\)\ ] &, \
\[IndentingNewLine]MapThread[{#1, #2[\([1]\)]} &, \
\[IndentingNewLine]{selectionsToBiomorphs[biomorphModel, 
                        allSelections], \[IndentingNewLine]expandSelections@
                        allSelections}]\[IndentingNewLine]]\[IndentingNewLine]\
]\[IndentingNewLine]])\)]\)\(\ \)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["clearSelectionBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(clearSelectionBT[genNum_Integer]\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Unselect\>", \ \ \
FontColor\  \[Rule] \ 
              RGBColor[0, 0, 
                0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ \
{invarLRBoxMargin[8, "\<Unselect\>"], {0.5, 
                0.5}}], \ \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ Active \[Rule] \ True\[IndentingNewLine], \ 
        ButtonFunction \[RuleDelayed] \ \
\((\((\[IndentingNewLine]clearAllAndUpdate[
                  genNum]; \[IndentingNewLine]SelectionMove[ButtonNotebook[], 
                  After, Notebook];\[IndentingNewLine])\) &)\)\
\[IndentingNewLine]]\)\(\ \)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["closeBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(closeBT[nbObj_NotebookObject]\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Close\>", \ \ FontColor\ \
 \[Rule] \ RGBColor[0, 0, 
                0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ \
{invarLRBoxMargin[8, "\<Close\>"], {0.5, 
                0.5}}], \ \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ Active \[Rule] \ True\[IndentingNewLine], \ 
        ButtonFunction \[RuleDelayed] \ \((\[IndentingNewLine]\((closeNB[#2])\
\) &\[IndentingNewLine])\), \ ButtonData \[Rule] nbObj]\)\(\ \)\)\)], "Input",\

  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["toggleSelectionButtons (not used anymore)", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Refresh\ selection\ buttons\ \
*) \)\(\[IndentingNewLine]\)\(toggleSelectionButtons[biosPerRow_Integer, \ 
        maxRows_Integer]\  := \ 
      Module\ [\[IndentingNewLine]{nbObj}, \[IndentingNewLine]nbObj\  = \ 
          ButtonNotebook[]; \[IndentingNewLine]SetSelectedNotebook[
          nbObj]; \ \[IndentingNewLine]For[i = 1, \ 
          i \[LessEqual] \ 
            maxRows, \ \(i++\), \[IndentingNewLine]NotebookFind[
            nbObj, "\<SelectionButtonRow\>" <> ToString[i], Next, \ 
            CellTags, \ 
            AutoScroll\  -> \ False]; \[IndentingNewLine]NotebookWrite[
            nbObj, \ bioSelectionButtons[i, \ biosPerRow, \ 
              maxRows]]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine] (*\ 
          Set\ selection\ insertion\ point\ to\ very\ beginning\ of\ notebook\
\ to\ scroll\ contents\ to\ beginning\ *) \[IndentingNewLine]SelectionMove[
          nbObj, \ Before, \ Notebook]\[IndentingNewLine]]\)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["bioSelectionButtons  (not used anymore)", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(bioSelectionButtons[rowNum_Integer, \ biosPerRow_Integer, \ 
        maxRows_Integer]\  := \ 
      Module\ [\[IndentingNewLine]{buttonStr}, \[IndentingNewLine]Cell[
          BoxData[RowBox[\[IndentingNewLine]Table[\[IndentingNewLine]With[\ \
{buttonID\  = \ buttonNum + 
                        biosPerRow \((rowNum - 
                              1)\)}, \[IndentingNewLine]AdjustmentBox[\
\[IndentingNewLine]ButtonBox[
                      AdjustmentBox[
                        StyleBox[\[IndentingNewLine]buttonStr\  = \ 
                            If[MemberQ[parentSelections, 
                                buttonID], \[IndentingNewLine]"\<P\>" <> \ 
                                ToString[
                                  Extract[\(Position[parentSelections, \ 
                                        buttonID]\)[\([1]\)], 
                                    1]], \[IndentingNewLine]ToString[
                                buttonID]\[IndentingNewLine]], \
\[IndentingNewLine]FontColor\  \[Rule] \ 
                            RGBColor[0, 0, 
                              0]], \[IndentingNewLine]\[IndentingNewLine]\
BoxMargins\  \[Rule] \ {invarLRBoxMargin[5, \ buttonStr], {0.5, 
                              0.5}}\[IndentingNewLine]\[IndentingNewLine]], \ \
\[IndentingNewLine]ButtonEvaluator \[Rule] \ Automatic, \ 
                      Active \[Rule] \ 
                        True, \ \[IndentingNewLine]ButtonFunction \
\[RuleDelayed] \ \
\((\((\[IndentingNewLine]With[\[IndentingNewLine]{buttonNumBF\  = \ \
#2[\([1]\)], \ \[IndentingNewLine]rowNumBF\  = \ #2[\([2]\)], \ \
\[IndentingNewLine]biosPerRowBF\  = \ #2[\([3]\)], \
\[IndentingNewLine]maxRowsBF\  = \ #2[\([4]\)]}, \[IndentingNewLine]\
\[IndentingNewLine]parentSelections\  = \ 
                                  toggleParentSelection[parentSelections, \ 
                                    buttonNumBF + 
                                      biosPerRowBF \((rowNumBF - 
                                        1)\)]; \[IndentingNewLine]\
\[IndentingNewLine]toggleSelectionButtons[biosPerRowBF, \ 
                                  maxRowsBF]\[IndentingNewLine]]\
\[IndentingNewLine])\) &)\), \[IndentingNewLine]ButtonData\  -> \ {buttonNum, \
\ rowNum, \ biosPerRow, \ maxRows}, \[IndentingNewLine]If[
                        MemberQ[parentSelections, 
                          buttonID\ ]\[IndentingNewLine], 
                        Background\  \[Rule] \ 
                          RGBColor[1, 1, 0]\[IndentingNewLine], 
                        Background\  \[Rule] \ 
                          GrayLevel[
                            0.75]\[IndentingNewLine]]\[IndentingNewLine]], \
\[IndentingNewLine]BoxMargins\  \[Rule] \ {{0.25*Mod[buttonNum, 2], 0}, {0, 
                          0}}\[IndentingNewLine]]\[IndentingNewLine]], \
{buttonNum, \ 1, \ biosPerRow}]\[IndentingNewLine]]]\[IndentingNewLine], 
          CellMargins \[Rule] {{4, 0}, {0, 0}}\[IndentingNewLine], 
          CellTags \[Rule] \ {"\<SelectionButtonRow\>" <> 
                ToString[rowNum]}\[IndentingNewLine], 
          ShowCellTags\  \[Rule] \ 
            False\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["primitiveSelectionBT", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(primitiveSelectionBT[theBiomorph_List, label_String, 
        extraInfo_Rule, prim_Rule, \ 
        isSelected_ /; 
          Element[isSelected, \ Booleans]]\)\(\ \)\(:=\)\(\ \)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox[
            label, \ \ FontColor\  \[Rule] \ 
              RGBColor[0, 0, 
                0]], \[IndentingNewLine]BoxMargins\  \[Rule] \ \
{invarLRBoxMargin[9, label], {0.5, 
                0.5}}], \ \[IndentingNewLine]Background\  \[Rule] 
          GrayLevel[0.75], \[IndentingNewLine] (*\(Background\  \[Rule] \ 
            If[isSelected, \ 
              RGBColor[1, 1, 0], \ \ GrayLevel[
                0.75]]\)\(,\)*) \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ 
        Active \[Rule] \ 
          True, \ \[IndentingNewLine]ButtonFunction \[RuleDelayed] \ \((\
\[IndentingNewLine]curBiomorphNBRefresh[ButtonNotebook[], \ theBiomorph, \ 
              prim, \ extraInfo]\[IndentingNewLine])\)]\)\(\ \)\)\)], "Input",\

  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Adjuster Bar", "Subsection",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(currentValAdj =. ;\)\(\ \)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(minRangeAdj = 1; \ maxRangeAdj = 20;\ \), "\[IndentingNewLine]", 
    \(\(stepSizeAdj = 
        Ceiling[\((maxRangeAdj - minRangeAdj)\)/10];\)\)}], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(decrBT[step_?NumberQ, label_String, cellTag_String]\  := \ 
      ButtonBox["\<\[LeftTriangle]\>", \[IndentingNewLine]ButtonEvaluator \
\[Rule] \ Automatic, \ 
        Active \[Rule] \ 
          True, \ \[IndentingNewLine]ButtonFunction \[RuleDelayed] \ \
\((Module[{nbObj = ButtonNotebook[]}, \[IndentingNewLine]updateAdj[label, 
                cellTag, 
                nbObj, \[IndentingNewLine]If[\((currentValAdj[nbObj]\  = \ 
                        currentValAdj[nbObj] - step)\) < \ minRangeAdj, \ 
                  currentValAdj[nbObj]\  = \ 
                    minRangeAdj, \[IndentingNewLine]currentValAdj[
                    nbObj]]\[IndentingNewLine]]\[IndentingNewLine]])\)\
\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(incrBT[step_?NumberQ, label_String, cellTag_String]\  := \ 
      ButtonBox["\<\[RightTriangle]\>", \[IndentingNewLine]ButtonEvaluator \
\[Rule] \ Automatic, \ 
        Active \[Rule] \ 
          True, \ \[IndentingNewLine]ButtonFunction \[RuleDelayed] \ \
\((Module[{nbObj = ButtonNotebook[]}, \[IndentingNewLine]updateAdj[label, 
                cellTag, 
                nbObj, \[IndentingNewLine]If[\((currentValAdj[nbObj]\  = \ 
                        currentValAdj[nbObj] + step)\) > \ maxRangeAdj, 
                  currentValAdj[nbObj]\  = \ 
                    maxRangeAdj, \[IndentingNewLine]currentValAdj[
                    nbObj]]\[IndentingNewLine]]\[IndentingNewLine]])\)\
\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(rangeBT[val_?NumberQ, label_String, cellTag_String, nbObj_]\  := \ 
      ButtonBox[
        AdjustmentBox[
          ToString[
            val], \[IndentingNewLine]BoxMargins \[Rule] {invarLRBoxMargin[\ 
                Floor[N[Log[10, maxRangeAdj]]] + 1, \ ToString[val], \ 
                leftMargin \[Rule] \ 0, \ rightMargin \[Rule] 0], {0, 
                0}}], \[IndentingNewLine]ButtonEvaluator \[Rule] \ 
          Automatic, \ 
        Active \[Rule] \ 
          True, \ \[IndentingNewLine]If[\((\((currentValAdj[
                    nbObj] \[GreaterEqual] 
                  val)\)\  && \ \((currentValAdj[nbObj] < 
                  val + stepSizeAdj)\))\), \[IndentingNewLine]Background \
\[Rule] RGBColor[1, 1, 0], \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.8]\[IndentingNewLine]], \[IndentingNewLine]ButtonFunction \
\[RuleDelayed] \ \((\[IndentingNewLine]updateAdj[label, cellTag, 
              ButtonNotebook[], 
              currentValAdj[ButtonNotebook[]]\  = \ 
                val])\)\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(valBox[nbObj_] := 
      AdjustmentBox[
        FrameBox[
          AdjustmentBox[\[IndentingNewLine]ToString[currentValAdj[nbObj]], 
            BoxMargins \[Rule] {{0, 0}, {0.3, 0.1}}\[IndentingNewLine]]], 
        BoxMargins \[Rule] {{1.5, 0}, {0, 0}}]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(adjuster[label_String, \ cellLabel_String, \ nbObj_, 
        initVal_:  1]\  := \ 
      Module[{}, \[IndentingNewLine]currentValAdj[nbObj]\  = \ 
          initVal; \[IndentingNewLine]Cell[
          BoxData[RowBox[
              Join[\[IndentingNewLine]{AdjustmentBox[
                    StyleBox[label, FontWeight \[Rule] "\<Bold\>"], 
                    BoxMargins \[Rule] {{0.5, 0}, {0, 
                          0}}]}, \[IndentingNewLine]{decrBT[stepSizeAdj, 
                    label, cellLabel]}, \[IndentingNewLine]\(rangeBT[#1, 
                      label, cellLabel, nbObj] &\) /@ 
                  Range[minRangeAdj, \ maxRangeAdj, \ 
                    stepSizeAdj], \ \[IndentingNewLine]{incrBT[stepSizeAdj, 
                    label, cellLabel]}\[IndentingNewLine] (*{valBox[
                      nbObj]}*) \[IndentingNewLine]]\[IndentingNewLine]]], \
\[IndentingNewLine]CellTags \[Rule] 
            cellLabel, \[IndentingNewLine]CellMargins \[Rule] {{0, 0}, {0, 
                0}}\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(updateAdj[label_String, cellTag_String, nbObj_, newVal_?NumberQ] := 
      Module[{}, \[IndentingNewLine]NotebookFind[nbObj, cellTag, Next, \ 
          CellTags, \ 
          AutoScroll\  -> \ False]; \[IndentingNewLine]NotebookWrite[nbObj, 
          adjuster[label, cellTag, nbObj, 
            newVal]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Sub-notebook Definitions", "Subsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(Off[General::"\<spell1\>"]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(screenMaxX\  = \ 1016; \ screenMaxY\  = \ 695; 
    windowBackgroundColor\  = \ RGBColor[0.8, \ 0.8, \ 0.0];\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[CellGroupData[{

Cell["ChooserNB", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(bioWinSizeX\  = \ 500; \ 
    bioWinSizeY\  = \ 650;\), "\[IndentingNewLine]", 
    \(\(\(chooserNB\  := \ \ Notebook[\[IndentingNewLine]{}, \ \
\[IndentingNewLine]WindowElements \[Rule] {"\<VerticalScrollBar\>"}, \
\[IndentingNewLine]WindowFrameElements \[Rule] {"\<CloseBox\>"}, \
\[IndentingNewLine]WindowSize \[Rule] {bioWinSizeX, \ 
            bioWinSizeY}, \[IndentingNewLine]WindowMargins \[Rule] \
{{Automatic, 0}, {Automatic, 
              0}}, \[IndentingNewLine]ShowCellBracket \[Rule] \ 
          True, \ \[IndentingNewLine]WindowClickSelect \[Rule] 
          True, \[IndentingNewLine]WindowFrame \[Rule] "\<Palette\>", \
\[IndentingNewLine]WindowTitle \[Rule] "\<Chooser\>", \
\[IndentingNewLine]Active \[Rule] True, \[IndentingNewLine]Background \[Rule] 
          windowBackgroundColor\[IndentingNewLine]]\)\(\[IndentingNewLine]\)
    \)\)}], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(chooserNBRefresh[nbObj_NotebookObject, \ bioModel_List, opts___]\  := \ 
      Module[{gen, biosPerRowOpt, imgSizeOpt, choiceList, 
          bioParentGraphic}, \
\[IndentingNewLine]\[IndentingNewLine]biosPerRowOpt = \(biosPerRow /. \
{opts}\) /. \[InvisibleSpace]Options[
              chooserNBRefresh]; \[IndentingNewLine]imgSizeOpt = \
\(bioImageSize /. {opts}\) /. \[InvisibleSpace]Options[
              chooserNBRefresh]; \[IndentingNewLine]gen = 
          getNumGens@bioModel; \[IndentingNewLine]choiceList = 
          biomorph[\ 
            getCurChildren[
              bioModel]\ ]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Select\ the\ cell\ containing\ the\ action\ buttons\ to\ be\ \
replace\ *) \[IndentingNewLine]NotebookFind[nbObj, "\<actionBTCell\>", 
          Previous, CellTags]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Replace\ the\ whole\ notebook\ if\ this\ is\ the\ 1  
            st\ generation\ \[IndentingNewLine]\((eg . \ after\ a\ ' 
                New'\ command\ is\ executed)\)\ *) \[IndentingNewLine]If[
          gen === 1, 
          SelectionMove[nbObj, All, 
            Notebook]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Display\ generation\ header\ *) \[IndentingNewLine]NotebookWrite[
          nbObj, Cell["\<Generation:  \>" <> 
              ToString[
                gen], "\<Section\>"]]; \[IndentingNewLine]\[IndentingNewLine] \
(*\ Draw\ biomorph\ parent\ in\ history\ window\ \
*) \[IndentingNewLine]bioParentGraphic\  = \ \[IndentingNewLine]Show[
            biomorph[getCurParent[bioModel]], \ 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]NotebookWrite[nbObj, 
          Cell[\[IndentingNewLine]GraphicsData[\[IndentingNewLine]"\<\
PostScript\>", \[IndentingNewLine]DisplayString[
                Insert[Graphics[
                    bioParentGraphic], {AspectRatio \[Rule] \ Automatic, 
                    ImageSize \[Rule] {150, 
                        150}}, \(-1\)]]\[IndentingNewLine]], \
\[IndentingNewLine]"\<Graphics\>", \[IndentingNewLine]ImageMargins \[Rule] \
{{110, 0}, {0, 
                  0}}\[IndentingNewLine]]]; \[IndentingNewLine]\
\[IndentingNewLine] (*\ Display\ choices\ *) \[IndentingNewLine]chooser[
          nbObj, choiceList, 
          gen, \[IndentingNewLine]choicesPerRow \[Rule] biosPerRowOpt, 
          choiceImageSize \[Rule] 
            imgSizeOpt, \[IndentingNewLine]backgroundColor \[Rule] 
            windowBackgroundColor, \ 
          bracketColor \[Rule] 
            GrayLevel[0]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Create\ evolve, \ 
          info\ and\ clear\ buttons\ *) \[IndentingNewLine]NotebookWrite[
          nbObj, \ Cell[
            BoxData[RowBox[\[IndentingNewLine]{chooserOKBT, infoBT, 
                  profileBT, \[IndentingNewLine]AdjustmentBox[
                    clearSelectionBT[
                      gen], \ \ BoxMargins \[Rule] {{0, 0}, {0, 
                          0}}]}\[IndentingNewLine]]], \
\[IndentingNewLine]CellMargins \[Rule] {{0, 0}, {0, 
                  20}}, \[IndentingNewLine]CellFrame\  \[Rule] \ 
              False, \[IndentingNewLine]CellTags \[Rule] {"\<actionBTCell\>"}\
\[IndentingNewLine]]];\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(Options[chooserNBRefresh] = {\ biosPerRow\  \[Rule] \ 5, 
          bioImageSize\  \[Rule] {70, 70}};\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ImageRegion->{{0, 1}, {0, 1}},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["CurrentNB", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(curBioWinSizeX\  = \ 350; \ 
    curBioWinSizeY\  = \ 570;\), "\[IndentingNewLine]", 
    \(curBiomorphNB[opts___]\  := \ 
      Module[{winMargin, \ 
          winTitle}, \[IndentingNewLine]winMargin\  = \ \(WindowMargins\  /. \
{opts}\) /. Options[
              curBiomorphNB]; \[IndentingNewLine]winTitle\  = \ \(WindowTitle\
\  /. {opts}\) /. 
            Options[curBiomorphNB]; \
\[IndentingNewLine]\[IndentingNewLine]Notebook[{}, \ 
          WindowFrameElements \[Rule] {"\<CloseBox\>"}, 
          WindowSize \[Rule] {curBioWinSizeX, \ 
              curBioWinSizeY}, \[IndentingNewLine]ShowCellBracket \[Rule] \ 
            True, \ WindowClickSelect \[Rule] True, 
          WindowFrame \[Rule] "\<Palette\>", \ \[IndentingNewLine]\ 
          Active \[Rule] True, 
          Background \[Rule] RGBColor[0.8, \ 0.8, \ 0.0], \ 
          WindowMargins \[Rule] 
            winMargin, \[IndentingNewLine]WindowTitle \[Rule] 
            winTitle\[IndentingNewLine]]\[IndentingNewLine]]\)}], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(Options[
          curBiomorphNB] = \ {\[IndentingNewLine]WindowMargins \[Rule] {{0, 
                Automatic}, {20, 
                Automatic}}, \[IndentingNewLine]WindowTitle \[Rule] \
"\<Current Biomorph\>"\[IndentingNewLine]};\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    RowBox[{\(curBiomorphNBRefresh[nbObj_NotebookObject, \ bioParent_List, \ 
        opts___]\), " ", ":=", " ", 
      RowBox[{"Module", " ", "[", " ", "\[IndentingNewLine]", 
        RowBox[{\({bioParentGraphic, \ bioParentModel, \ extraInfoOpt, \ 
            primOpt}\), ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(primOpt\  = \ \(primitive /. \[InvisibleSpace]{opts}\) \
/. \[InvisibleSpace]Options[curBiomorphNBRefresh]\), ";", 
            "\[IndentingNewLine]", \(extraInfoOpt\  = \ \(extraInfo \
/. \[InvisibleSpace]{opts}\) /. \[InvisibleSpace]Options[
                  curBiomorphNBRefresh]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              Select\ entire\ notebook\ to\ be\ replaced\ by\ new\ data\ \
*) \), "\[IndentingNewLine]", \(SelectionMove[nbObj, \ All, \ Notebook]\), 
            ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(NotebookWrite[
              nbObj, \[IndentingNewLine]Cell[
                BoxData[
                  AdjustmentBox[\[IndentingNewLine]StyleBox["\<Number of \
Animation Frames\>", FontWeight \[Rule] "\<Bold\>"], 
                    BoxMargins \[Rule] {{0.5, 0}, {0, 
                          0}}]\[IndentingNewLine]]], 
              CellMargins \[Rule] {{0, 0}, {0, 0}}\[IndentingNewLine]]\), ";",
             "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(If[
              NumberQ[currentValAdj[nbObj]], \[IndentingNewLine]NotebookWrite[
                nbObj, \ 
                adjuster["\<\>", "\<AniFrames\>", nbObj, 
                  currentValAdj[nbObj]]], \[IndentingNewLine]NotebookWrite[
                nbObj, \ 
                adjuster["\<\>", "\<AniFrames\>", nbObj, 
                  1]]\[IndentingNewLine]]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              Create\ primitive\ selection\ buttons\ *) \), 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"If", "[", 
                
                RowBox[{\(SymbolName[liveOn] === "\<True\>"\), ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"NotebookWrite", "[", 
                    RowBox[{"nbObj", ",", " ", 
                      RowBox[{"Cell", "[", 
                        RowBox[{
                          RowBox[{"BoxData", "[", 
                            RowBox[{"RowBox", "[", "\[IndentingNewLine]", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{"primitiveSelectionBT", "[", 
                                    RowBox[{
                                    "bioParent", ",", "\"\<Refresh\>\"", 
                                      ",", \(extraInfo \[Rule] extraInfoOpt\),
                                       ",", \(primitive \[Rule] primLine\), 
                                      ",", 
                                      
                                      RowBox[{\((primLine)\), " ", "===", " ",
                                         
                                        RowBox[{\((primOpt)\), Cell[""]}]}]}],
                                     "]"}], ",", " ", 
                                  "\[IndentingNewLine]", \(live3DPrimitiveBT[
                                    bioParent, "\<Cone\>", 
                                    primitive \[Rule] primCone]\), ",", " ", 
                                  "\[IndentingNewLine]", \(live3DPrimitiveBT[
                                    bioParent, "\<Ellipsoid\>", 
                                    primitive \[Rule] primEllipsoid]\)}], 
                                "\[IndentingNewLine]", "}"}], 
                              "\[IndentingNewLine]", "]"}], "]"}], ",", 
                          "\[IndentingNewLine]", \(CellMargins \[Rule] {{10, 
                                0}, {0, 10}}\), ",", 
                          "\[IndentingNewLine]", \(CellFrame\  \[Rule] \ 
                            False\)}], "\[IndentingNewLine]", "]"}]}], "]"}], 
                  "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
                  RowBox[{"NotebookWrite", "[", 
                    RowBox[{"nbObj", ",", " ", 
                      RowBox[{"Cell", "[", 
                        RowBox[{
                          RowBox[{"BoxData", "[", 
                            RowBox[{"RowBox", "[", "\[IndentingNewLine]", 
                              RowBox[{"{", 
                                RowBox[{"primitiveSelectionBT", "[", 
                                  RowBox[{
                                  "bioParent", ",", "\"\<Refresh\>\"", 
                                    ",", \(extraInfo \[Rule] extraInfoOpt\), 
                                    ",", \(primitive \[Rule] primLine\), ",", 
                                    
                                    RowBox[{\((primLine)\), " ", "===", " ", 
                                      RowBox[{\((primOpt)\), Cell[""]}]}]}], 
                                  "]"}], "\[IndentingNewLine]", "}"}], 
                              "\[IndentingNewLine]", "]"}], "]"}], ",", 
                          "\[IndentingNewLine]", \(CellMargins \[Rule] {{10, 
                                0}, {0, 10}}\), ",", 
                          "\[IndentingNewLine]", \(CellFrame\  \[Rule] \ 
                            False\)}], "\[IndentingNewLine]", "]"}]}], 
                    "]"}]}], "\[IndentingNewLine]", "]"}], 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(NotebookWrite[nbObj, 
                Cell[BoxData[
                    closeBT[
                      nbObj]], \[IndentingNewLine]CellMargins \[Rule] {{10, 
                        0}, {0, 0}}, \[IndentingNewLine]CellFrame\  \[Rule] \ 
                    False\[IndentingNewLine]]\[IndentingNewLine]]\)}], ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              Draw\ biomorph\ parent\ in\ current\ biomorph\ window\ *) \), 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              Print\ current\ bio\ chromosome\ info\ *) \), 
            "\[IndentingNewLine]", \(NotebookWrite[
              nbObj, \ \[IndentingNewLine]{\[IndentingNewLine]Cell[
                  BoxData[\ \ \ \ \ extraInfoOpt\ \ \ \ ]], \
\[IndentingNewLine]Cell[
                  BoxData[\ \ \ \ \ "\<# of Iterations:  \>" <> 
                      ToString[
                        First[bioParent]]\ \ \ \ \ ]], \
\[IndentingNewLine]Cell[
                  BoxData[\ \ \ \ \ formatChromosome[
                      bioParent]\ \ \ \ \ ]]\[IndentingNewLine]}\
\[IndentingNewLine]]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(bioParentModel\  = \ 
              biomorph[bioParent, \ primitive -> primLine]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(bioParentGraphic\  = \ 
              Table[Show[\[IndentingNewLine]bioParentModel, \
\[IndentingNewLine]\[IndentingNewLine]ViewPoint -> {2*N[Cos[t*Degree]], 
                      2*N[Sin[t*Degree]], 
                      1}, \ \[IndentingNewLine]SphericalRegion \[Rule] 
                    True, \[IndentingNewLine]DisplayFunction \[Rule] 
                    Identity, \[IndentingNewLine]ImageSize \[Rule] {250, 
                      250}\[IndentingNewLine]\[IndentingNewLine]], \ {t, 
                  360/currentValAdj[nbObj], 360\ , 
                  360/currentValAdj[nbObj]}]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(\(NotebookWrite[nbObj, 
                  Cell[GraphicsData[\[IndentingNewLine]"\<PostScript\>", \
\[IndentingNewLine]DisplayString[
                        Insert[
                          Graphics[#1], {AspectRatio \[Rule] \ Automatic, 
                            ImageSize \[Rule] {280, 280}, \ 
                            PlotRange \[Rule] {{0, 1}, {0, 
                                  1}}}, \(-1\)]]\[IndentingNewLine]], \
\[IndentingNewLine]"\<Graphics\>", \ \[IndentingNewLine]ImageMargins \[Rule] \
{{\(-0.01\), 0}, {0, 
                          0}}, \[IndentingNewLine]CellTags \[Rule] \
{"\<animationCell\>"}]] &\) /@ bioParentGraphic\), ";", "\[IndentingNewLine]",
             "\[IndentingNewLine]", \( (*\ 
              Set\ selection\ insertion\ point\ to\ very\ beginning\ of\ \
notebook\ to\ scroll\ contents\ to\ beginning\ *) \), 
            "\[IndentingNewLine]", \(SelectionMove[nbObj, \ Before, \ 
              Notebook]\)}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "]"}]}]], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(Options[
          curBiomorphNBRefresh]\  = \ {\[IndentingNewLine]extraInfo \[Rule] "\
\< \>", primitive \[Rule] \ primLine\[IndentingNewLine]};\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["HistoryNB  (not used anymore)", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(historyBioWinSizeX\  = \ 400; \ 
    historyBioWinSizeY\  = \ 650;\), "\[IndentingNewLine]", 
    \(\(\(historyBiomorphNB\  := \ \ Notebook[\[IndentingNewLine]{}, \ \
\[IndentingNewLine]WindowElements \[Rule] {"\<VerticalScrollBar\>"}, \
\[IndentingNewLine]WindowFrameElements \[Rule] {"\<CloseBox\>"}, 
        WindowSize \[Rule] {historyBioWinSizeX, \ 
            historyBioWinSizeY}, \[IndentingNewLine]WindowMargins \[Rule] \
{{Automatic, 0}, {Automatic, 
              0}}, \[IndentingNewLine]ShowCellBracket \[Rule] \ 
          True, \ \[IndentingNewLine]WindowClickSelect \[Rule] 
          True, \[IndentingNewLine]WindowFrame \[Rule] "\<Palette\>", \
\[IndentingNewLine]WindowTitle \[Rule] "\<History\>", \
\[IndentingNewLine]Active \[Rule] True, \[IndentingNewLine]Background \[Rule] 
          windowBackgroundColor\[IndentingNewLine]]\)\(\[IndentingNewLine]\)
    \)\)}], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(historyNBRefresh[nbObj_NotebookObject, \ bioModel_List]\  := \ 
      Module\ [\ \[IndentingNewLine]{bioParentGraphic, \ bioChildrenGraphic, 
          biosPerRow = 5}, \[IndentingNewLine]NotebookWrite[nbObj, \ 
          Cell[StringInsert["\<Generation \>", \ 
              ToString[\ 
                getNumGens[
                  bioModel]\ ], \ \(-1\)]]]; \[IndentingNewLine]\
\[IndentingNewLine] (*\ 
          Draw\ biomorph\ parent\ in\ history\ window\ \
*) \[IndentingNewLine]bioParentGraphic\  = \ 
          Show[biomorph[getCurParent[bioModel]], \ 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]\[IndentingNewLine]NotebookWrite[
          nbObj, Cell[\[IndentingNewLine]GraphicsData[\[IndentingNewLine]"\<\
PostScript\>", \[IndentingNewLine]DisplayString[
                Insert[Graphics[
                    bioParentGraphic], {AspectRatio \[Rule] \ 
                      Automatic}, \(-1\)]]\[IndentingNewLine]], \
\[IndentingNewLine]"\<Graphics\>"]]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]\  (*\ 
          Draw\ biomorph\ children\ in\ history\ window\ \
*) \[IndentingNewLine]bioChildrenGraphic\  = \ 
          Show[\[IndentingNewLine]GraphicsArray[\ 
              Partition[biomorph[getCurChildren[bioModel]]\ , \ biosPerRow]], 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]\[IndentingNewLine]NotebookWrite[
          nbObj, Cell[\[IndentingNewLine]GraphicsData[\[IndentingNewLine]"\<\
PostScript\>", \[IndentingNewLine]DisplayString[
                Insert[Graphics[\ 
                    bioChildrenGraphic], {AspectRatio \[Rule] \ 
                      Automatic}, \(-1\)]]\[IndentingNewLine]], \
\[IndentingNewLine]"\<Graphics\>"]];\[IndentingNewLine]\[IndentingNewLine]]\)]\
, "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["CtrlNB", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    RowBox[{"ctrlBTCell", " ", ":=", " ", 
      RowBox[{"Cell", "[", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"BoxData", "[", 
            RowBox[{"GridBox", "[", 
              RowBox[{\({{newBT}, \ {quitBT}, \ {curBioBT}}\), ",", 
                RowBox[{
                  FormBox["ColumnAlignments",
                    "TraditionalForm"], "\[Rule]", " ", "Center"}], ",", 
                " ", \(RowSpacings\  \[Rule] \ \ 0\), ",", 
                " ", \(ColumnSpacings \[Rule] \ 0\)}], "]"}], " ", "]"}], 
          ",", \(CellMargins \[Rule] {{0, 0}, {0, 0}}\)}], 
        "\[IndentingNewLine]", "]"}]}]], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \(ctrlWinSizeX\  = \ 90; \ 
    ctrlWinSizeY\  = \ If[IsLinux[], 80, 65];\), "\[IndentingNewLine]", 
    \(ctrlWinCoordX\  = \ 0; \ 
    ctrlWinCoordY\  = \ 0;\ \), "\[IndentingNewLine]", 
    \(\(\(ctrlNB\  := \ \ Notebook[\[IndentingNewLine]{ctrlBTCell}, \
\[IndentingNewLine]WindowElements \[Rule] {}, \
\[IndentingNewLine]WindowFrameElements \[Rule] {"\<CloseBox\>"}, \
\[IndentingNewLine]WindowSize \[Rule] {ctrlWinSizeX, \ 
            ctrlWinSizeY}, \[IndentingNewLine]WindowMargins \[Rule] \
{{ctrlWinCoordX, \ Automatic}, {Automatic, 
              ctrlWinCoordY}}, \[IndentingNewLine]ShowCellBracket \[Rule] \ 
          False, \ \[IndentingNewLine]WindowClickSelect \[Rule] 
          False, \[IndentingNewLine]WindowFrame \[Rule] "\<Palette\>", \
\[IndentingNewLine]WindowTitle \[Rule] "\<Biomorph Control Panel\>", \
\[IndentingNewLine]Active \[Rule] True, \[IndentingNewLine]Background \[Rule] 
          RGBColor[0.0, \ 0.0, \ 
            0.0]\[IndentingNewLine]]\)\(\[IndentingNewLine]\)
    \)\)}], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\( (*\ 
      Redraw\ ctrl\ window . \ \ Used\ to\ toggle\ button\ \
\(\(colors\)\(.\)\)\ *) \)\(\[IndentingNewLine]\)\(refreshCtrlWin\  := \ 
      Module[\[IndentingNewLine]{nbObj}, \[IndentingNewLine]nbObj\  = \ 
          ButtonNotebook[]; \[IndentingNewLine]SelectionMove[nbObj, All, 
          ButtonCell]; \[IndentingNewLine]NotebookWrite[nbObj, \ 
          ctrlBTCell]; \[IndentingNewLine]SelectionMove[nbObj, Before, 
          Notebook];\[IndentingNewLine]]\)\)\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["InfoNB", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[{
    \( (*infoWinSizeX\  = \ 400; \ 
      infoWinSizeY\  = \ 650;*) \[IndentingNewLine]infoWinSizeX\  = \ 650; \ 
    infoWinSizeY\  = \ 400;\), "\[IndentingNewLine]", 
    \(infoNB\  := \ \ Notebook[\[IndentingNewLine]{}, \ \
\[IndentingNewLine]WindowElements \[Rule] {"\<VerticalScrollBar\>"}, 
        WindowFrameElements \[Rule] {"\<CloseBox\>"}, 
        WindowSize \[Rule] {infoWinSizeX, \ 
            infoWinSizeY}, \[IndentingNewLine]WindowMargins \[Rule] \
{{Automatic, 0}, {Automatic, 
              0}}, \[IndentingNewLine]ShowCellBracket \[Rule] \ True, \ 
        WindowClickSelect \[Rule] 
          False, \[IndentingNewLine]WindowFrame \[Rule] "\<Palette\>", \
\[IndentingNewLine]WindowTitle \[Rule] "\<Biomorph Info\>", \ \
\[IndentingNewLine]Active \[Rule] 
          True, \[IndentingNewLine]Background \[Rule] \ 
          windowBackgroundColor\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(refreshInfoNB[population_List, \ selections_List, \ 
        nbObj_NotebookObject]\  := \ 
      Module[\[IndentingNewLine]{bioParentGraphic, \ 
          bioParent}, \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Create\ close\ button\ *) \[IndentingNewLine]NotebookWrite[nbObj, \ 
          Cell[BoxData[
              RowBox[\[IndentingNewLine]{closeBT[
                    nbObj]}\[IndentingNewLine]]], \
\[IndentingNewLine]CellMargins \[Rule] {{30, 0}, {0, 
                  20}}, \[IndentingNewLine]CellFrame\  \[Rule] \ 
              False\[IndentingNewLine]]]; \[IndentingNewLine]\
\[IndentingNewLine]NotebookWrite[
          nbObj, \ \[IndentingNewLine]{\[IndentingNewLine]Cell[
              BoxData[\[IndentingNewLine]condensedPrint[population, \ 
                  expandSelections@
                    selections]\[IndentingNewLine]]]\[IndentingNewLine]}]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
          Set\ selection\ insertion\ point\ to\ very\ beginning\ of\ notebook\
\ to\ scroll\ contents\ to\ beginning\ *) \[IndentingNewLine]SelectionMove[
          nbObj, \ Before, \ 
          Notebook]\[IndentingNewLine]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["refreshAll[ ]", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(refreshAll[bioModel_List]\  := \ 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine] (*\(historyNBRefresh[
              historyBiomorphNBObj, \ 
              bioModel];\)*) \[IndentingNewLine]chooserNBRefresh[
          chooserNBObj, \ 
          bioModel]; \
\[IndentingNewLine]\[IndentingNewLine]curBiomorphNBRefresh[curBiomorphNBObj, 
          getCurParent[bioModel], 
          extraInfo \[Rule] \((StyleBox["\<Generation   \>" <> 
                  ToString[
                    getNumGens[
                      bioModel]], \[IndentingNewLine]FontWeight \[Rule] \
"\<Bold\>"])\)];\[IndentingNewLine]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
spawnNB[ nb_Notebook ]
closeNB[ nbObj_NotebookObject ]\
\>", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(spawnNB[nb_Notebook]\  := \ 
      Module[{nbObj}, \ \[IndentingNewLine]nbObj\  = \ 
          NotebookPut[nb]; \[IndentingNewLine]allNBs\  = \ 
          Append[allNBs, \ 
            nbObj]; \[IndentingNewLine]nbObj\[IndentingNewLine]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(closeNB[nbObj_NotebookObject]\  := \ 
      Module[{}, \ \[IndentingNewLine]NotebookClose[
          nbObj]; \[IndentingNewLine]allNBs\  = \ 
          Select[allNBs, \ \((\(! \((#1 === \ 
                      nbObj)\)\))\) &]\[IndentingNewLine]]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(On[General::"\<spell1\>"]\)], "Input",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]],

Cell[CellGroupData[{

Cell["Biomorph Evolution", "Subsubsection",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(\(startEvolutionBT[]\)\(:=\)\(\[IndentingNewLine]\)\(ButtonBox[
        AdjustmentBox[\[IndentingNewLine]StyleBox["\<Start Biomorph \
Program\>", \ \ FontColor\  \[Rule] \ 
              RGBColor[0, 0, 
                0]]\[IndentingNewLine]], \ \[IndentingNewLine]ButtonEvaluator \
\[Rule] \ Automatic, \ Active \[Rule] \ True\[IndentingNewLine], \ 
        ButtonFunction \[RuleDelayed] \ \((\[IndentingNewLine] (*\ 
              Open\ notebooks\ in\ front\ end, \ 
              and\ store\ the\ resulting\ notebook\ objects\ in\ the\ allNBs\ \
list\ *) \[IndentingNewLine]allNBs\  = \ {}; \
\[IndentingNewLine]\(curBiomorphNBObj\  = \ 
                  spawnNB[
                    curBiomorphNB[]];\)\[IndentingNewLine] \
(*\(historyBiomorphNBObj\  = \ 
                    spawnNB[
                      historyBiomorphNB];\)*) \[IndentingNewLine]\(\
chooserNBObj\  = \ spawnNB[chooserNB];\)\[IndentingNewLine]\(ctrlNBObj\  = \ 
                  spawnNB[
                    ctrlNB];\)\[IndentingNewLine]\[IndentingNewLine]\(\
biomorphModel\  = \ 
                  newBioTree[
                    randomBiomorphParams[]];\)\[IndentingNewLine]refreshAll[\ 
                biomorphModel];\[IndentingNewLine])\)]\)\(\ \)\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization flag", "Subsection",
  ShowGroupOpenCloseIcon->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell["\<\
Flag for determining whether or not everything has been initialized \
(ie. user evaluated all initialized cells from Kernal menu).
Used by the 'Start Artflowers' button.  If the cells are not initialized then \
SymbolName[EverythingInitializedFlag] =!= \"True\".\
\>", "Text",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}],

Cell[BoxData[
    \(\(BiomorphInitializedFlag = True;\)\)], "Input",
  InitializationCell->True,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, Placeholder]}]&),
  ButtonEvaluator->None,
  ButtonData:>Automatic,
  Active->False,
  ButtonMinHeight->1,
  ButtonExpandable->True,
  ButtonStyle->None,
  ButtonSource->Automatic,
  ButtonMargins->3,
  ButtonFrame->"Palette",
  Background->GrayLevel[0.750011],
  ButtonNote->None}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell["Dawkins, R. (1986). The Blind Watchmaker.  Oxford, Longman.", "Text"],

Cell["\<\
Kwong,H. (2000).  Improved Interface for Interactive Evolutionary \
Design.  Technical Report, Dept. of Computer Science, University of \
Calgary.\
\>", "Text"],

Cell[TextData[{
  "Official web page for evolutionary design with EVOLVICA:\n ",
  ButtonBox["http://www.cpsc.ucalgary.ca/~jacob/EvolutionaryDesign",
    ButtonData:>{
      URL[ "http://www.cpsc.ucalgary.ca/~jacob/EvolutionaryDesign"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "IMS 2001 web site:\n",
  ButtonBox["http://www.sie.dendai.ac.jp/ims2001/",
    ButtonData:>{
      URL[ "http://www.sie.dendai.ac.jp/ims2001/"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "Technical report on the creation of an improved interface for evolutionary \
design:\n",
  ButtonBox["http://pharos.cpsc.ucalgary.ca/Dienst/UI/2.0/Describe/ncstrl.\
ucalgary_cs/2001-678-01?abstract=",
    ButtonData:>{
      URL[ 
      "http://pharos.cpsc.ucalgary.ca/Dienst/UI/2.0/Describe/ncstrl.ucalgary_\
cs/2001-678-01?abstract="], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 746}},
AutoGeneratedPackage->None,
InitializationCellEvaluation->True,
WindowSize->{777, 668},
WindowMargins->{{Automatic, 113}, {21, Automatic}},
ImageSize->{500, Inherited},
Magnification->1,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`02CoodooL3309K0dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000Goo00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 84, 1, 62, "Title"],
Cell[1792, 53, 213, 6, 82, "Subtitle"],
Cell[2008, 61, 74, 0, 58, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2107, 65, 49, 0, 59, "Section"],
Cell[2159, 67, 1183, 28, 39, "Text"],
Cell[3345, 97, 1185, 23, 55, "Text"],
Cell[4533, 122, 1390, 36, 29, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5960, 163, 36, 0, 59, "Section"],
Cell[5999, 165, 2783, 53, 299, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8819, 223, 41, 0, 59, "Section"],
Cell[8863, 225, 413, 7, 65, "Text"],
Cell[9279, 234, 610, 15, 153, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9926, 254, 39, 0, 39, "Section"],
Cell[9968, 256, 338, 7, 39, "Text"],
Cell[10309, 265, 2861, 54, 639, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13207, 324, 441, 14, 59, "Section"],

Cell[CellGroupData[{
Cell[13673, 342, 443, 14, 46, "Subsection"],
Cell[14119, 358, 17360, 574, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31516, 937, 445, 14, 30, "Subsection"],
Cell[31964, 953, 724, 23, 70, "Text"],

Cell[CellGroupData[{
Cell[32713, 980, 557, 18, 70, "Subsubsection"],
Cell[33273, 1000, 1167, 28, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34477, 1033, 496, 15, 70, "Subsubsection"],
Cell[34976, 1050, 597, 18, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35610, 1073, 511, 15, 70, "Subsubsection"],
Cell[36124, 1090, 547, 17, 70, "Input",
  InitializationCell->True],
Cell[36674, 1109, 947, 23, 70, "Input",
  InitializationCell->True],
Cell[37624, 1134, 669, 19, 70, "Input",
  InitializationCell->True],
Cell[38296, 1155, 1304, 31, 70, "Input",
  InitializationCell->True],
Cell[39603, 1188, 628, 19, 70, "Input",
  InitializationCell->True],
Cell[40234, 1209, 606, 19, 70, "Input",
  InitializationCell->True],
Cell[40843, 1230, 624, 19, 70, "Input",
  InitializationCell->True],
Cell[41470, 1251, 602, 19, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[42109, 1275, 538, 18, 70, "Subsubsection"],
Cell[42650, 1295, 794, 21, 70, "Input",
  InitializationCell->True],
Cell[43447, 1318, 1094, 26, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44578, 1349, 633, 21, 70, "Subsubsection"],
Cell[45214, 1372, 653, 23, 70, "Text"],
Cell[45870, 1397, 581, 18, 70, "Input",
  InitializationCell->True],
Cell[46454, 1417, 736, 21, 70, "Input",
  InitializationCell->True],
Cell[47193, 1440, 620, 21, 70, "Text"],
Cell[47816, 1463, 743, 20, 70, "Input",
  InitializationCell->True],
Cell[48562, 1485, 760, 20, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49359, 1510, 513, 15, 70, "Subsubsection"],
Cell[49875, 1527, 521, 17, 70, "Input",
  InitializationCell->True],
Cell[50399, 1546, 884, 23, 70, "Input",
  InitializationCell->True],
Cell[51286, 1571, 1269, 28, 70, "Input",
  InitializationCell->True],
Cell[52558, 1601, 752, 22, 70, "Text"],
Cell[53313, 1625, 1208, 28, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54558, 1658, 580, 20, 70, "Subsubsection"],
Cell[55141, 1680, 532, 17, 70, "Input",
  InitializationCell->True],
Cell[55676, 1699, 1245, 29, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56958, 1733, 438, 14, 70, "Subsubsection"],
Cell[57399, 1749, 1879, 33, 70, "Output"],

Cell[CellGroupData[{
Cell[59303, 1786, 480, 15, 70, "Input"],
Cell[59786, 1803, 3345, 53, 70, "Output"]
}, Open  ]],
Cell[63146, 1859, 450, 15, 70, "Input"],

Cell[CellGroupData[{
Cell[63621, 1878, 462, 15, 70, "Input"],
Cell[64086, 1895, 463, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64586, 1915, 469, 15, 70, "Input"],
Cell[65058, 1932, 572, 18, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65667, 1955, 462, 15, 70, "Input"],
Cell[66132, 1972, 863, 20, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67032, 1997, 467, 15, 70, "Input"],
Cell[67502, 2014, 513, 16, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[68064, 2036, 439, 14, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[68528, 2054, 488, 15, 70, "Input"],
Cell[69019, 2071, 1736, 31, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70792, 2107, 494, 15, 70, "Input"],
Cell[71289, 2124, 1682, 31, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73008, 2160, 488, 15, 70, "Input"],
Cell[73499, 2177, 3113, 50, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76649, 2232, 486, 15, 70, "Input"],
Cell[77138, 2249, 514, 16, 70, "Output"]
}, Open  ]],
Cell[77667, 2268, 462, 15, 70, "Input"],
Cell[78132, 2285, 463, 15, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[78644, 2306, 478, 15, 30, "Subsection"],

Cell[CellGroupData[{
Cell[79147, 2325, 517, 16, 37, "Subsubsection"],
Cell[79667, 2343, 464, 15, 70, "Input"],
Cell[80134, 2360, 489, 16, 70, "Input",
  InitializationCell->True],
Cell[80626, 2378, 487, 15, 70, "Input"],
Cell[81116, 2395, 513, 16, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[81666, 2416, 516, 16, 29, "Subsubsection"],
Cell[82185, 2434, 886, 26, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83120, 2466, 549, 16, 30, "Subsection"],

Cell[CellGroupData[{
Cell[83694, 2486, 522, 16, 70, "Subsubsection"],
Cell[84219, 2504, 692, 21, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[84948, 2530, 517, 16, 70, "Subsubsection"],
Cell[85468, 2548, 525, 17, 70, "Input"],
Cell[85996, 2567, 989, 25, 70, "Input",
  InitializationCell->True],
Cell[86988, 2594, 767, 22, 70, "Input",
  InitializationCell->True],
Cell[87758, 2618, 816, 24, 70, "Input",
  InitializationCell->True],
Cell[88577, 2644, 652, 20, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[89266, 2669, 516, 16, 70, "Subsubsection"],
Cell[89785, 2687, 583, 18, 70, "Input",
  InitializationCell->True],
Cell[90371, 2707, 574, 18, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[90982, 2730, 509, 16, 70, "Subsubsection"],
Cell[91494, 2748, 649, 20, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[92168, 2772, 548, 17, 70, "Input"],
Cell[92719, 2791, 313095, 4956, 70, 29315, 1439, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[405829, 7750, 743, 20, 70, "Input",
  InitializationCell->True],
Cell[406575, 7772, 675, 19, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[407287, 7796, 508, 16, 70, "Subsubsection"],
Cell[407798, 7814, 528, 17, 70, "Input",
  InitializationCell->True],
Cell[408329, 7833, 3141, 64, 70, "Input",
  InitializationCell->True],
Cell[411473, 7899, 804, 22, 70, "Input",
  InitializationCell->True],
Cell[412280, 7923, 527, 17, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[412844, 7945, 499, 15, 70, "Subsubsection"],
Cell[413346, 7962, 2158, 47, 70, "Input",
  InitializationCell->True],
Cell[415507, 8011, 615, 18, 70, "Input",
  InitializationCell->True],
Cell[416125, 8031, 3298, 68, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[419460, 8104, 485, 15, 70, "Subsubsection"],
Cell[419948, 8121, 712, 20, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[420709, 8147, 522, 16, 30, "Subsection"],
Cell[421234, 8165, 528, 17, 70, "Input",
  InitializationCell->True],
Cell[421765, 8184, 879, 24, 70, "Input",
  InitializationCell->True],
Cell[422647, 8210, 646, 20, 70, "Input",
  InitializationCell->True],
Cell[423296, 8232, 636, 20, 70, "Input",
  InitializationCell->True],
Cell[423935, 8254, 1336, 30, 70, "Input",
  InitializationCell->True],
Cell[425274, 8286, 527, 17, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[425838, 8308, 509, 16, 30, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[426372, 8328, 537, 18, 70, "Subsubsection"],
Cell[426912, 8348, 2509, 52, 70, "Input",
  InitializationCell->True],
Cell[429424, 8402, 637, 19, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[430098, 8426, 471, 15, 70, "Subsubsection"],
Cell[430572, 8443, 1176, 28, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[431785, 8476, 472, 15, 70, "Subsubsection"],
Cell[432260, 8493, 1032, 24, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[433329, 8522, 474, 15, 70, "Subsubsection"],
Cell[433806, 8539, 1911, 43, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[435754, 8587, 477, 15, 70, "Subsubsection"],
Cell[436234, 8604, 1618, 34, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[437889, 8643, 472, 15, 70, "Subsubsection"],
Cell[438364, 8660, 1412, 33, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[439813, 8698, 475, 15, 70, "Subsubsection"],
Cell[440291, 8715, 2097, 45, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[442425, 8765, 482, 15, 70, "Subsubsection"],
Cell[442910, 8782, 1173, 28, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[444120, 8815, 473, 15, 70, "Subsubsection"],
Cell[444596, 8832, 1036, 25, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[445669, 8862, 507, 15, 70, "Subsubsection"],
Cell[446179, 8879, 1515, 35, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[447731, 8919, 505, 15, 70, "Subsubsection"],
Cell[448239, 8936, 3651, 69, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[451927, 9010, 486, 15, 70, "Subsubsection"],
Cell[452416, 9027, 1458, 35, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[453923, 9068, 503, 16, 30, "Subsection",
  InitializationCell->True],
Cell[454429, 9086, 502, 16, 70, "Input",
  InitializationCell->True],
Cell[454934, 9104, 615, 18, 70, "Input",
  InitializationCell->True],
Cell[455552, 9124, 1184, 28, 70, "Input",
  InitializationCell->True],
Cell[456739, 9154, 1183, 28, 70, "Input",
  InitializationCell->True],
Cell[457925, 9184, 1535, 36, 70, "Input",
  InitializationCell->True],
Cell[459463, 9222, 725, 21, 70, "Input",
  InitializationCell->True],
Cell[460191, 9245, 1519, 33, 70, "Input",
  InitializationCell->True],
Cell[461713, 9280, 796, 21, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[462546, 9306, 487, 15, 30, "Subsection"],
Cell[463036, 9323, 528, 17, 47, "Input",
  InitializationCell->True],
Cell[463567, 9342, 610, 18, 63, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[464202, 9364, 475, 15, 44, "Subsubsection"],
Cell[464680, 9381, 1360, 31, 271, "Input",
  InitializationCell->True],
Cell[466043, 9414, 3736, 74, 767, "Input",
  InitializationCell->True],
Cell[469782, 9490, 640, 19, 47, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[470459, 9514, 475, 15, 36, "Subsubsection"],
Cell[470937, 9531, 1499, 36, 223, "Input",
  InitializationCell->True],
Cell[472439, 9569, 707, 20, 95, "Input",
  InitializationCell->True],
Cell[473149, 9591, 9150, 165, 1529, "Input",
  InitializationCell->True],
Cell[482302, 9758, 619, 18, 79, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[482958, 9781, 495, 15, 36, "Subsubsection"],
Cell[483456, 9798, 1384, 31, 271, "Input",
  InitializationCell->True],
Cell[484843, 9831, 2262, 48, 495, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[487142, 9884, 472, 15, 36, "Subsubsection"],
Cell[487617, 9901, 1124, 29, 95, "Input",
  InitializationCell->True],
Cell[488744, 9932, 1513, 34, 287, "Input",
  InitializationCell->True],
Cell[490260, 9968, 976, 24, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[491273, 9997, 472, 15, 36, "Subsubsection"],
Cell[491748, 10014, 1351, 31, 239, "Input",
  InitializationCell->True],
Cell[493102, 10047, 1638, 36, 415, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[494777, 10088, 479, 15, 36, "Subsubsection"],
Cell[495259, 10105, 1103, 28, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[496399, 10138, 528, 18, 60, "Subsubsection"],
Cell[496930, 10158, 739, 21, 70, "Input",
  InitializationCell->True],
Cell[497672, 10181, 749, 21, 70, "Input",
  InitializationCell->True],
Cell[498424, 10204, 527, 17, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[498988, 10226, 452, 14, 36, "Subsubsection"],
Cell[499443, 10242, 1702, 38, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[501194, 10286, 482, 15, 30, "Subsection"],
Cell[501679, 10303, 695, 19, 70, "Text"],
Cell[502377, 10324, 505, 16, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[502931, 10346, 29, 0, 39, "Section"],
Cell[502963, 10348, 75, 0, 29, "Text"],
Cell[503041, 10350, 170, 4, 29, "Text"],
Cell[503214, 10356, 285, 6, 60, "Text"],
Cell[503502, 10364, 212, 6, 60, "Text"],
Cell[503717, 10372, 405, 10, 60, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

